@@ -13,7 +13,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 #include <stdio.h>
 #include <unistd.h>
@@ -27,7 +27,7 @@
 
 #include "cdw_ncurses.h"
 
-#include "config.h"
+#include "config_cdw.h"
 
 #include "cdw_config.h"
 #include "gettext.h"
