@@ -1,5 +1,5 @@
-#ifndef __CDDB_H_
-#define __CDDB_H_
+#ifndef H_CDW_CDDB
+#define H_CDW_CDDB
 
 #ifdef HAVE_LIBMYSQLCLIENT
 #include <mysql/mysql.h>
@@ -12,7 +12,9 @@ MYSQL_RES* query_content(char *type, char *disk, char *dir);
 MYSQL_RES* query_disk(char *cdname, int no, char *type);
 MYSQL_RES* search_content(char *file, char *type, char *disk, char *dir)
 
-#endif
+#endif /* #ifdef HAVE_LIBMYSQLCLIENT */
+
+
 
 #ifdef HAVE_LIBSQLITE
 #include <sqlite.h>
@@ -24,6 +26,6 @@ int add_to_dic();
 SQLITE_RES* query_content(char *type, char *disk, char *dir);
 SQLITE_RES* query_disk(char *cdname, int no, char *type);
 SQLITE_RES* search_content(char *file, char *type, char *disk, char *dir)*/
-#endif
+#endif /* #ifdef HAVE_LIBSQLITE */
 
-#endif
+#endif /* #ifndef H_CDW_CDDB */
