@@ -14,18 +14,19 @@
 
 typedef cdw_rv_t (* fields_builder_function_t)(cdw_form_t *, void *, int, int, int, int);
 
+
 typedef struct {
-	bool visible;           /* on some occasions some config pages are disabled = invisible */
-	int n_fields;           /* number of fields in ncurses form (last field=NULL not included) */
-	fields_builder_function_t fields_builder;  /* function that defines fields description and creates the fields */
-	const char *label;      /* text label specific to each page; it will be passed to function creating tabs of tabbed window */
-	cdw_form_t *cdw_form;   /* data structure build on top of ncurses fields, and combined with "tabbed windows" window and subwindow */
-} cdw_config_page_t;
+	bool visible;           /* On some occasions some options pages are disabled = invisible. */
+	int n_fields;           /* Number of fields in ncurses form (last field=NULL not included). */
+	fields_builder_function_t fields_builder;  /* Function that defines fields description and creates the fields in the options page. */
+	const char *label;      /* Text label specific to each options page. It will be passed to function creating tabs of tabbed window. */
+	cdw_form_t *cdw_form;   /* Data structure built on top of ncurses fields, and combined with "tabbed windows" window and subwindow. */
+} cdw_options_page_t;
 
 cdw_rv_t cdw_config_window(void);
 
 
-cdw_rv_t cdw_config_ui_tabs_window_form_draw(cdw_tabs_window_t *twindow, cdw_config_page_t *c_pages);
+cdw_rv_t cdw_config_ui_tabs_window_form_draw(cdw_tabs_window_t *twindow);
 int      cdw_config_ui_tabs_window_form_reader(void *twindow);
 
 
@@ -71,6 +72,12 @@ enum {
 	f_audiodir_i,
 	f_audiodir_b };
 
+/* field indexes for page with UDF settings */
+enum {
+	f_udf_tools_t = 0,
+	f_udf_options_t
+};
+
 /* field indexes for page with tool settings */
 enum {
 	f_ext_tools_no_save_t = 0,
@@ -101,10 +108,10 @@ enum {
 	f_volume_size_dd,
 	f_cust_volume_size_l,
 	f_cust_volume_size_i,
+	f_cust_volume_size_l2,
 	f_follow_symlinks_cb,
 	f_follow_symlinks_l
 };
 
 
 #endif /* H_CDW_CONFIG_WINDOW */
-
