@@ -1,6 +1,6 @@
 /* cdw
  * Copyright (C) 2002 Varkonyi Balazs
- * Copyright (C) 2007 - 2012 Kamil Ignacak
+ * Copyright (C) 2007 - 2014 Kamil Ignacak
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 
@@ -31,7 +31,12 @@
 
 
 #include <cdio/mmc.h>
+#include <cdio/mmc_cmds.h>
 #include <cdio/logging.h>
+#include <cdio/iso9660.h>
+
+#include "config_cdw_undefine.h"
+#include "config_cdw.h"
 
 #include "cdw_cdio.h"
 #include "cdw_cdio_drives.h"
@@ -42,7 +47,6 @@
 #include "gettext.h"
 #include "cdw_debug.h"
 #include "cdw_logging.h"
-#include "config.h"
 #include "cdw_sys.h"
 
 
@@ -142,6 +146,8 @@ static cdw_rv_t cdw_cdio_get_info_fs(cdw_cdio_t *disc, const char *device_fullpa
 static void     cdw_cdio_get_info_cd(cdw_cdio_t *disc);
 static void     cdw_cdio_get_info_dvd(cdw_cdio_t *disc);
 
+static void cdw_cdio_get_iso9660_pvd(cdw_cdio_t *disc);
+
 static void cdw_cdio_init_values(cdw_cdio_t *disc);
 
 static cdw_track_format_t cdw_cdio_get_track_format_from_sector_header(cdw_cdio_t *disc, lsn_t sector);
@@ -389,6 +395,8 @@ cdw_rv_t cdw_cdio_get_info(cdw_cdio_t *disc, const char *device_fullpath)
 		cdw_cdio_get_info_dvd(disc);
 	}
 
+	cdw_cdio_get_iso9660_pvd(disc);
+
 	crv = cdw_cdio_get_info_fs(disc, device_fullpath);
 
 	return crv;
@@ -398,6 +406,30 @@ cdw_rv_t cdw_cdio_get_info(cdw_cdio_t *disc, const char *device_fullpath)
 
 
 
+void cdw_cdio_get_iso9660_pvd(cdw_cdio_t *disc)
+{
+	iso9660_pvd_t pvd;
+	bool r = iso9660_fs_read_pvd(disc->p_cdio, &pvd);
+
+	if (!r) {
+		cdw_vdm ("ERROR: failed to read ISO9660 PVD\n");
+		return;
+	}
+
+	int block_size = iso9660_get_pvd_block_size(&pvd);
+	int space_size = iso9660_get_pvd_space_size(&pvd);
+
+	cdw_vdm ("INFO: PVD        space size = %d (%.2f MB)\n", space_size, space_size * block_size / (1024 * 1024.0));
+	cdw_vdm ("INFO: PVD        block size = %d\n", block_size);
+	cdw_vdm ("INFO: PVD              type = %d\n", pvd.type);
+
+	return;
+}
+
+
+
+
+
 /**
    \brief Get disc type (CD/DVD)
 
@@ -764,6 +796,7 @@ cdw_rv_t cdw_cdio_recognize_track(cdw_cdio_t *disc, track_t t)
 	   to check track format, and may be used later when reading sectors */
 	disc->tracks[t].first_sector = cdio_get_track_lsn(disc->p_cdio, t);
 	disc->tracks[t].last_sector = cdio_get_track_last_lsn(disc->p_cdio, t);
+
 	disc->tracks[t].n_sectors = disc->tracks[t].last_sector - disc->tracks[t].first_sector + 1;
 
 	if (disc->tracks[t].first_sector == CDIO_INVALID_LSN
@@ -1214,18 +1247,32 @@ void cdw_cdio_disc_debug_print(cdw_cdio_t *disc)
 		cdw_assert (0, "ERROR: missed case\n");
 	}
 
+	/* FIXME: maybe this is not the best place to put this
+	   specific FIXME, but...
+
+	   in main window ('Volume' window -> 'On disc') we display
+	   total size of data on disc. Sometimes it is a sum of sizes
+	   of file systems in tracks - and this is bad, because tracks
+	   are larger than field systems in the tracks.
+
+	   Try to use file system size for reading data from tracks,
+	   but also try to use n_sectors to show usage of disc
+	   area. */
+
 	for (track_t t = disc->first_track; t <= disc->last_track; t++) {
 		cdw_vdm ("## INFO: ---------------------------------------- \n");
-		cdw_vdm ("## INFO:      track number = %8d \n", t);
-		cdw_vdm ("## INFO:      first_sector = %8d \n", disc->tracks[t].first_sector);
-		cdw_vdm ("## INFO:       last_sector = %8d \n", disc->tracks[t].last_sector);
-		cdw_vdm ("## INFO:         n_sectors = %8d \n", disc->tracks[t].n_sectors);
-		cdw_vdm ("## INFO: n_sectors_to_read = %8d \n", disc->tracks[t].n_sectors_to_read);
-		cdw_vdm ("## INFO:              diff = %8d \n", disc->tracks[t].n_sectors - disc->tracks[t].n_sectors_to_read);
-		cdw_vdm ("## INFO:       sector_size = %8d \n", disc->tracks[t].sector_size);
-		cdw_vdm ("## INFO: fs size (sectors) = %8d \n", disc->tracks[t].fs.size);
-		cdw_vdm ("## INFO:            fs type = %d / \"%s\" \n", disc->tracks[t].fs.cdio_fs, cdw_ofs_short_label(disc->tracks[t].fs.cdio_fs));
-		cdw_vdm ("## INFO: track format:      \"%s\"\n", track_format_data[disc->tracks[t].cdw_track_format].cdw_track_format_label);
+		cdw_vdm ("## INFO:      track number = %8d\n", t);
+		cdw_vdm ("## INFO:      first_sector = %8d\n", disc->tracks[t].first_sector);
+		cdw_vdm ("## INFO:       last_sector = %8d\n", disc->tracks[t].last_sector);
+		cdw_vdm ("## INFO:         n_sectors = %8d (%.2f MB)\n", disc->tracks[t].n_sectors,
+			 (disc->tracks[t].n_sectors * disc->tracks[t].sector_size) / (1024.0 * 1024));
+		cdw_vdm ("## INFO: fs size (sectors) = %8d (%.2f MB) \n", disc->tracks[t].fs.size,
+			 (disc->tracks[t].fs.size * disc->tracks[t].sector_size) / (1024.0 * 1024));
+		cdw_vdm ("## INFO: n_sectors_to_read = %8d\n", disc->tracks[t].n_sectors_to_read);
+		cdw_vdm ("## INFO:              diff = %8d\n", disc->tracks[t].n_sectors - disc->tracks[t].n_sectors_to_read);
+		cdw_vdm ("## INFO:       sector_size = %8d\n", disc->tracks[t].sector_size);
+		cdw_vdm ("## INFO:           fs type = %d / \"%s\"\n", disc->tracks[t].fs.cdio_fs, cdw_ofs_short_label(disc->tracks[t].fs.cdio_fs));
+		cdw_vdm ("## INFO:      track format = %d / \"%s\"\n", disc->tracks[t].cdw_track_format, track_format_data[disc->tracks[t].cdw_track_format].cdw_track_format_label);
 		cdw_vdm ("## INFO: ---------------------------------------- \n");
 	}
 
@@ -1831,4 +1878,3 @@ static void cdw_cdio_log_handler(cdio_log_level_t level, const char *message)
 
 	return;
 }
-
