@@ -1,6 +1,6 @@
 /* cdw
  * Copyright (C) 2002 Varkonyi Balazs
- * Copyright (C) 2007 - 2012 Kamil Ignacak
+ * Copyright (C) 2007 - 2014 Kamil Ignacak
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 
@@ -621,7 +621,7 @@ cdw_rv_t cdw_disc_get_meta_info(cdw_disc_t *disc)
 				      program cannot get metadata from disc */
 				   _("Cannot get information about disc."),
 				   CDW_BUTTONS_OK, CDW_COLORS_ERROR);
-		cdw_main_ui_main_window_wrefresh();
+		cdw_main_window_wrefresh();
 
 		return CDW_ERROR;
 	}
@@ -635,19 +635,19 @@ cdw_rv_t cdw_disc_get_meta_info(cdw_disc_t *disc)
 		   supported (this was more true in cdw v. 0.3.91,
 		   situation has improved in 0.3.92). */
 
-		if (global_config.show_dvd_rw_support_warning) {
+		if (global_config.general.show_dvd_rw_support_warning) {
 
 			/* 2TRANS: this is title of dialog window */
 			cdw_buttons_dialog(_("Warning"),
 					   /* 2TRANS: this is message dialog window */
 					   _("This is DVD-RW disc, it is not fully supported by cdw. You may have some problems."),
 					   CDW_BUTTONS_OK, CDW_COLORS_WARNING);
-			cdw_main_ui_main_window_wrefresh();
+			cdw_main_window_wrefresh();
 
 			/* don't annoy user with this message anymore
 			   in current run of cdw; this option is
 			   not saved to configuration file */
-			global_config.show_dvd_rw_support_warning = false;
+			global_config.general.show_dvd_rw_support_warning = false;
 		}
 	}
 
@@ -704,7 +704,7 @@ cdw_rv_t cdw_disc_get_meta_info_with_cdio(cdw_disc_t *disc)
 				      program cannot get metadata from disc */
 				   _("Cannot get basic information about disc."),
 				   CDW_BUTTONS_OK, CDW_COLORS_ERROR);
-		cdw_main_ui_main_window_wrefresh();
+		cdw_main_window_wrefresh();
 		return CDW_ERROR;
 	}
 
@@ -1004,7 +1004,7 @@ cdw_rv_t cdw_disc_resolve(cdw_disc_t *disc)
 		   || t == CDW_DVD_R_SEQ
 		   || t == CDW_DVD_R_RES
 		   || t == CDW_DVD_RP
-		   || (t == CDW_DVD_RP_DL && global_config.support_dvd_rp_dl)) {
+		   || (t == CDW_DVD_RP_DL && global_config.general.support_dvd_rp_dl)) {
 
 		disc->type_erasable = CDW_FALSE;
 		disc->type_writable = CDW_TRUE;
@@ -1132,7 +1132,7 @@ void cdw_disc_resolve_type_label(cdw_disc_t *disc)
 	char *l = disc->type_label;
 
 	if (disc->type == CDW_DVD_RP_DL &&
-	    ! global_config.support_dvd_rp_dl) {
+	    ! global_config.general.support_dvd_rp_dl) {
 
 		strncpy(l, cdw_disc_type_labels[CDW_DISC_TYPE_UNKNOWN], CDW_DISC_TYPE_LABEL_LEN);
 	} else {
@@ -1255,8 +1255,8 @@ void cdw_disc_debug_print_disc(cdw_disc_t *disc)
 	cdw_vdm ("CURRENT DISC:  type erasable = \"%s\"\n", cdw_utils_get_cdw_bool_type_label(disc->type_erasable));
 
 	float coeff = 512.0; /* (n_sectors * 2048) / (1024.0 * 1024.0) = n_sectors / 512.0 */
-	cdw_vdm ("CURRENT DISC CAPACITY:  used = %lld (%.3f MB)\n", disc->capacity.sectors_used, (double) disc->capacity.sectors_used / coeff);
-	//cdw_vdm ("CURRENT DISC CAPACITY: total = %lld (%.3f MB)\n", disc->capacity.sectors_total, (double) disc->capacity.sectors_total / coeff);
+	cdw_vdm ("CURRENT DISC CAPACITY:  used = %lld sectors (%.3f MB)\n", disc->capacity.sectors_used, (double) disc->capacity.sectors_used / coeff);
+	cdw_vdm ("CURRENT DISC CAPACITY: total = %lld sectors (%.3f MB)\n", disc->capacity.sectors_total, (double) disc->capacity.sectors_total / coeff);
 
 	if (disc->state_empty == CDW_TRUE) {
 		return;
@@ -1330,6 +1330,7 @@ void cdw_disc_resolve_capacities(cdw_disc_t *disc)
 		disc->capacity.sectors_used = disc->xorriso_info.sectors_used >= 0 ? disc->xorriso_info.sectors_used : disc->cdio->ofs->n_sectors;
 	} else if (disc->libburn_info.unformatted_size != 0) {
 		cdw_vdm ("INFO: using libburn info\n");
+		/* FIXME: are you sure that this is always 2048? */
 		disc->capacity.sectors_total = disc->libburn_info.unformatted_size / 2048;
 		disc->capacity.sectors_used = 0;
 		if (disc->cdio->ofs->n_sectors > 0) {
@@ -1445,3 +1446,55 @@ track_t cdw_disc_get_number_of_tracks(cdw_disc_t *disc)
 	return disc->cdio->n_tracks;
 }
 
+
+
+
+
+/*
+  Capacity of Blu-ray Standard disc size, XL 4 layer: 128 001 769 472 bytes
+  Capacity of uint32_t type:                            4 294 967 295
+  Capacity of uint64_t type:               18 446 744 073 709 551 615
+
+  \return zero on errors
+  \return total disc capacity (in bytes) on success
+*/
+uint64_t cdw_disc_get_total_capacity_bytes(void)
+{
+	cdw_disc_t *disc = cdw_disc_new();
+	if (!disc) {
+		cdw_vdm ("ERROR: failed to make new disc\n");
+		return 0;
+	}
+
+	cdw_rv_t crv = cdw_disc_get(disc);
+	if (crv != CDW_OK) {
+		cdw_vdm ("ERROR: failed to get disc info\n");
+		cdw_disc_delete(&disc);
+		return 0;
+	}
+
+	cdw_main_window_volume_info_view_update(disc->capacity.sectors_used, disc->capacity.sectors_total, false);
+
+	uint64_t capacity = 0;
+	if (disc->capacity.sectors_total < 0) {
+		cdw_vdm ("ERROR: failed to get sectors total from disc\n");
+		capacity = 0;
+	} else {
+		/* 2048 bytes per sector is a kind of lowest common
+		   denominator. Most (but not all) discs supported by
+		   cdw (CD and DVD discs) will have at least 2048
+		   bytes per sector.
+
+		   FIXME: if you ever decide to support other disc
+		   types, the sector size will may be different (I
+		   haven't checked this).
+
+		   FIXME: this may be true for empty CD discs, but for
+		   CD discs that already have some tracks in different
+		   formats this is not exactly true. */
+		capacity = ((uint64_t) disc->capacity.sectors_total) * 2048;
+	}
+
+	cdw_disc_delete(&disc);
+	return capacity;
+}
