@@ -1,6 +1,6 @@
 /* cdw
  * Copyright (C) 2002 Varkonyi Balazs
- * Copyright (C) 2007 - 2012 Kamil Ignacak
+ * Copyright (C) 2007 - 2014 Kamil Ignacak
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #include <stdlib.h>
@@ -28,7 +28,7 @@
 #include <fcntl.h>
 
 #include "gettext.h"
-#include "cdw_thread.h" /* run_command() */
+#include "cdw_thread.h" /* cdw_thread_run_command() */
 #include "cdw_widgets.h"
 #include "cdw_config.h"
 #include "cdw_config_window.h"
@@ -163,7 +163,7 @@ static void cdw_cdrecord_internal_error_dialog(cdw_id_t id);
 
 
 
-/* used in only one function: cdw_rv_t run_command_cdrecord_write_direct(void);
+/* used in only one function: cdw_rv_t cdw_cdrecord_write_from_files(void);
    I know that it is an awful solution, but it has to stay for now */
 #define CDRECORD_WRITE_DATA_FREE_RESOURCES \
 	/* ANSI C allows free(NULL); */\
@@ -251,7 +251,7 @@ cdw_rv_t cdw_cdrecord_write_from_image(cdw_task_t *task, cdw_disc_t *disc)
 	cdw_vdm ("INFO: final command for writing image to optical disc:\n");
 	cdw_vdm ("INFO: \"%s\"\n", command);
 
-	int rv = run_command(command, task);
+	int rv = cdw_thread_run_command(command, task);
 	free(command);
 	command = (char *) NULL;
 
@@ -270,7 +270,7 @@ cdw_rv_t cdw_cdrecord_write_from_image(cdw_task_t *task, cdw_disc_t *disc)
    \brief Write files selected by user to optical disc
 
    Create command line string (program name + arguments) for writing files
-   to optical disc. Run the command (using run_command()), show a window with
+   to optical disc. Run the command (using cdw_thread_run_command()), show a window with
    process information to the user.
 
    The command line string (when passed to shell) will do the following:
@@ -321,7 +321,7 @@ cdw_rv_t cdw_cdrecord_write_from_files(cdw_task_t *task, cdw_disc_t *disc)
 	   that will be used by program writing to disk - read
 	   cdw_cdrecord_create_command_for_writing() function for explanation */
 	tsize_command = cdw_string_concat("tsize=`", mkisofs_command, " --print-size -quiet`", (char *) NULL);
-	if (tsize_command == CDW_OK) {
+	if (!tsize_command) {
 		cdw_cdrecord_internal_error_dialog(2);
 		CDRECORD_WRITE_DATA_FREE_RESOURCES;
 		cdw_vdm ("ERROR: failed to prepare tsize command string\n");
@@ -371,9 +371,9 @@ cdw_rv_t cdw_cdrecord_write_from_files(cdw_task_t *task, cdw_disc_t *disc)
 	   (program name + options) passed to shell */
 	cdw_logging_write(_("Command for cdrecord: \"%s\"\n"), cdrecord_command);
 	cdw_logging_write("\n\n");
-	/* no need to print "final_command" to log - this is done in run_command() */
+	/* no need to print "final_command" to log - this is done in cdw_thread_run_command() */
 
-	int rv = run_command(final_command, task);
+	int rv = cdw_thread_run_command(final_command, task);
 
 	CDRECORD_WRITE_DATA_FREE_RESOURCES;
 	if (rv == 0) {
@@ -394,7 +394,7 @@ cdw_rv_t cdw_cdrecord_write_from_files(cdw_task_t *task, cdw_disc_t *disc)
 
    This function does the following:
    \li Prepares blanking command
-   \li Calls run_command() to blank disc
+   \li Calls cdw_thread_run_command() to blank disc
    \li If blanking could not be performed, user is informed about this
 
    Media should be checked for "erasability" before calling this function.
@@ -441,7 +441,7 @@ cdw_rv_t cdw_cdrecord_erase_disc(cdw_task_t *task, cdw_disc_t *disc)
 
 	cdw_vdm ("command = \"%s\"\n", command);
 
-	int rv = run_command(command, task);
+	int rv = cdw_thread_run_command(command, task);
 
 	free(command);
 	command = (char *) NULL;
@@ -452,7 +452,7 @@ cdw_rv_t cdw_cdrecord_erase_disc(cdw_task_t *task, cdw_disc_t *disc)
 
 	/* it might occur during blanking that 'this media does not
 	   support blanking, ignoring', and disc->type_erasable was
-	   set to 'MEDIA_ERASABLE_NO' in run_command(); let's inform user
+	   set to 'MEDIA_ERASABLE_NO' in cdw_thread_run_command(); let's inform user
 	   about this sad fact */
 	if (disc->type_erasable == CDW_FALSE) {
 		if (task->erase.erase_mode == CDW_ERASE_MODE_FAST) {
@@ -560,7 +560,7 @@ cdw_rv_t cdw_cdrecord_get_meta(cdw_task_t *task, cdw_disc_t *disc)
 			   it is about getting some meta information from
 			   optical disc */
 			cdw_processwin_display_sub_info(_("Getting ATIP information"));
-			int rv = run_command(command, task);
+			int rv = cdw_thread_run_command(command, task);
 			free(command);
 			command = (char *) NULL;
 			cdw_task_check_tool_status(task);
@@ -586,7 +586,7 @@ cdw_rv_t cdw_cdrecord_get_meta(cdw_task_t *task, cdw_disc_t *disc)
 			   it is about getting some meta information from
 			   optical disc */
 			cdw_processwin_display_sub_info(_("Getting PRCAP information"));
-			int rv = run_command(command, task);
+			int rv = cdw_thread_run_command(command, task);
 			free(command);
 			command = (char *) NULL;
 			cdw_task_check_tool_status(task);
@@ -613,7 +613,7 @@ cdw_rv_t cdw_cdrecord_get_meta(cdw_task_t *task, cdw_disc_t *disc)
 			   it is about getting some meta information from
 			   optical disc */
 			cdw_processwin_display_sub_info(_("Getting TOC information"));
-			int rv = run_command(command, task);
+			int rv = cdw_thread_run_command(command, task);
 			free(command);
 			command = (char *) NULL;
 			cdw_task_check_tool_status(task);
@@ -639,7 +639,7 @@ cdw_rv_t cdw_cdrecord_get_meta(cdw_task_t *task, cdw_disc_t *disc)
 			   it is about getting some meta information from
 			   optical disc */
 			cdw_processwin_display_sub_info(_("Getting MSINFO information"));
-			int rv = run_command(command, task);
+			int rv = cdw_thread_run_command(command, task);
 			free(command);
 			command = (char *) NULL;
 			cdw_task_check_tool_status(task);
@@ -667,7 +667,7 @@ cdw_rv_t cdw_cdrecord_get_meta(cdw_task_t *task, cdw_disc_t *disc)
 
    Go through all supported CDRECORD options and if given option is enabled,
    put its value into one string. Put path to CDRECORD at the beginning of
-   the string. This creates a string that can be passed to run_command().
+   the string. This creates a string that can be passed to cdw_thread_run_command().
 
    \pre \p task->source is set to either OBJ_DATA_FILES or OBJ_ISO_IMAGE.
    These two values identify two valid sources of data that can be
@@ -704,7 +704,7 @@ char *cdw_cdrecord_create_command_for_writing(cdw_task_t *task, cdw_disc_t *disc
 	if (task->id == CDW_TASK_BURN_FROM_FILES) {
 		strcpy(tsize_value, "${tsize}");
 	} else { /* task->id == CDW_TASK_BURN_FROM_IMAGE */
-		long long int fs_size = cdw_fs_get_file_size(task->burn.iso9660_file_fullpath);
+		long long int fs_size = cdw_fs_get_file_size(task->image_file_fullpath);
 		snprintf(tsize_value, TSIZE_LEN + 1, "%lld", fs_size / 2048);
 		cdw_vdm ("INFO: tsize_value string = \"%s\", strlen(tsize_value) = %zd\n", tsize_value, strlen(tsize_value));
 	}
@@ -731,11 +731,11 @@ char *cdw_cdrecord_create_command_for_writing(cdw_task_t *task, cdw_disc_t *disc
 	   chars (not including ending \0); last +1 below is for ending \0 */
 	size_t pad_len_max = 9 + CDW_CDRECORD_OPTIONS_PADSIZE_FIELD_LEN_MAX + 7;
 	char pad_string[pad_len_max + 1];
-	if (task->burn.cdrecord.pad_size > 0) {
+	if (task->burn.cdrecord_pad_size > 0) {
 		snprintf(pad_string, pad_len_max + 1,
-			 " padsize=%ds %s ", task->burn.cdrecord.pad_size, task->burn.cdrecord.pad ? "-pad" : " ");
+			 " padsize=%ds %s ", task->burn.cdrecord_pad_size, task->burn.cdrecord_pad ? "-pad" : " ");
 	} else {
-		snprintf(pad_string, pad_len_max + 1, " %s ", task->burn.cdrecord.pad ? "-pad" : " ");
+		snprintf(pad_string, pad_len_max + 1, " %s ", task->burn.cdrecord_pad ? "-pad" : " ");
 	}
 	cdw_vdm ("pad string is \"%s\", %zd / %zd chars\n", pad_string, strlen(pad_string), pad_len_max);
 
@@ -766,7 +766,7 @@ char *cdw_cdrecord_create_command_for_writing(cdw_task_t *task, cdw_disc_t *disc
 					  strlen(disc_mode) ? disc_mode : " ",
 
 					  task->burn.dummy ? " -dummy " : " ",
-					  task->burn.cdrecord.burnproof ? " driveropts=burnfree " : " ",
+					  task->burn.cdrecord_burnproof ? " driveropts=burnfree " : " ",
 
 					  /* cdrecord man page says: "Values below
 					     2 seconds are not recommended to give
@@ -776,7 +776,7 @@ char *cdw_cdrecord_create_command_for_writing(cdw_task_t *task, cdw_disc_t *disc
 
 					  add_multi ? " -multi " : " ",
 
-					  " ", task->burn.cdrecord.other_cdrecord_options, " ",
+					  " ", task->burn.cdrecord_other_options, " ",
 
 					  pad_string,
 
@@ -792,7 +792,7 @@ char *cdw_cdrecord_create_command_for_writing(cdw_task_t *task, cdw_disc_t *disc
 					     path to iso file may contain spaces, so put
 					     the path in quotes */
 					  read_from_stdin ? " - " : "\"",
-					  read_from_stdin ? "  " : task->burn.iso9660_file_fullpath,
+					  read_from_stdin ? "  " : task->image_file_fullpath,
 					  read_from_stdin ? "  " : "\"",
 
 					  /* last argument passed to concat() must be NULL */
@@ -1042,120 +1042,3 @@ bool cdw_cdrecord_allow_dummy(cdw_disc_t *disc)
 		return false;
 	}
 }
-
-
-
-
-
-/* *** unused code below *** */
-
-#if 0
-
-
-/**
-   \brief Create process writing audio CD; this code is currently not maintained
-
-   \param task - variable describing current task
-
-   \return CDW_OK
- */
-cdw_rv_t run_command_cdrecord_write_audio(cdw_task_t *task)
-{
-	char command[500];
-	cdw_rv_t crv = CDW_OK;
-
-	crv = cdw_config_ui_conditional_volume_label_dialog();
-	bool use_scsi = cdw_config_has_scsi_device();
-	const char *device = use_scsi ? global_config.scsi : cdw_drive_get_drive_fullpath();
-
-	if (crv == CDW_OK) { /* user entered label: empty or non-empty, but continue in both cases */
-		cdw_assert (task->burn.tool.fullpath != (char *) NULL, "ERROR: tool fullpath is NULL\n");
-		sprintf(command, "%s -v speed=%d dev=%s -audio", task->burn.tool.fullpath, task->burn.speed, device);
-		if (global_config.pad) {
-			/* when you go back to maintaining this code, don't
-			   forget to add padsize */
-			strcat(command, " -pad ");
-		}
-		if (task->burn.disc_mode == CDW_DISC_MODE_DAO) {
-			strcat(command, " -dao ");
-		}
-		if (global_config.dummy) {
-			strcat(command, " -dummy ");
-		}
-		if (global_config.burnproof) {
-			strcat(command, " -driveropts=burnproof ");
-		}
-		sprintf(command, "%s %s/*.wav", command, global_config.audiodir);
-		/* 2TRANS: this is dialog window title
-		   (writing audio files to CD) */
-		cdw_processwin_create(_("Write audio"),
-				      /* 2TRANS: this is message in dialog
-					 window: writing audio CD is in
-					 progress */
-				      _("Writing audio..."), true);
-
-		run_command(command, task);
-
-		/* 2TRANS: this is message in dialog window; result of
-		   operation is unknown */
-		cdw_processwin_destroy(_("Writing audio finished"), true);
-
-		/* 2TRANS: this string will be used as title of window
-		   displaying log of operation (of writing audio CD) */
-		after_event(_("Write audio log"), 1);
-	}
-
-	return CDW_OK;
-}
-
-
-
-
-
-/**
-   \brief Create process copying CD disk; this code is currently not maintained
-
-   \param task - variable describing current task
-
-   \return CDW_OK
- */
-cdw_rv_t run_command_cdrecord_copy_disk(cdw_task_t *task)
-{
-	char command[500];
-	int in_fd;
-	bool use_scsi = cdw_config_has_scsi_device();
-	const char *device = use_scsi ? global_config.scsi : cdw_drive_get_drive_fullpath();
-
-	if ((in_fd = open("/dev/cdrom", O_RDONLY)) != -1) {
-		close(in_fd);
-		cdw_assert (task->burn.tool.fullpath != (char *) NULL, "ERROR: tool fullpath is NULL\n");
-		sprintf(command, "%s -v speed=%d dev=%s %s", task->burn.tool.fullpath, task->burn.speed, device, lobal_config.other_cdrecord_options);
-		if (global_config.eject) {
-			strcat(command, " -eject");
-		}
-		if (global_config.dummy) {
-			strcat(command, " -dummy");
-		}
-
-		sprintf(command, "%s -isosize %s", command, global_config.cdrw_device);
-		/* 2TRANS: this is dialog window title */
-		cdw_processwin_create(_("Copy data CD"), (char *) NULL, true);
-
-		run_command(command, task);
-
-		/* 2TRANS: this is message in dialog window:
-		   result of operation (success/failure) unknown */
-		cdw_processwin_destroy(_("Copying data CD finished"), true);
-
-		/* 2TRANS: this string will be used as title of
-		   window displaying log of operation (of copying CD) */
-		after_event(_("Copy data CD log"), 1);
-	}
-
-	return CDW_OK;
-}
-
-
-
-#endif
-
