@@ -1,6 +1,6 @@
 /* cdw
  * Copyright (C) 2002 Varkonyi Balazs
- * Copyright (C) 2007 - 2012 Kamil Ignacak
+ * Copyright (C) 2007 - 2014 Kamil Ignacak
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 
@@ -61,7 +61,7 @@ cdw_rv_t cdw_cdrecord_options_form(cdw_form_t *cdw_form, void *cdw_task, int fir
 
 	int padsize_width = CDW_CDRECORD_OPTIONS_PADSIZE_FIELD_LEN_MAX;
 	char pad_size[CDW_CDRECORD_OPTIONS_PADSIZE_FIELD_LEN_MAX + 1];
-	snprintf(pad_size, (size_t) padsize_width + 1, "%d", task->burn.cdrecord.pad_size);
+	snprintf(pad_size, (size_t) padsize_width + 1, "%d", task->burn.cdrecord_pad_size);
 	int Xs_col = second_col + padsize_width;
 
 	/* the "150" value below is selected after small tests with DVD;
@@ -71,35 +71,37 @@ cdw_rv_t cdw_cdrecord_options_form(cdw_form_t *cdw_form, void *cdw_task, int fir
 	   so it should be a constant defined in some header */
 
 	cdw_form_descr_t descr[] = {
-		/*     type        begin_y   begin_x       n_cols           n_lines  field enum              data1                                       data2 */
+		/* type                      begin_y   begin_x        n_cols    n_lines   field enum                data1                                                data2 */
 
-		{ CDW_WIDGET_CHECKBOX, 1,  first_col + 1,          1,     1,  f_cdrecord_pad_cb,        (void *) NULL,         task->burn.cdrecord.pad ? 1 : 0 },
+		{ CDW_WIDGET_ID_CHECKBOX,          1,  first_col + 1,          1,     1,  f_cdrecord_pad_cb,        (void *) NULL,         task->burn.cdrecord_pad ? 1 : 0 },
 		/* 2TRANS: this is checkbox label in config window; a noun (?); "pad" -> "padding" -> "some bytes added at the end of proper data" */
-		{ CDW_WIDGET_LABEL,    1,  first_col + 4, width_wide,     1,  f_cdrecord_pad_l,         _("Pad"),                                            0 },
+		{ CDW_WIDGET_ID_STATIC_LABEL,      1,  first_col + 4, width_wide,     1,  f_cdrecord_pad_l,         _("Pad"),                                            0 },
 
 		/* 2TRANS: this is checkbox label: keep no longer than original; "Pad" refers to adding empty data at the end of track */
-		{ CDW_WIDGET_LABEL,    2,  first_col,     width_wide,     1,  f_cdrecord_pad_size_l,    _("Pad size (number >= 0, '150' is recommended)"),   0 },
-		{ CDW_WIDGET_INPUT,    3,  second_col,    padsize_width,  1,  f_cdrecord_pad_size_i,    pad_size,                       (size_t) padsize_width },
+		{ CDW_WIDGET_ID_DYNAMIC_LABEL,     2,  first_col,     width_wide,     1,  f_cdrecord_pad_size_l,    _("Pad size (number >= 0, '150' is recommended)"),   0 },
+		{ CDW_WIDGET_ID_SAFE_INPUT_LINE,   3,  second_col,    padsize_width,  1,  f_cdrecord_pad_size_i,    pad_size,                       (size_t) padsize_width },
 		/* padsize, Xs */
 		/* 2TRANS: do not translate */
-		{ CDW_WIDGET_LABEL,    3,  Xs_col,  1,                    1,  f_cdrecord_pad_size_xl,   _("s"),                                              0 },
+		{ CDW_WIDGET_ID_STATIC_LABEL,      3,  Xs_col,  1,                    1,  f_cdrecord_pad_size_xl,   _("s"),                                              0 },
 
-		{ CDW_WIDGET_CHECKBOX, 5,  first_col + 1,          1,     1,  f_cdrecord_burnproof_cb,  (void *) NULL,   task->burn.cdrecord.burnproof ? 1 : 0 },
+		{ CDW_WIDGET_ID_CHECKBOX,          5,  first_col + 1,          1,     1,  f_cdrecord_burnproof_cb,  (void *) NULL,   task->burn.cdrecord_burnproof ? 1 : 0 },
 		/* 2TRANS: this is checkbox label in configuration window; see documentation of cdrecord for definition of "burnproof" */
-		{ CDW_WIDGET_LABEL,    5,  first_col + 4, width_wide,     1,  f_cdrecord_burnproof_l,   _("Burnproof"),                                      0 },
+		{ CDW_WIDGET_ID_STATIC_LABEL,      5,  first_col + 4, width_wide,     1,  f_cdrecord_burnproof_l,   _("Burnproof"),                                      0 },
 
 		/* 2TRANS: this is label of input field in configuration window; the field contains other options passed to cdrecord */
-		{ CDW_WIDGET_LABEL,    6,  first_col,     width_wide,     1,  f_cdrecord_other_l,       _("Other cdrecord options:"),                        0 },
-		{ CDW_WIDGET_INPUT,    7,  first_col,     width_wide - 3, 1,  f_cdrecord_other_i,       task->burn.cdrecord.other_cdrecord_options,          0 },
+		{ CDW_WIDGET_ID_DYNAMIC_LABEL,     6,  first_col,     width_wide,     1,  f_cdrecord_other_l,       _("Other cdrecord options:"),                        0 },
+		{ CDW_WIDGET_ID_SAFE_INPUT_LINE,   7,  first_col,     width_wide - 3, 1,  f_cdrecord_other_i,       task->burn.cdrecord_other_options,                   0 },
 
 		/* guard */
-		{ -1,                  0,  0,           0,              0,  0,                          (void *) NULL,                                       0 }};
+		{ -1,                              0,  0,             0,              0,  0,                        (void *) NULL,                                       0 }};
 
 	cdw_rv_t crv = cdw_form_description_to_fields(descr, cdw_form);
 	if (crv != CDW_OK) {
 		cdw_vdm ("ERROR: failed to convert form description to form\n");
 		return CDW_ERROR;
 	} else {
+		cdw_form_bind_input_and_label(cdw_form, f_cdrecord_pad_size_i, f_cdrecord_pad_size_l);
+		cdw_form_bind_input_and_label(cdw_form, f_cdrecord_other_i, f_cdrecord_other_l);
 		return CDW_OK;
 	}
 }
@@ -108,10 +110,9 @@ cdw_rv_t cdw_cdrecord_options_form(cdw_form_t *cdw_form, void *cdw_task, int fir
 
 
 
-cdw_rv_t cdw_cdrecord_options_validate(cdw_form_t *cdw_form, int *fi)
+cdw_rv_t cdw_cdrecord_options_validate(cdw_task_t *task, int *fi)
 {
-	char *s = cdw_ncurses_get_field_string(*(cdw_form->fields + f_cdrecord_other_i));
-	cdw_rv_t crv = cdw_string_security_parser(s, (char *) NULL);
+	cdw_rv_t crv = cdw_string_security_parser(task->burn.cdrecord_other_options, (char *) NULL);
 	if (crv != CDW_OK) {
 		*fi = f_cdrecord_other_i;
 		return CDW_NO;
@@ -126,15 +127,14 @@ cdw_rv_t cdw_cdrecord_options_validate(cdw_form_t *cdw_form, int *fi)
 
 cdw_rv_t cdw_cdrecord_options_save(cdw_form_t *cdw_form, cdw_task_t *task)
 {
-	task->burn.cdrecord.pad = cdw_form_get_checkbox_state(cdw_form, f_cdrecord_pad_cb);
+	task->burn.cdrecord_pad = cdw_form_get_checkbox_state(cdw_form, f_cdrecord_pad_cb);
 
 	const char *buf = cdw_form_get_string(cdw_form, f_cdrecord_pad_size_i);
-	task->burn.cdrecord.pad_size = atoi(buf);
+	task->burn.cdrecord_pad_size = atoi(buf);
 
-	task->burn.cdrecord.burnproof = cdw_form_get_checkbox_state(cdw_form, f_cdrecord_burnproof_cb);
+	task->burn.cdrecord_burnproof = cdw_form_get_checkbox_state(cdw_form, f_cdrecord_burnproof_cb);
 
-	cdw_string_set(&(task->burn.cdrecord.other_cdrecord_options), cdw_ncurses_get_field_string(*(cdw_form->fields + f_cdrecord_other_i)));
+	cdw_string_set(&(task->burn.cdrecord_other_options), cdw_ncurses_get_field_string(*(cdw_form->fields + f_cdrecord_other_i)));
 
 	return CDW_OK;
 }
-
