@@ -1,6 +1,6 @@
 /* cdw
  * Copyright (C) 2002 Varkonyi Balazs
- * Copyright (C) 2007 - 2012 Kamil Ignacak
+ * Copyright (C) 2007 - 2014 Kamil Ignacak
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #include <stdlib.h>
@@ -38,7 +38,7 @@ cdw_rv_t cdw_digest_run_task(cdw_task_t *task)
 	}
 
 
-	int rv = run_command(command, task);
+	int rv = cdw_thread_run_command(command, task);
 	free(command);
 	command = (char *) NULL;
 
@@ -48,4 +48,3 @@ cdw_rv_t cdw_digest_run_task(cdw_task_t *task)
 		return CDW_ERROR;
 	}
 }
-
