@@ -1,6 +1,6 @@
 /* cdw
  * Copyright (C) 2002 Varkonyi Balazs
- * Copyright (C) 2007 - 2012 Kamil Ignacak
+ * Copyright (C) 2007 - 2014 Kamil Ignacak
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #include <stdlib.h>
@@ -382,7 +382,7 @@ int cdw_dvd_rw_mediainfo_pr_handle_mounted_media(regex_t *regex, regmatch_t *mat
 		thread_task->disc->type = CDW_DVD_ROM;
 
 	} else if (!strcmp(submatch, "DVD+R Double Layer")
-		   && global_config.support_dvd_rp_dl) {
+		   && global_config.general.support_dvd_rp_dl) {
 		thread_task->disc->type = CDW_DVD_RP_DL;
 
 	} else {
