@@ -1,6 +1,6 @@
 /* cdw
  * Copyright (C) 2002 Varkonyi Balazs
- * Copyright (C) 2007 - 2012 Kamil Ignacak
+ * Copyright (C) 2007 - 2014 Kamil Ignacak
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #define _BSD_SOURCE /* strdup() */
@@ -85,6 +85,7 @@
 #define CDW_TOOL_DVD_RW_FORMAT_NAME      "dvd+rw-format"
 #define CDW_TOOL_DVD_RW_MEDIAINFO_NAME   "dvd+rw-mediainfo"
 #define CDW_TOOL_XORRISO_NAME            "xorriso"
+#define CDW_TOOL_MKUDFFS_NAME            "mkudffs"
 #define CDW_TOOL_MD5SUM_NAME             "md5sum"
 #define CDW_TOOL_SHA1SUM_NAME            "sha1sum"
 #define CDW_TOOL_SHA224SUM_NAME          "sha224sum"
@@ -92,6 +93,23 @@
 #define CDW_TOOL_SHA384SUM_NAME          "sha384sum"
 #define CDW_TOOL_SHA512SUM_NAME          "sha512sum"
 
+/* These 7 tools below are helpers for creating UDF image
+   (a.k.a. mkudffs helpers). They are used exclusively for creating
+   UDF image file.
+
+   I don't intend to make it possible to select instances of these
+   tools - when invoking them, I just use hardwired names. But I still
+   need to verify that they are available on user's system. The
+   verification will be performed just like for any other tool: with
+   cdw_which. */
+#define CDW_TOOL_TRUNCATE_NAME           "truncate"
+#define CDW_TOOL_SUDO_NAME               "sudo"
+#define CDW_TOOL_MOUNT_NAME              "mount"
+#define CDW_TOOL_UMOUNT_NAME             "umount"
+#define CDW_TOOL_SYNC_NAME               "sync"
+#define CDW_TOOL_RSYNC_NAME              "rsync"
+
+
 
 
 typedef struct {
@@ -156,6 +174,9 @@ static struct {
 		   mkisofs + xorriso */
 		cdw_ext_tools_handler_config_t iso9660_handlers;
 
+		/* Tools for creating stand alone UDF file. */
+		cdw_ext_tools_handler_config_t udf_handlers;
+
 		/* cdrecord + xorriso */
 		cdw_ext_tools_handler_config_t cd_handlers;
 
@@ -185,6 +206,7 @@ static void cdw_ext_tools_init_cdw_tools(void);
 static void     cdw_ext_tools_build_cd_handlers(void);
 static void     cdw_ext_tools_build_dvd_handlers(void);
 static void     cdw_ext_tools_build_iso9660_handlers(void);
+static void     cdw_ext_tools_build_udf_handlers(void);
 static void     cdw_ext_tools_build_digest_handlers(void);
 static cdw_rv_t cdw_ext_tools_build_tool_config(cdw_id_t tool_id, cdw_ext_tools_tool_config_t *tool_config);
 static void     cdw_ext_tools_build_handlers(cdw_ext_tools_handler_config_t *handlers, cdw_id_clabel_t input_items[], int n_items_max);
@@ -249,6 +271,7 @@ cdw_rv_t cdw_ext_tools_init(void)
 	cdw_ext_tools_build_cd_handlers();
 	cdw_ext_tools_build_dvd_handlers();
 	cdw_ext_tools_build_iso9660_handlers();
+	cdw_ext_tools_build_udf_handlers();
 	cdw_ext_tools_build_digest_handlers();
 
 	cdw_ext_tools_build_tool_config(CDW_TOOL_MKISOFS, &cdw_ext_tools.config.mkisofs);
@@ -298,6 +321,8 @@ void cdw_ext_tools_init_cdw_tools(void)
 	cdw_ext_tools.config.cd_handlers.n_items = 0;
 	cdw_ext_tools.config.iso9660_handlers.current_ind = 0;
 	cdw_ext_tools.config.iso9660_handlers.n_items = 0;
+	cdw_ext_tools.config.udf_handlers.current_ind = 0;
+	cdw_ext_tools.config.udf_handlers.n_items = 0;
 	cdw_ext_tools.config.digest_handlers.current_ind = 0;
 	cdw_ext_tools.config.digest_handlers.n_items = 0;
 
@@ -308,6 +333,8 @@ void cdw_ext_tools_init_cdw_tools(void)
 		cdw_ext_tools.config.cd_handlers.items[t].label = (char *) NULL;
 		cdw_ext_tools.config.iso9660_handlers.items[t].id = CDW_TOOL_NONE;
 		cdw_ext_tools.config.iso9660_handlers.items[t].label = (char *) NULL;
+		cdw_ext_tools.config.udf_handlers.items[t].id = CDW_TOOL_NONE;
+		cdw_ext_tools.config.udf_handlers.items[t].label = (char *) NULL;
 		cdw_ext_tools.config.digest_handlers.items[t].id = CDW_TOOL_NONE;
 		cdw_ext_tools.config.digest_handlers.items[t].label = (char *) NULL;
 	}
@@ -330,6 +357,8 @@ void cdw_ext_tools_init_cdw_tools(void)
 	strcpy(cdw_ext_tools.tools[CDW_TOOL_DVD_RW_FORMAT].name,    CDW_TOOL_DVD_RW_FORMAT_NAME);
 	strcpy(cdw_ext_tools.tools[CDW_TOOL_DVD_RW_MEDIAINFO].name, CDW_TOOL_DVD_RW_MEDIAINFO_NAME);
 	strcpy(cdw_ext_tools.tools[CDW_TOOL_XORRISO].name,   CDW_TOOL_XORRISO_NAME);
+	strcpy(cdw_ext_tools.tools[CDW_TOOL_MKUDFFS].name,   CDW_TOOL_MKUDFFS_NAME);
+
 	strcpy(cdw_ext_tools.tools[CDW_TOOL_MD5SUM].name,    CDW_TOOL_MD5SUM_NAME);
 	strcpy(cdw_ext_tools.tools[CDW_TOOL_SHA1SUM].name,   CDW_TOOL_SHA1SUM_NAME);
 	strcpy(cdw_ext_tools.tools[CDW_TOOL_SHA224SUM].name, CDW_TOOL_SHA224SUM_NAME);
@@ -337,6 +366,13 @@ void cdw_ext_tools_init_cdw_tools(void)
 	strcpy(cdw_ext_tools.tools[CDW_TOOL_SHA384SUM].name, CDW_TOOL_SHA384SUM_NAME);
 	strcpy(cdw_ext_tools.tools[CDW_TOOL_SHA512SUM].name, CDW_TOOL_SHA512SUM_NAME);
 
+	strcpy(cdw_ext_tools.tools[CDW_TOOL_TRUNCATE].name, CDW_TOOL_TRUNCATE_NAME);
+	strcpy(cdw_ext_tools.tools[CDW_TOOL_SUDO].name,     CDW_TOOL_SUDO_NAME);
+	strcpy(cdw_ext_tools.tools[CDW_TOOL_MOUNT].name,    CDW_TOOL_MOUNT_NAME);
+	strcpy(cdw_ext_tools.tools[CDW_TOOL_UMOUNT].name,   CDW_TOOL_UMOUNT_NAME);
+	strcpy(cdw_ext_tools.tools[CDW_TOOL_SYNC].name,     CDW_TOOL_SYNC_NAME);
+	strcpy(cdw_ext_tools.tools[CDW_TOOL_RSYNC].name,    CDW_TOOL_RSYNC_NAME);
+
 	return;
 }
 
@@ -359,6 +395,7 @@ void cdw_ext_tools_find_external_tools(void)
 		   tools[t].name, that is available in paths specified in
 		   environment variable PATH */
 		cdw_dll_t *instances = (cdw_dll_t *) NULL;
+		cdw_vdm ("INFO: looking for tool #%d (%s)\n", t, cdw_ext_tools.tools[t].name);
 		if (!cdw_which(cdw_ext_tools.tools[t].name, &instances)) {
 			cdw_vdm ("WARNING: can't get instances table for tool \"%s\"\n",
 				 cdw_ext_tools.tools[t].name);
@@ -460,6 +497,24 @@ void cdw_ext_tools_debug_print_config(void)
 	cdw_assert (cdw_ext_tools.config.iso9660_handlers.items[i].label != (char *) NULL, "ERROR: label #%d of ISO9660 handler is NULL\n", i);
 	cdw_vdm ("INFO: ISO9660 #%d label = \"%s\"\n", i, cdw_ext_tools.config.iso9660_handlers.items[i].label);
 
+
+	/* UDF handlers aren't mutually exclusive alternatives, they
+	   are a set of tools needed by "create UDF file" recipe. So
+	   don't list "current" tool, because "current" doesn't make
+	   sense in this context. List all tools from the recipe. */
+	for (int j = 0;
+	     j < cdw_ext_tools.config.udf_handlers.n_items;
+	     j++) {
+
+		/* Some tools needed by the recipe may be
+		   missing. Don't assert. */
+#if 0
+		cdw_assert (cdw_ext_tools.config.udf_handlers.items[j].label != (char *) NULL, "ERROR: label #%d of UDF handler is NULL\n", j);
+#endif
+		cdw_vdm ("INFO: UDF tool #%d label = \"%s\"\n", j, cdw_ext_tools.config.udf_handlers.items[j].label);
+	}
+
+
 	i = cdw_ext_tools.config.cd_handlers.current_ind;
 	cdw_assert (cdw_ext_tools.config.cd_handlers.items[i].label != (char *) NULL, "ERROR: label #%d of CD handler is NULL\n", i);
 	cdw_vdm ("INFO: CD handler #%d label = \"%s\"\n", i, cdw_ext_tools.config.cd_handlers.items[i].label);
@@ -662,7 +717,7 @@ void cdw_ext_tools_print_labels(void)
 */
 bool cdw_ext_tools_is_tool_available(cdw_id_t tool_id)
 {
-	cdw_assert (tool_id >= CDW_TOOL_MKISOFS && tool_id <= CDW_TOOL_SHA512SUM,
+	cdw_assert (tool_id >= CDW_TOOL_MKISOFS && tool_id <= CDW_TOOL_RSYNC,
 		    "ERROR: incorrect tool id: %lld\n", tool_id);
 
 	return cdw_ext_tools.tools[tool_id].available;
@@ -859,6 +914,32 @@ void cdw_ext_tools_build_iso9660_handlers(void)
 
 
 
+void cdw_ext_tools_build_udf_handlers(void)
+{
+	/* For now the list includes only a tool that directly handles
+	   UDF file system, although a full recipe for creating UDF
+	   file perhaps includes few more tools.
+
+	   Perhaps the tools should be counted as "UDF handlers" as well.
+
+	   For now I don't intend to support any UDF creators other
+	   than mkudffs, so I won't have to include them in the list
+	   below. So the list may be "a list of all tools needed in
+	   all steps of recipe for creating UDF file" - udf_recipe_tools. */
+
+	/* For now let's just put here the mkudffs, I will add rest of
+	   tools later. */
+
+	cdw_id_clabel_t tool_ids[] = {{ CDW_TOOL_MKUDFFS, CDW_TOOL_MKUDFFS_NAME }};
+	cdw_ext_tools_build_handlers(&(cdw_ext_tools.config.udf_handlers), tool_ids, 1);
+
+	return;
+}
+
+
+
+
+
 const char *clabel_dvd_rw_tools_mkisofs = "dvd+rw-tools (+ mkisofs)";
 const char *clabel_dvd_rw_tools = "dvd+rw-tools";
 
@@ -908,6 +989,41 @@ bool cdw_ext_tools_dvd_rw_tools_available(void)
 
 
 
+bool cdw_ext_tools_iso9660_sa_tool_available(void)
+{
+	if (cdw_ext_tools_is_tool_available(CDW_TOOL_MKISOFS)
+	    || cdw_ext_tools_is_tool_available(CDW_TOOL_XORRISO)) {
+
+		return true;
+	} else {
+		return false;
+	}
+}
+
+
+
+
+
+bool cdw_ext_tools_udf_sa_tools_tools_available(void)
+{
+	if (cdw_ext_tools_is_tool_available(CDW_TOOL_MKUDFFS)
+	    && cdw_ext_tools_is_tool_available(CDW_TOOL_TRUNCATE)
+	    && cdw_ext_tools_is_tool_available(CDW_TOOL_SUDO)
+	    && cdw_ext_tools_is_tool_available(CDW_TOOL_MOUNT)
+	    && cdw_ext_tools_is_tool_available(CDW_TOOL_UMOUNT)
+	    && cdw_ext_tools_is_tool_available(CDW_TOOL_SYNC)
+	    && cdw_ext_tools_is_tool_available(CDW_TOOL_RSYNC)) {
+
+		return true;
+	} else {
+		return false;
+	}
+}
+
+
+
+
+
 bool cdw_ext_tools_config_is_manual(void)
 {
 	return cdw_ext_tools.config.manual_selection;
@@ -1146,6 +1262,17 @@ void cdw_ext_tools_save_configuration(cdw_ext_tools_configuration_t *etc)
 		cdw_ext_tools.config.cd_handlers.current_ind = cdw_dropdown_get_current_item_ind(etc->cd_handlers);
 		cdw_ext_tools.config.dvd_handlers.current_ind = cdw_dropdown_get_current_item_ind(etc->dvd_handlers);
 		cdw_ext_tools.config.iso9660_handlers.current_ind = cdw_dropdown_get_current_item_ind(etc->iso9660);
+
+		/* Is this necessary? The list is not presented in UI,
+		   so it won't be changed by user. */
+		/* I'm commenting this out because valgrind complains
+		   about using uninitialized variable.  etc->udf is
+		   never set, is never changed by user in UI, so I
+		   think I shouldn't use it.  udf_handlers.current_ind
+		   is set only once (elsewhere) and never changed, so
+		   this line is not necessary. */
+		/* cdw_ext_tools.config.udf_handlers.current_ind = cdw_dropdown_get_current_item_ind(etc->udf); */
+
 		cdw_ext_tools.config.digest_handlers.current_ind = cdw_dropdown_get_current_item_ind(etc->digest_handlers);
 
 		cdw_ext_tools.config.mkisofs.current_ind = cdw_dropdown_get_current_item_ind(etc->mkisofs);
@@ -1590,6 +1717,7 @@ bool cdw_ext_tools_set_iso9660_otf_tool_dvd(cdw_disc_t *disc, cdw_id_label_t *to
 
 
 
+/* _sa_ = stand alone */
 bool cdw_ext_tools_set_iso9660_sa_tool(cdw_id_label_t *tool)
 {
 	int impl_ind = 0;
@@ -1600,6 +1728,7 @@ bool cdw_ext_tools_set_iso9660_sa_tool(cdw_id_label_t *tool)
 			return false;
 		}
 		impl_ind = cdw_ext_tools_get_manual_selection_ind(tool->id);
+		cdw_vdm ("INFO: manual selection, tool id = %lld\n", tool->id);
 	} else {
 		if (cdw_ext_tools_is_tool_available(CDW_TOOL_MKISOFS)) {
 			tool->id = CDW_TOOL_MKISOFS;
@@ -1609,6 +1738,7 @@ bool cdw_ext_tools_set_iso9660_sa_tool(cdw_id_label_t *tool)
 			return false;
 		}
 		impl_ind = CDW_EXT_TOOLS_SYSTEM_DEFAULT_INSTANCE_IND;
+		cdw_vdm ("INFO: auto selection, tool id = %lld, impl ind = %d\n", tool->id, impl_ind);
 	}
 
 	cdw_assert (cdw_ext_tools_is_tool_available(tool->id), "ERROR: tool was in dd, but is not available\n");
@@ -1617,6 +1747,7 @@ bool cdw_ext_tools_set_iso9660_sa_tool(cdw_id_label_t *tool)
 		cdw_vdm ("ERROR: fullpath #%d to ISO9660 tool %lld is NULL\n", impl_ind, tool->id);
 		return false;
 	} else {
+		cdw_vdm ("INFO: selected tool %lld / %s\n", tool->id, tool->label);
 		return true;
 	}
 }
@@ -1625,6 +1756,32 @@ bool cdw_ext_tools_set_iso9660_sa_tool(cdw_id_label_t *tool)
 
 
 
+bool cdw_ext_tools_set_udf_sa_tool(cdw_id_label_t *tool)
+{
+	if (cdw_ext_tools_is_tool_available(CDW_TOOL_MKUDFFS)) {
+		tool->id = CDW_TOOL_MKUDFFS;
+	} else {
+		return false;
+	}
+
+	int impl_ind = CDW_EXT_TOOLS_SYSTEM_DEFAULT_INSTANCE_IND;
+	cdw_assert (cdw_ext_tools_is_tool_available(tool->id), "ERROR: tool was in dd, but is not available\n");
+	tool->label = cdw_ext_tools.tools[tool->id].instances[impl_ind];
+	if (!tool->label) {
+		cdw_vdm ("ERROR: fullpath #%d to UDF tool %lld is NULL\n", impl_ind, tool->id);
+		return false;
+	} else {
+		cdw_vdm ("INFO: selected tool %lld / %s\n", tool->id, tool->label);
+		return true;
+	}
+}
+
+
+
+
+
+
+
 bool cdw_ext_tools_set_erase_tool(cdw_disc_t *disc, cdw_id_label_t *tool)
 {
 	int impl_ind = 0;
@@ -1745,42 +1902,23 @@ bool cdw_ext_tools_is_digest_tool(cdw_id_t tool_id)
 
 
 
-/* unused code below */
 
-#if 0
-
-
-
-/* for now it only works for growisofs */
-cdw_rv_t cdw_ext_tools_check_versions(void)
+/**
+   Simple getter, since struct cdw_ext_tools is local in this file.
+*/
+int cdw_ext_tools_get_n_iso9660_handlers(void)
 {
-	int i = 0;
-	char *fullpath = cdw_ext_tools.tools[CDW_TOOL_GROWISOFS].instances[i];
-
-	while (fullpath != (char *) NULL) {
-		char *command = cdw_string_concat(fullpath, " --version", (char *) NULL);
-		if (command == (char *) NULL) {
-			cdw_vdm ("ERROR: failed to create command for fullpath \"%s\"\n", fullpath);
-			return CDW_ERROR;
-		} else {
-			/* need the task only for pipe regexp dispatcher,
-			   and the dispatcher checks for some specific fields,
-			   which we have to set here */
-			cdw_task_t task;
-			task.burn.tool.id = CDW_TOOL_GROWISOFS;
-			task.id = CDW_TASK_BURN_FROM_IMAGE;
-
-			run_command(command, &task);
-			free(command);
-			command = (char *) NULL;
-
-			i++;
-			fullpath = cdw_ext_tools.tools[CDW_TOOL_GROWISOFS].instances[i];
-		}
-	}
-
-	return CDW_OK;
+	return cdw_ext_tools.config.iso9660_handlers.n_items;
 }
 
-#endif
 
+
+
+
+/**
+   Simple getter, since struct cdw_ext_tools is local in this file.
+*/
+int cdw_ext_tools_get_n_udf_handlers(void)
+{
+	return cdw_ext_tools.config.udf_handlers.n_items;
+}
