@@ -1,6 +1,6 @@
 /* cdw
  * Copyright (C) 2002 Varkonyi Balazs
- * Copyright (C) 2007 - 2012 Kamil Ignacak
+ * Copyright (C) 2007 - 2014 Kamil Ignacak
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,12 +14,12 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 /**
    \file growisofs_interface.c
-   \brief Interface to growisofs: building command line calls and calling run_command() to run them
+   \brief Interface to growisofs: building command line calls and calling cdw_thread_run_command() to run them
 
    Fragments from man page:
 
@@ -255,7 +255,7 @@ cdw_rv_t cdw_growisofs_run_task(cdw_task_t *task, cdw_disc_t *disc)
    \brief Call growisofs to write iso image file to DVD disc
 
    Call one function to create command line string, and then call
-   run_command() to execute this string in shell. Create processwin to
+   cdw_thread_run_command() to execute this string in shell. Create processwin to
    show some progress to the user. Finish with some meaningful message
    displayed in processwin.
 
@@ -277,7 +277,7 @@ cdw_rv_t cdw_growisofs_write_from_image(cdw_task_t *task, cdw_disc_t *disc)
 	   preparation to writing, but the writing hasn't started yet */
 	cdw_processwin_display_sub_info(_("Preparing to write. Please wait."));
 
-	int rv = run_command(command, task);
+	int rv = cdw_thread_run_command(command, task);
 
 	free(command);
 	command = (char *) NULL;
@@ -297,7 +297,7 @@ cdw_rv_t cdw_growisofs_write_from_image(cdw_task_t *task, cdw_disc_t *disc)
    \brief Call growisofs to write selected files to DVD disc
 
    Call one function to create command line string, and then call
-   run_command() to execute this string in shell. Create processwin to
+   cdw_thread_run_command() to execute this string in shell. Create processwin to
    show some progress to the user. Finish with some meaningful message
    displayed in processwin.
 
@@ -319,7 +319,7 @@ cdw_rv_t cdw_growisofs_write_from_files(cdw_task_t *task, cdw_disc_t *disc)
 	   preparation to writing, but the writing hasn't started yet */
 	cdw_processwin_display_sub_info(_("Preparing to write. Please wait."));
 
-	int rv = run_command(command, task);
+	int rv = cdw_thread_run_command(command, task);
 
 	free(command);
 	command = (char *) NULL;
@@ -401,14 +401,14 @@ char *cdw_growisofs_create_command_write_from_image(cdw_task_t *task, cdw_disc_t
 				     " -speed=", speed_string, " ",
 				     dao ? " -use-the-force-luke=dao " : " ",
 				     task->burn.dummy ? " -use-the-force-luke=dummy " : " ",
-				     " ", task->burn.growisofs.other_growisofs_options, " ",
+				     " ", task->burn.growisofs_other_options, " ",
 
 				     dvd_compat ? " -dvd-compat " : " ",
 
 				     " -Z ",
 				     /* path to ISO file may contain spaces, so
 					surround the path with quotes */
-				     drive, "=", "\"", task->burn.iso9660_file_fullpath, "\"",
+				     drive, "=", "\"", task->image_file_fullpath, "\"",
 
 				     (char *) NULL);
 
@@ -578,7 +578,7 @@ char *cdw_growisofs_create_command_write_from_files(cdw_task_t *task, cdw_disc_t
 					  task->burn.dummy ? " -use-the-force-luke=dummy " : " ",
 					  " -use-the-force-luke=moi ",
 
-					  " ", task->burn.growisofs.other_growisofs_options, " ",
+					  " ", task->burn.growisofs_other_options, " ",
 
 					  dvd_compat ? " -dvd-compat " : " ",
 
@@ -707,7 +707,7 @@ cdw_rv_t run_command_growisofs_blank_dvd(cdw_task_t *task)
 	   preparation to erasing, but the erasing hasn't started yet */
 	cdw_processwin_display_sub_info(_("Preparing to erase. Please wait."));
 
-	int rv = run_command(command, task);
+	int rv = cdw_thread_run_command(command, task);
 
 	free(command);
 	command = (char *) NULL;
@@ -728,4 +728,3 @@ cdw_rv_t run_command_growisofs_blank_dvd(cdw_task_t *task)
 
 
 #endif
-
