@@ -1,6 +1,6 @@
 /* cdw
  * Copyright (C) 2002 Varkonyi Balazs
- * Copyright (C) 2007 - 2012 Kamil Ignacak
+ * Copyright (C) 2007 - 2014 Kamil Ignacak
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 
@@ -52,20 +52,21 @@ cdw_rv_t cdw_growisofs_options_form(cdw_form_t *cdw_form, void *cdw_task, int fi
 	cdw_form->fields = page_growisofs_fields;
 
 	cdw_form_descr_t descr[] = {
-		/*     type       begin_y  begin_x   n_cols     n_lines  field enum            data1                                       data2 */
+		/* type                      begin_y   begin_x     n_cols    n_lines   field enum            data1                                       data2 */
 
 		/* 2TRANS: this is a label for input field: "Other options passed to growisofs */
-		{ CDW_WIDGET_LABEL,  1,  first_col,  width_wide,     1,  f_growisofs_other_l,  _("Other growisofs options:"),                 0 },
-		{ CDW_WIDGET_INPUT,  2,  first_col,  width_wide - 3, 1,  f_growisofs_other_i,  task->burn.growisofs.other_growisofs_options,  0 },
+		{ CDW_WIDGET_ID_DYNAMIC_LABEL,     1,  first_col,  width_wide,     1,  f_growisofs_other_l,  _("Other growisofs options:"),                 0 },
+		{ CDW_WIDGET_ID_SAFE_INPUT_LINE,   2,  first_col,  width_wide - 3, 1,  f_growisofs_other_i,  task->burn.growisofs_other_options,            0 },
 
 		/* guard */
-		{ -1,                0,  0,          0,              0,  0,                   (void *) NULL,                                  0 }};
+		{ -1,                              0,  0,          0,              0,  0,                    (void *) NULL,                                 0 }};
 
 	cdw_rv_t crv = cdw_form_description_to_fields(descr, cdw_form);
 	if (crv != CDW_OK) {
 		cdw_vdm ("ERROR: failed to convert form description to form\n");
 		return CDW_ERROR;
 	} else {
+		cdw_form_bind_input_and_label(cdw_form, f_growisofs_other_i, f_growisofs_other_l);
 		return CDW_OK;
 	}
 }
@@ -74,10 +75,9 @@ cdw_rv_t cdw_growisofs_options_form(cdw_form_t *cdw_form, void *cdw_task, int fi
 
 
 
-cdw_rv_t cdw_growisofs_options_validate(cdw_form_t *cdw_form, int *fi)
+cdw_rv_t cdw_growisofs_options_validate(cdw_task_t *task, int *fi)
 {
-	char *s = cdw_ncurses_get_field_string(*(cdw_form->fields + f_growisofs_other_i));
-	cdw_rv_t crv = cdw_string_security_parser(s, (char *) NULL);
+	cdw_rv_t crv = cdw_string_security_parser(task->burn.growisofs_other_options, (char *) NULL);
 	if (crv != CDW_OK) {
 		*fi = f_growisofs_other_i;
 		return CDW_NO;
@@ -92,8 +92,7 @@ cdw_rv_t cdw_growisofs_options_validate(cdw_form_t *cdw_form, int *fi)
 
 cdw_rv_t cdw_growisofs_options_save(cdw_form_t *cdw_form, cdw_task_t *task)
 {
-	cdw_string_set(&(task->burn.growisofs.other_growisofs_options), cdw_ncurses_get_field_string(*(cdw_form->fields + f_growisofs_other_i)));
+	cdw_string_set(&(task->burn.growisofs_other_options), cdw_ncurses_get_field_string(*(cdw_form->fields + f_growisofs_other_i)));
 
 	return CDW_OK;
 }
-
