@@ -9,7 +9,7 @@
 
 
 cdw_rv_t cdw_growisofs_options_form(cdw_form_t *cdw_form, void *task, int first_col, int second_col, int width_wide, int width_narrow);
-cdw_rv_t cdw_growisofs_options_validate(cdw_form_t *cdw_form, int *fi);
+cdw_rv_t cdw_growisofs_options_validate(cdw_task_t *task, int *fi);
 cdw_rv_t cdw_growisofs_options_save(cdw_form_t *cdw_form, cdw_task_t *task);
 
 
