@@ -1,6 +1,6 @@
 /* cdw
  * Copyright (C) 2002 Varkonyi Balazs
- * Copyright (C) 2007 - 2012 Kamil Ignacak
+ * Copyright (C) 2007 - 2014 Kamil Ignacak
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 /**
@@ -661,14 +661,14 @@ void cdw_growisofs_pr_handle_writing_data(regex_t *regex, regmatch_t *matches)
 			} else {
 				speed_decimal = atoi(submatch);
 			}
-			cdw_vdm ("INFO: submatch %d, decimal part of speed: \"%s\" -> %d\n", i, submatch, speed_decimal);
+			cdw_sdm ("INFO: submatch %d, decimal part of speed: \"%s\" -> %d\n", i, submatch, speed_decimal);
 		} else if (i == 12) { /* speed - fractional part */
 			if (!strcmp(submatch, "??")) {
 				speed_fract = 0;
 			} else {
 				speed_fract = atoi(submatch);
 			}
-			cdw_vdm ("INFO: submatch %d, fractional part of speed: \"%s\" -> %d\n", i, submatch, speed_fract);
+			cdw_sdm ("INFO: submatch %d, fractional part of speed: \"%s\" -> %d\n", i, submatch, speed_fract);
 		} else if (i == 15) { /* minutes remaining */
 			if (!strcmp(submatch, "??")) {
 				minutes = 99;
@@ -720,7 +720,7 @@ void cdw_growisofs_pr_handle_writing_data(regex_t *regex, regmatch_t *matches)
 		cdw_sdm ("INFO: progress_string = \"%s\"\n", progress_string);
 	}
 
-	cdw_vdm ("INFO: done / total = %f / %f (task: %s)\n", done, total,
+	cdw_sdm ("INFO: done / total = %f / %f (task: %s)\n", done, total,
 		 thread_task->id == CDW_TASK_BURN_FROM_IMAGE ? "burn from image" :
 		 (thread_task->id == CDW_TASK_BURN_FROM_FILES ? "burn from files" : "erase"));
 
@@ -748,7 +748,7 @@ void cdw_growisofs_pr_handle_writing_data(regex_t *regex, regmatch_t *matches)
 	   ETA stands for time left to end of process, %2d is amount of
 	   minutes left, %02d is amount of seconds left */
 	sprintf(eta_string, _("ETA: %2d:%02d"), minutes, seconds);
-	cdw_vdm ("INFO: ETA: minutes = %d, seconds = %d -> string = \"%s\"\n", minutes, seconds, eta_string);
+	cdw_sdm ("INFO: ETA: minutes = %d, seconds = %d -> string = \"%s\"\n", minutes, seconds, eta_string);
 	cdw_processwin_display_eta(eta_string);
 
 	char speed_string[PROCESSWIN_MAX_RTEXT_LEN + 1];
@@ -756,7 +756,7 @@ void cdw_growisofs_pr_handle_writing_data(regex_t *regex, regmatch_t *matches)
 	   "Speed" is writing speed, %d and %d are decimal and fractional
 	   parts of writing speed, e.g. "Speed: 2.5x" */
 	sprintf(speed_string, _("Speed: %d.%dx"), speed_decimal, speed_fract);
-	cdw_vdm ("INFO: speed: decimal = %d, fract = %d -> string = \"%s\"\n",
+	cdw_sdm ("INFO: speed: decimal = %d, fract = %d -> string = \"%s\"\n",
 		 speed_decimal, speed_fract, speed_string);
 	cdw_processwin_display_fifo_and_speed(-1, speed_decimal, speed_fract);
 
