@@ -1,6 +1,6 @@
 /* cdw
  * Copyright (C) 2002 Varkonyi Balazs
- * Copyright (C) 2007 - 2012 Kamil Ignacak
+ * Copyright (C) 2007 - 2014 Kamil Ignacak
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #include <libburn/libburn.h>
@@ -57,6 +57,7 @@ cdw_rv_t cdw_libburn_get_meta_info(cdw_disc_t *disc, const char *drive_path)
 	rv = burn_drive_get_speedlist(drive_infos[0].drive, &speed_list);
 	if (rv != 1) {
 		cdw_vdm ("ERROR: error while getting speedlist\n");
+		burn_drive_info_free(drive_infos);
 		burn_finish();
 		return CDW_ERROR;
 	}
@@ -70,6 +71,8 @@ cdw_rv_t cdw_libburn_get_meta_info(cdw_disc_t *disc, const char *drive_path)
 		speed_factor = 1385; /* 1385 k/s (k = 1000 B); source: libburn.h */
 	} else {
 		cdw_vdm ("ERROR: invalid disc simple type %d\n", disc->cdio->simple_type);
+		burn_drive_info_free(drive_infos);
+		burn_finish();
 		return CDW_ERROR;
 	}
 
@@ -158,5 +161,3 @@ cdw_rv_t cdw_libburn_get_meta_info(cdw_disc_t *disc, const char *drive_path)
 
 	return CDW_OK;
 }
-
-
