@@ -1,6 +1,6 @@
 /* cdw
  * Copyright (C) 2002 Varkonyi Balazs
- * Copyright (C) 2007 - 2012 Kamil Ignacak
+ * Copyright (C) 2007 - 2014 Kamil Ignacak
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #include <stdlib.h>
@@ -436,7 +436,7 @@ void mkisofs_stdout_regexp_destroy(void)
 int cdw_mkisofs_handle_image_creation(regex_t *regex, regmatch_t *matches)
 {
 	/* additional check is to avoid mistake with direct writing */
-	if (thread_task->id != CDW_TASK_CREATE_IMAGE) {
+	if (thread_task->id != CDW_TASK_CREATE_IMAGE_ISO9660) {
 		return 0;
 	}
 
@@ -502,7 +502,7 @@ int cdw_mkisofs_handle_image_creation(regex_t *regex, regmatch_t *matches)
 int cdw_mkisofs_handle_image_creation_100percent(__attribute__((unused)) regex_t *regex, __attribute__((unused)) regmatch_t *matches)
 {
 	/* additional check is to avoid mistake with direct writing */
-	if (thread_task->id != CDW_TASK_CREATE_IMAGE) {
+	if (thread_task->id != CDW_TASK_CREATE_IMAGE_ISO9660) {
 		return 0;
 	}
 
@@ -591,5 +591,3 @@ int cdw_mkisofs_handle_implementation_botch(regex_t *regex, regmatch_t *matches)
 		return 0;
 	}
 }
-
-
