@@ -1,6 +1,6 @@
 /* cdw
  * Copyright (C) 2002 Varkonyi Balazs
- * Copyright (C) 2007 - 2012 Kamil Ignacak
+ * Copyright (C) 2007 - 2014 Kamil Ignacak
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 
@@ -23,9 +23,9 @@
  * \brief Code creating threads and processes used in communication
  *        with external tools
  *
- * Main function in this file is run_command(): its main tasks are:
+ * Main function in this file is cdw_thread_run_command(): its main tasks are:
  * \li creating pairs of sockets for communication with child process
- *     (run_command() calls socketpair())
+ *     (cdw_thread_run_command() calls socketpair())
  * \li creating child process using fork()
  * \li replacing child process with external tool process using exec() call
  *     (this happens in child process)
@@ -33,7 +33,7 @@
  *     child process (this happens in parent process)
  * \li waiting for thread functions to return
  *
- * run_command() hides threads and exec() from rest of project code.
+ * cdw_thread_run_command() hides threads and exec() from rest of project code.
  *
  * Thread functions are read_child_stdout() and read_child_stderr() (and
  * calculate_digest.read_and_write() - see below). They are executed in parent
@@ -72,6 +72,10 @@
 #include <sys/socket.h>
 #include <errno.h>
 
+/* wait() */
+#include <sys/types.h>
+#include <sys/wait.h>
+
 #include "gettext.h"
 #include "cdw_logging.h"
 #include "cdw_regex_dispatch.h"
@@ -121,7 +125,8 @@ static pthread_mutex_t mutex = PTHREAD_MUTEX_INITIALIZER;
 /* two generic thread functions */
 static void *read_child_stdout(void *dummy);
 static void *read_child_stderr(void *dummy);
-static void cdw_thread_set_child_env(void);
+static void  cdw_thread_wait(cdw_task_t *thread_task);
+static void  cdw_thread_set_child_env(void);
 
 #define CDW_THREAD_EVAL_READ(m_char_buf, m_i, m_pipe_buf, m_new_lines, m_f) \
 	cdw_assert (m_f == cdw_stdout || m_f == cdw_stderr, "ERROR: incorrect file %d\n", m_f);	\
@@ -270,18 +275,20 @@ void *read_child_stderr(__attribute__((unused)) void *dummy)
    Function makes 'task' available as 'thread_task' so that thread functions
    (working in parent code) and regexp functions can set task->tool_status.
 
+   TODO: make the function return values of type cdw_rv_t, for consistency.
+
    \param command - name of program (tool) that you want to run + it's arguments
    \param task - variable describing current task
 
    \return 0 on success
    \return -1 on failure
 */
-int run_command(const char *command, cdw_task_t *task)
+int cdw_thread_run_command(const char *command, cdw_task_t *task)
 {
 	thread_task = task;
-	cdw_sdm ("non-masked tool_status = 0x%04x\n", task->tool_status);
+	cdw_sdm ("INFO: non-masked tool_status = 0x%04x\n", task->tool_status);
 
-	cdw_logging_write_separator();
+	//cdw_logging_write_separator();
 
 	time0 = time(NULL);
 	/* 2TRANS: this is time stamp (current time) printed to log file;
@@ -296,7 +303,7 @@ int run_command(const char *command, cdw_task_t *task)
 	cdw_logging_write(_("Full command issued to shell: \"%s\"\n"), command);
 	/* 2TRANS: this is message printed in log file; 'external tools' are
 	   programs like cdrecord or mkisofs */
-	cdw_logging_write(_("Output from external tool(s) follow:\n\n"));
+	cdw_logging_write(_("Output from external tool(s):\n\n"));
 
 	if ((socketpair(AF_UNIX, SOCK_STREAM, 0, stdin_pipe) == 0)
 		    && (socketpair(AF_UNIX, SOCK_STREAM, 0, stdout_pipe) == 0)
@@ -448,19 +455,38 @@ int run_command(const char *command, cdw_task_t *task)
 				cdw_sdm ("INFO: created thread read_child_stdout\n");
 			}
 
-			/* threads are created; now we must wait for them to complete
-			   their job and return (both of them);
-			   when thread functions end we can execute pthread_join()s */
+
+			/* First let the child process exit, then wait
+			   for threads reading from stdout/stderr of
+			   the exited child process. This order seems
+			   to be better: the functions return on
+			   reading EOF, which in turn (if memory
+			   serves me well) is pushed through the pipe
+			   on child process exiting. So first wait for
+			   the child (wait()), and then wait for
+			   threads (pthread_join()). */
+
+
+			/* Perhaps for some external tool we won't be
+			   able to parse its stdout/stderr output. Let's at
+			   least have exit code of the tool. */
+			cdw_thread_wait(thread_task);
+
+
+			/* Threads have been created above. When
+			   thread functions end we can execute
+			   pthread_join()s */
 			pthread_join(thread_2, NULL);
 			pthread_join(thread_1, NULL);
 
-			/* this file descriptor most probably has been
+
+			/* This file descriptor most probably has been
 			   already closed by read/write function (otherwise
 			   child process would still wait for data on open
 			   stdin, so it would still be active, so thread would
-			   be still active and could not have been joined;
+			   be still active and could not have been joined).;
 
-			   but just to be sure: close it again;
+			   But just to be sure: close it again;
 			   closing file equals marking end of input (eof) for
 			   external processes (like md5sum) waiting for more data */
 			close(stdin_pipe[PARENTS_END]);
@@ -481,6 +507,24 @@ int run_command(const char *command, cdw_task_t *task)
 
 
 
+void cdw_thread_wait(cdw_task_t *task)
+{
+	wait(&(task->tool_status.child_exit_status_raw));
+	if (WIFEXITED (task->tool_status.child_exit_status_raw)) {
+		cdw_vdm ("INFO: child process called exit(%d)\n", WEXITSTATUS(task->tool_status.child_exit_status_raw));
+	} else {
+		cdw_vdm ("ERROR: child process terminated by signal %d\n", WTERMSIG (task->tool_status.child_exit_status_raw));
+	}
+
+	task->tool_status.child_exit_status = WEXITSTATUS(task->tool_status.child_exit_status_raw);
+
+	return;
+}
+
+
+
+
+
 /* this function modifies child process' environment, which is a "throw-away"
    environment - no need to remember initial state of environment in order
    to restore it later */
