@@ -11,7 +11,7 @@
 
 
 
-int run_command(const char *command, cdw_task_t *task);
+int      cdw_thread_run_command(const char *command, cdw_task_t *task);
 cdw_rv_t cdw_thread_send_key_to_child_process(int key);
 
 #endif /* #ifndef H_CDW_THREAD */
