@@ -1,6 +1,6 @@
 /* cdw
  * Copyright (C) 2002 Varkonyi Balazs
- * Copyright (C) 2007 - 2012 Kamil Ignacak
+ * Copyright (C) 2007 - 2014 Kamil Ignacak
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 /**
@@ -23,7 +23,7 @@
    \brief Functions creating calls to xorriso and calling xorriso
 
    Functions for creating xorriso command line strings, creating string
-   with xorriso parameters, and for calling run_command()
+   with xorriso parameters, and for calling cdw_thread_run_command()
    with prepared command line string.
 */
 
@@ -52,7 +52,7 @@ static char *cdw_xorriso_create_command_media_info(cdw_task_t *task);
 static char *cdw_xorriso_create_meta_information_string(cdw_task_t *task);
 static char *cdw_xorriso_create_command_create_iso_fs(cdw_task_t *task);
 static char *cdw_xorriso_create_command_burn_from_files(cdw_task_t *task, cdw_disc_t *disc);
-static char *cdw_xorriso_create_command_burn_from_image(cdw_task_t *task);
+static char *cdw_xorriso_create_command_burn_from_image(cdw_task_t *task, cdw_disc_t *disc);
 static char *cdw_xorriso_create_command_erase(cdw_task_t *task, cdw_disc_t *disc);
 static bool  cdw_xorriso_close_disc(cdw_task_t *task);
 
@@ -76,12 +76,12 @@ static bool  cdw_xorriso_close_disc(cdw_task_t *task);
 cdw_rv_t cdw_xorriso_run_task(cdw_task_t *task, cdw_disc_t *disc)
 {
 	char *command = (char *) NULL;
-	if (task->id == CDW_TASK_CREATE_IMAGE) {
+	if (task->id == CDW_TASK_CREATE_IMAGE_ISO9660) {
 		command = cdw_xorriso_create_command_create_image(task);
 	} else if (task->id == CDW_TASK_BURN_FROM_FILES) {
 		command = cdw_xorriso_create_command_burn_from_files(task, disc);
 	} else if (task->id == CDW_TASK_BURN_FROM_IMAGE) {
-		command = cdw_xorriso_create_command_burn_from_image(task);
+		command = cdw_xorriso_create_command_burn_from_image(task, disc);
 	} else if (task->id == CDW_TASK_MEDIA_INFO) {
 		const char *drive_path = cdw_drive_get_drive_fullpath();
 		cdw_rv_t crv = cdw_libburn_get_meta_info(disc, drive_path);
@@ -96,11 +96,8 @@ cdw_rv_t cdw_xorriso_run_task(cdw_task_t *task, cdw_disc_t *disc)
 		cdw_assert (0, "ERROR: incorrect task id %lld\n", task->id);
 	}
 
-	if (command == (char *) NULL) {
-		cdw_vdm ("ERROR: failed to create xorriso command string\n");
-		return CDW_ERROR;
-	} else {
-		int rv = run_command(command, task);
+	if (command) {
+		int rv = cdw_thread_run_command(command, task);
 		free(command);
 		command = (char *) NULL;
 
@@ -109,6 +106,9 @@ cdw_rv_t cdw_xorriso_run_task(cdw_task_t *task, cdw_disc_t *disc)
 		} else {
 			return CDW_ERROR;
 		}
+	} else {
+		cdw_vdm ("ERROR: failed to create xorriso command string\n");
+		return CDW_ERROR;
 	}
 }
 
@@ -118,20 +118,19 @@ cdw_rv_t cdw_xorriso_run_task(cdw_task_t *task, cdw_disc_t *disc)
 
 char *cdw_xorriso_create_command_create_image(cdw_task_t *task)
 {
-	cdw_assert (task->id == CDW_TASK_CREATE_IMAGE,
+	cdw_assert (task->id == CDW_TASK_CREATE_IMAGE_ISO9660,
 		    "ERROR: incorrect task id: %lld\n", task->id);
 	cdw_assert (task->create_image.tool.id == CDW_TOOL_XORRISO,
 		    "ERROR: incorrect tool id: %lld\n", task->create_image.tool.id);
-	cdw_assert (task->create_image.tool.label != (char *) NULL,
-		    "ERROR: tool fullpath is NULL\n");
+	cdw_assert (task->create_image.tool.label, "ERROR: tool fullpath is NULL\n");
 
 	char *fs_command = cdw_xorriso_create_command_create_iso_fs(task);
-	if (fs_command == (char *) NULL) {
+	if (!fs_command) {
 		cdw_vdm ("ERROR: failed to create string with IS9660 parameters\n");
 		return (char *) NULL;
 	}
 	char *command = cdw_string_concat(task->create_image.tool.label,
-					  " -outdev ", task->create_image.iso9660_file_fullpath, " ",
+					  " -outdev ", task->image_file_fullpath, " ",
 					  fs_command,
 					  " -blank fast ", /* to start writing to image from scratch */
 
@@ -141,12 +140,12 @@ char *cdw_xorriso_create_command_create_image(cdw_task_t *task)
 	free(fs_command);
 	fs_command = (char *) NULL;
 
-	if (command == (char *) NULL) {
-		cdw_vdm ("ERROR: failed to create xorriso command string\n");
-		return (char *) NULL;
-	} else {
+	if (command) {
 		cdw_vdm ("INFO: xorriso command for creating ISO9660 image: \"%s\"\n", command);
 		return command;
+	} else {
+		cdw_vdm ("ERROR: failed to create xorriso command string\n");
+		return (char *) NULL;
 	}
 }
 
@@ -166,14 +165,13 @@ char *cdw_xorriso_create_command_burn_from_files(cdw_task_t *task, cdw_disc_t *d
 		    "ERROR: tool fullpath is NULL\n");
 
 	char *fs_command = cdw_xorriso_create_command_create_iso_fs(task);
-	if (fs_command == (char *) NULL) {
+	if (!fs_command) {
 		cdw_vdm ("ERROR: failed to create string with IS9660 parameters\n");
 		return (char *) NULL;
 	}
 
 	const char *device_fullpath = cdw_drive_get_drive_fullpath();
-	cdw_assert (device_fullpath != (char *) NULL,
-		    "ERROR: \"device fullpath\" is NULL\n");
+	cdw_assert (device_fullpath, "ERROR: \"device fullpath\" is NULL\n");
 
 	bool close = cdw_xorriso_close_disc(task);
 	char speed_string[5 + 1];
@@ -182,10 +180,10 @@ char *cdw_xorriso_create_command_burn_from_files(cdw_task_t *task, cdw_disc_t *d
 	char *command = cdw_string_concat(task->burn.tool.label,
 					  " -dev ", device_fullpath,
 					  " -speed ", speed_string,
-					  fs_command,
+					  fs_command, /* ISO9660 main options + ISO9660 meta data options. */
 
 					  " ", task->burn.dummy ? " -dummy on " : " ",
-					  " ", task->burn.xorriso.other_xorriso_burn_options == (char *) NULL ? " " : task->burn.xorriso.other_xorriso_burn_options, " ",
+					  " ", task->burn.xorriso_burn_other_options ? task->burn.xorriso_burn_other_options : " ", " ",
 
 					  close ? " -close on " : " -close off ",
 
@@ -195,12 +193,12 @@ char *cdw_xorriso_create_command_burn_from_files(cdw_task_t *task, cdw_disc_t *d
 	free(fs_command);
 	fs_command = (char *) NULL;
 
-	if (command == (char *) NULL) {
-		cdw_vdm ("ERROR: failed to create xorriso command string\n");
-		return (char *) NULL;
-	} else {
+	if (command) {
 		cdw_vdm ("INFO: xorriso command for burning from files: \"%s\"\n", command);
 		return command;
+	} else {
+		cdw_vdm ("ERROR: failed to create xorriso command string\n");
+		return (char *) NULL;
 	}
 }
 
@@ -209,7 +207,7 @@ char *cdw_xorriso_create_command_burn_from_files(cdw_task_t *task, cdw_disc_t *d
 
 
 /* xorriso -as cdrecord -vv -dev=/dev/scd0 /tmp/image.iso */
-char *cdw_xorriso_create_command_burn_from_image(cdw_task_t *task)
+char *cdw_xorriso_create_command_burn_from_image(cdw_task_t *task, cdw_disc_t *disc)
 {
 	cdw_assert (task->id == CDW_TASK_BURN_FROM_IMAGE,
 		    "ERROR: incorrect task id: %lld\n", task->id);
@@ -217,15 +215,13 @@ char *cdw_xorriso_create_command_burn_from_image(cdw_task_t *task)
 		    "ERROR: session mode is not set properly\n");
 	cdw_assert (task->burn.tool.id == CDW_TOOL_XORRISO,
 		    "ERROR: incorrect tool id: %lld\n", task->burn.tool.id);
-	cdw_assert (task->burn.tool.label != (char *) NULL,
-		    "ERROR: tool fullpath is NULL\n");
+	cdw_assert (task->burn.tool.label, "ERROR: tool fullpath is NULL\n");
 
 	const char *device_fullpath = cdw_drive_get_drive_fullpath();
-	cdw_assert (device_fullpath != (char *) NULL,
-		    "ERROR: \"device fullpath\" is NULL\n");
+	cdw_assert (device_fullpath, "ERROR: \"device fullpath\" is NULL\n");
 
 	char speed_string[5 + 1];
-	snprintf(speed_string, 5 + 1, "%lld ", task->erase.speed_id);
+	snprintf(speed_string, 5 + 1, "%lld%s ", task->burn.speed_id, disc->cdio->simple_type == CDW_DISC_SIMPLE_TYPE_CD ? "c" : "d");
 
 	bool close = cdw_xorriso_close_disc(task);
 
@@ -237,21 +233,22 @@ char *cdw_xorriso_create_command_burn_from_image(cdw_task_t *task)
 					     xorriso's dummy option */
 					  " ", task->burn.dummy ? " -dummy " : " ",
 					  " speed=", speed_string,
-					  task->burn.iso9660_file_fullpath,
+					  task->image_file_fullpath,
 
 					  " -- ",
 
-					  " ", task->burn.xorriso.other_xorriso_burn_options == (char *) NULL ? " " : task->burn.xorriso.other_xorriso_burn_options, " ",
+					  /* TODO: where is "dummy" option? Answer: look few lines up, you silly. */
+					  " ", task->burn.xorriso_burn_other_options ? task->burn.xorriso_burn_other_options : " ", " ",
 
 					  close ? " -close on " : " -close off ",
 					  (char *) NULL);
 
-	if (command == (char *) NULL) {
-		cdw_vdm ("ERROR: failed to create xorriso command string\n");
-		return (char *) NULL;
-	} else {
+	if (command) {
 		cdw_vdm ("INFO: xorriso command for burning from image: \"%s\"\n", command);
 		return command;
+	} else {
+		cdw_vdm ("ERROR: failed to create xorriso command string\n");
+		return (char *) NULL;
 	}
 }
 
@@ -261,43 +258,40 @@ char *cdw_xorriso_create_command_burn_from_image(cdw_task_t *task)
 
 char *cdw_xorriso_create_command_create_iso_fs(cdw_task_t *task)
 {
-	cdw_assert (task->id == CDW_TASK_CREATE_IMAGE
+	cdw_assert (task->id == CDW_TASK_CREATE_IMAGE_ISO9660
 		    || task->id == CDW_TASK_BURN_FROM_FILES,
 		    "ERROR: incorrect task id: %lld\n", task->id);
 	cdw_assert (task->create_image.tool.id == CDW_TOOL_XORRISO,
 		    "ERROR: incorrect tool id: %lld\n", task->create_image.tool.id);
-	const char *graftpoints_fullpath = cdw_graftpoints_get_fullpath();
-	cdw_assert (graftpoints_fullpath != (char *) NULL,
-		    "ERROR: graftpoints fullpath is NULL\n");
 
-	bool useful_rock_ridge = task->create_image.rock_ridge == CDW_ISO9660_RR_USEFUL ? true : false;
+	const char *graftpoints_fullpath = cdw_graftpoints_get_fullpath();
+	cdw_assert (graftpoints_fullpath, "ERROR: graftpoints fullpath is NULL\n");
+
+	bool useful_rr = task->create_image.iso9660.rock_ridge == CDW_ISO9660_RR_USEFUL;
 	char *meta_information = cdw_xorriso_create_meta_information_string(task);
 
-	char *command = cdw_string_concat(task->create_image.joliet_information ? " -joliet on " : " -joliet off ",
-					  task->create_image.follow_symlinks ? " -follow link " : "",
+	char *command = cdw_string_concat(task->create_image.iso9660.joliet_information ? " -joliet on " : " -joliet off ",
+					  task->create_image.iso9660.follow_symlinks ? " -follow link " : "",
 					  " -pathspecs on ",
 
-					  task->create_image.pad ? " -padding 300k " : " -padding 0 ",
+					  task->create_image.iso9660.pad ? " -padding 300k " : " -padding 0 ",
 
 
 					  " -path_list ", graftpoints_fullpath, " ",
 					  meta_information ? meta_information : "", /* already surrounded by spaces */
-					  " ", task->create_image.xorriso.other_xorriso_iso_options == (char *) NULL ? " " : task->create_image.xorriso.other_xorriso_iso_options, " ",
-					  useful_rock_ridge ? " -find / -true -exec mkisofs_r -- " : "",
+					  " ", task->create_image.iso9660.xorriso_iso_other_options ? task->create_image.iso9660.xorriso_iso_other_options : " ", " ",
+					  useful_rr ? " -find / -true -exec mkisofs_r -- " : "",
 
 					  (char *) NULL);
 
-	if (meta_information) {
-		free(meta_information);
-		meta_information = (char *) NULL;
-	}
+	cdw_string_delete(&meta_information);
 
-	if (command == (char *) NULL) {
-		cdw_vdm ("ERROR: failed to create xorriso command string for ISO9660 fs\n");
-		return (char *) NULL;
-	} else {
+	if (command) {
 		cdw_vdm ("INFO: xorriso command string for ISO9660 fs: \"%s\"\n", command);
 		return command;
+	} else {
+		cdw_vdm ("ERROR: failed to create xorriso command string for ISO9660 fs\n");
+		return (char *) NULL;
 	}
 }
 
@@ -307,43 +301,31 @@ char *cdw_xorriso_create_command_create_iso_fs(cdw_task_t *task)
 
 char *cdw_xorriso_create_meta_information_string(cdw_task_t *task)
 {
-	/* there will always be a volume ID, either from
-	   config file, or from wizard's form field */
-	size_t volume_id = strlen(task->create_image.volume_id);
+	/* This data can be edited in main window of "burn from files"
+	   wizard or "crate image" wizard. */
+	size_t volume_id = strlen(task->create_image.iso9660.volume_id);
 
-	size_t publisher = 0;
-	size_t system_id = 0;
-	size_t volume_set_id = 0;
-
-	if (task->id == CDW_TASK_BURN_FROM_FILES) {
-		/* this is to avoid adding (possibly outdated/invalid) meta
-		   information; the information may come from previous
-		   'create image' task, but now it may be invalid for
-		   purposes of 'burn from files' task;
-		   TODO: this should be fixed by adding 'meta' tab to
-		   configuration panel in write wizard */
-		;
-	} else {
-		publisher = strlen(task->create_image.publisher);
-		system_id = strlen(task->create_image.system_id);
-		volume_set_id = strlen(task->create_image.volume_set_id);
-	}
+	/* This data can be edited in "meta data" page of "Options
+	   window" in "create image" or "burn from files" wizard. */
+	size_t publisher     = strlen(task->create_image.iso9660.publisher);
+	size_t system_id     = strlen(task->create_image.iso9660.system_id);
+	size_t volume_set_id = strlen(task->create_image.iso9660.volume_set_id);
 
 	char *s = cdw_string_concat(" ",
 				    volume_id ? " -volid \"" : "",
-				    volume_id ? task->create_image.volume_id : "",
+				    volume_id ? task->create_image.iso9660.volume_id : "",
 				    volume_id ? "\" " : "",
 
 				    publisher ? " -publisher \"" : " ",
-				    publisher ? task->create_image.publisher : "",
+				    publisher ? task->create_image.iso9660.publisher : "",
 				    publisher ? "\" " : "",
 
 				    system_id ? " -system_id \"" : "",
-				    system_id ? task->create_image.system_id : "",
+				    system_id ? task->create_image.iso9660.system_id : "",
 				    system_id ? "\" " : "",
 
 				    volume_set_id ? " -volset_id \"" : "",
-				    volume_set_id ? task->create_image.volume_set_id : "",
+				    volume_set_id ? task->create_image.iso9660.volume_set_id : "",
 				    volume_set_id ? "\" " : "",
 
 				    " ", (char *) NULL);
@@ -358,24 +340,22 @@ char *cdw_xorriso_create_meta_information_string(cdw_task_t *task)
 
 char *cdw_xorriso_create_command_media_info(cdw_task_t *task)
 {
-	cdw_assert (task->media_info.tool.label != (char *) NULL,
-		    "ERROR: tool fullpath is NULL\n");
+	cdw_assert (task->media_info.tool.label, "ERROR: tool fullpath is NULL\n");
 
 	const char *device = cdw_drive_get_drive_fullpath();
-	cdw_assert (device != (char *) NULL,
-		    "ERROR: \"device\" fullpath is NULL\n");
+	cdw_assert (device, "ERROR: \"device\" fullpath is NULL\n");
 
 	char *command = cdw_string_concat(task->media_info.tool.label,
 					  " -indev ",
 					  device, " -toc ",
 					  (char *) NULL);
 
-	if (command == (char *) NULL) {
-		cdw_vdm ("ERROR: failed to create xorriso command string for media info\n");
-		return (char *) NULL;
-	} else {
+	if (command) {
 		cdw_vdm ("INFO: xorriso command string for media info: \"%s\"\n", command);
 		return command;
+	} else {
+		cdw_vdm ("ERROR: failed to create xorriso command string for media info\n");
+		return (char *) NULL;
 	}
 }
 
@@ -385,12 +365,10 @@ char *cdw_xorriso_create_command_media_info(cdw_task_t *task)
 
 char *cdw_xorriso_create_command_erase(cdw_task_t *task, cdw_disc_t *disc)
 {
-	cdw_assert (task->erase.tool.label != (char *) NULL,
-		    "ERROR: \"erase\" tool fullpath is NULL\n");
+	cdw_assert (task->erase.tool.label, "ERROR: \"erase\" tool fullpath is NULL\n");
 
 	const char *device = cdw_drive_get_drive_fullpath();
-	cdw_assert (device != (char *) NULL,
-		    "ERROR: \"device\" fullpath is NULL\n");
+	cdw_assert (device, "ERROR: \"device\" fullpath is NULL\n");
 
 	char blank_mode[30 + 1];
 	if (disc->type == CDW_CD_RW) {
@@ -403,18 +381,22 @@ char *cdw_xorriso_create_command_erase(cdw_task_t *task, cdw_disc_t *disc)
 		cdw_assert (0, "ERROR: xorriso can't work with media type %d\n", disc->type);
 	}
 
-	char *command = cdw_string_concat(task->erase.tool.label,
-					  " -dev ",  device,
-					  blank_mode,
+	char speed_string[5 + 1];
+	snprintf(speed_string, 5 + 1, "%lld%s ", task->erase.speed_id, disc->cdio->simple_type == CDW_DISC_SIMPLE_TYPE_CD ? "c" : "d");
 
+
+	char *command = cdw_string_concat(task->erase.tool.label,
+					  " -dev ",  device, " ",
+					  blank_mode,
+					  " -speed ", speed_string, " ",
 					  (char *) NULL);
 
-	if (command == (char *) NULL) {
-		cdw_vdm ("ERROR: failed to create xorriso command string for erasing\n");
-		return (char *) NULL;
-	} else {
+	if (command) {
 		cdw_vdm ("INFO: xorriso command string for erasing: \"%s\"\n", command);
 		return command;
+	} else {
+		cdw_vdm ("ERROR: failed to create xorriso command string for erasing\n");
+		return (char *) NULL;
 	}
 }
 
@@ -489,5 +471,3 @@ bool cdw_xorriso_allow_dummy(__attribute__((unused)) cdw_disc_t *disc)
 {
 	return true;
 }
-
-
