@@ -1,6 +1,6 @@
 /* cdw
  * Copyright (C) 2002 Varkonyi Balazs
- * Copyright (C) 2007 - 2012 Kamil Ignacak
+ * Copyright (C) 2007 - 2014 Kamil Ignacak
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #include <stdio.h>
@@ -35,6 +35,7 @@
 #include "cdw_drive.h"
 #include "cdw_utils.h"
 #include "cdw_logging.h"
+#include "cdw_string.h"
 
 extern char stdout_pipe_buffer[PIPE_BUFFER_SIZE + 1];
 extern char stderr_pipe_buffer[PIPE_BUFFER_SIZE + 1];
@@ -42,7 +43,6 @@ extern char stderr_pipe_buffer[PIPE_BUFFER_SIZE + 1];
 /* time captured at the beginning of process */
 extern time_t time0;
 
-extern cdw_config_t global_config;
 extern cdw_task_t *thread_task;
 
 
@@ -179,7 +179,7 @@ static cdw_regex_t stderr_regex[] = {
 	  (regex_t *) NULL, (regmatch_t *) NULL, REG_EXTENDED,
 	  cdw_xorriso_handle_simulation_not_supported },
 
-	{ "simulation not supported", 1008,
+	{ "exceeds free space on media", 1008,
 	  /* "xorriso : FAILURE : Image size 1262877s exceeds free space on media 1217680s"
 	     not enough free space on disc to write selected files
 	     (this should work for burning image as well) */
@@ -207,6 +207,12 @@ static cdw_regex_t stderr_regex[] = {
 	  (regex_t *) NULL, (regmatch_t *) NULL, REG_EXTENDED,
 	  cdw_xorriso_handle_not_a_known_option },
 
+	{ "FAILURE : Not a known command", 1011,
+	  /* Unknown option passed to xorriso */
+	  "FAILURE : Not a known command: (.+)",
+	  (regex_t *) NULL, (regmatch_t *) NULL, REG_EXTENDED,
+	  cdw_xorriso_handle_not_a_known_option },
+
 
 	{ "table guard", -1,
 	  /* guard: debug_id = -1 */
@@ -429,7 +435,7 @@ int cdw_xorriso_handle_media_current(regex_t *regex, regmatch_t *matches)
 
 int cdw_xorriso_handle_media_status(regex_t *regex, regmatch_t *matches)
 {
-	if (thread_task->id == CDW_TASK_CREATE_IMAGE) {
+	if (thread_task->id == CDW_TASK_CREATE_IMAGE_ISO9660) {
 		/* xorriso output for ISO files (no disc):
 		   "Drive current: -outdev '/tmp/image.iso'
 		   Media current: stdio file, overwriteable
@@ -903,9 +909,11 @@ int cdw_xorriso_handle_cannot_read_iso_image_tree(__attribute__((unused)) regex_
 
 int cdw_xorriso_handle_not_a_known_option(regex_t *regex, regmatch_t *matches)
 {
-	/* regexp for catching unknown option
+	/* regexp for catching unknown option/command
 	                                    1
-	   "FAILURE : Not a known option: (.+)" */
+	   "FAILURE : Not a known option: (.+)"
+           "FAILURE : Not a known command: (.+)"
+	*/
 	cdw_regex_assert_subex_number(regex->re_nsub, 1);
 
 	char submatch[PIPE_BUFFER_SIZE];
