@@ -1,6 +1,6 @@
 /* cdw
  * Copyright (C) 2002 Varkonyi Balazs
- * Copyright (C) 2007 - 2012 Kamil Ignacak
+ * Copyright (C) 2007 - 2014 Kamil Ignacak
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 
@@ -33,6 +33,23 @@
 #include "cdw_form.h"
 #include "cdw_logging.h"
 
+/*
+  Code in this file operates on only three ISO9660 meta-data fields:
+  - publisher
+  - volume set id
+  - system id
+
+  These three fields are displayed in "Meta data" tab in wizard
+  options ("create image" wizard and "burn from files" wizard).
+
+  There is also a fourth ISO9660 meta-data field: "volume id", but it
+  is displayed in main window of wizard, so it is handled directly by
+  wizard code.
+
+  Notice that cdw_mkisofsrc handles more ISO9660 meta-data fields than
+  cdw_xorrisorc.
+*/
+
 
 /* the value must be larger than any of CDW_ISO9660_*_LEN values
    defined in optical_file_systems/cdw_iso9660.h */
@@ -48,7 +65,6 @@ static cdw_form_text_maker_t text_makers[] = {
 	cdw_xorrisorc_top_message,
 };
 
-static cdw_task_t *local_task = (cdw_task_t *) NULL;
 
 
 
@@ -65,7 +81,7 @@ enum {
 
 
 
-static FIELD *xorrisorc_fields[CDW_XORRISORC_N_FIELDS + 1]; /* +1 for last field == NULL */
+static FIELD *xorrisorc_fields[CDW_XORRISO_ISO_META_OPTIONS_N_FIELDS + 1]; /* +1 for last field == NULL */
 
 
 /**
@@ -74,40 +90,43 @@ static FIELD *xorrisorc_fields[CDW_XORRISORC_N_FIELDS + 1]; /* +1 for last field
    \return CDW_OK when all fields were created (probably) without problems
    \return CDW_GEN_ERROR if one of fields was created incorrectly
 */
-cdw_rv_t cdw_xorrisorc_form(cdw_form_t *cdw_form, void *cdw_task, int first_col, __attribute__((unused)) int second_col, int width_wide, __attribute__((unused)) int width_narrow)
+cdw_rv_t cdw_xorrisorc_options_form(cdw_form_t *cdw_form, __attribute__((unused)) void *cdw_iso, int first_col, __attribute__((unused)) int second_col, int width_wide, __attribute__((unused)) int width_narrow)
 {
-	cdw_task_t *task = (cdw_task_t *) cdw_task;
-	local_task = task;
 	cdw_form->fields = xorrisorc_fields;
 
 	cdw_form_descr_t descr[] = {
-		/*     type      begin_y  begin_x       n_cols          n_lines  field enum                    data1                               data2 */
+		/*     type                   begin_y   begin_x     n_cols           n_lines  field enum                     data1                               data2 */
 
-		{ CDW_WIDGET_TEXT,    1,  1,          width_wide + 2,        7,  f_xorrisorc_top_message_l,    text_makers,                            0 },
+		{ CDW_WIDGET_ID_TEXT,               1,  1,          width_wide + 2,        7,  f_xorrisorc_top_message_l,    text_makers,                            0 },
 		/* 2TRANS: this is button label; a verb: read data from config file */
-		{ CDW_WIDGET_BUTTON, 10,  1,          1,                     1,  f_xorrisorc_top_message_b,    _("Read"),              CDW_COLORS_DIALOG },
+		{ CDW_WIDGET_ID_BUTTON,            10,  1,          1,                     1,  f_xorrisorc_top_message_b,    _("Read"),              CDW_COLORS_DIALOG },
 
 		/* 2TRANS: this is a label next to input field, in which user can enter information about publisher of ISO9660 volume */
-		{ CDW_WIDGET_LABEL,  12,  first_col,  width_wide,            1,  f_xorrisorc_publisher_l,      _("Publisher"),                         0 },
-		{ CDW_WIDGET_INPUT,  13,  first_col,  width_wide,            1,  f_xorrisorc_publisher_i,      (char *) NULL,       CDW_ISO9660_PUBL_LEN },
+		{ CDW_WIDGET_ID_DYNAMIC_LABEL,     12,  first_col,  width_wide,            1,  f_xorrisorc_publisher_l,      _("Publisher"),                         0 },
+		{ CDW_WIDGET_ID_SAFE_INPUT_LINE,   13,  first_col,  width_wide,            1,  f_xorrisorc_publisher_i,      (char *) NULL,       CDW_ISO9660_PUBL_LEN },
 
 		/* 2TRANS: this is a label next to input field, in which user can enter information about ID of ISO9660 volume set */
-		{ CDW_WIDGET_LABEL,  14,  first_col,  width_wide,            1,  f_xorrisorc_volume_set_id_l,  _("Volume set ID"),                     0 },
-		{ CDW_WIDGET_INPUT,  15,  first_col,  width_wide,            1,  f_xorrisorc_volume_set_id_i,  (char *) NULL,       CDW_ISO9660_VOLS_LEN },
+		{ CDW_WIDGET_ID_DYNAMIC_LABEL,     14,  first_col,  width_wide,            1,  f_xorrisorc_volume_set_id_l,  _("Volume set ID"),                     0 },
+		{ CDW_WIDGET_ID_SAFE_INPUT_LINE,   15,  first_col,  width_wide,            1,  f_xorrisorc_volume_set_id_i,  (char *) NULL,       CDW_ISO9660_VOLS_LEN },
 
 		/* 2TRANS: this is a label next to input field, in which user can enter information about system on which ISO9660 volume has been created */
-		{ CDW_WIDGET_LABEL,  16,  first_col,  width_wide,            1,  f_xorrisorc_system_id_l,      _("System ID"),                         0 },
-		{ CDW_WIDGET_INPUT,  17,  first_col,  CDW_ISO9660_SYSI_LEN,  1,  f_xorrisorc_system_id_i,      (char *) NULL,       CDW_ISO9660_SYSI_LEN },
+		{ CDW_WIDGET_ID_DYNAMIC_LABEL,     16,  first_col,  width_wide,            1,  f_xorrisorc_system_id_l,      _("System ID"),                         0 },
+		{ CDW_WIDGET_ID_SAFE_INPUT_LINE,   17,  first_col,  CDW_ISO9660_SYSI_LEN,  1,  f_xorrisorc_system_id_i,      (char *) NULL,       CDW_ISO9660_SYSI_LEN },
 
 		/* guard */
-		{ -1,                 0,  0,          0,                     0,  0,                            (void *) NULL,                          0 }};
+		{ -1,                               0,  0,          0,                     0,  0,                            (void *) NULL,                          0 }};
 
 	cdw_rv_t crv = cdw_form_description_to_fields(descr, cdw_form);
 	if (crv != CDW_OK) {
 		cdw_vdm ("ERROR: failed to convert form description to form\n");
 		return CDW_ERROR;
 	} else {
-		cdw_form_set_function(cdw_form, f_xorrisorc_top_message_b, cdw_xorrisorc_read_config_file);
+		cdw_form_set_widget_callback(cdw_form, f_xorrisorc_top_message_b, cdw_xorrisorc_read_config_file);
+
+		cdw_form_bind_input_and_label(cdw_form, f_xorrisorc_publisher_i, f_xorrisorc_publisher_l);
+		cdw_form_bind_input_and_label(cdw_form, f_xorrisorc_volume_set_id_i, f_xorrisorc_volume_set_id_l);
+		cdw_form_bind_input_and_label(cdw_form, f_xorrisorc_system_id_i, f_xorrisorc_system_id_l);
+
 		return CDW_OK;
 	}
 }
@@ -116,24 +135,21 @@ cdw_rv_t cdw_xorrisorc_form(cdw_form_t *cdw_form, void *cdw_task, int first_col,
 
 
 
-cdw_rv_t cdw_xorrisorc_validate(cdw_form_t *cdw_form, int *fi)
+cdw_rv_t cdw_xorrisorc_options_validate(cdw_iso9660_t *iso, int *fi)
 {
-	char *s = cdw_ncurses_get_field_string(*(cdw_form->fields + f_xorrisorc_publisher_i));
-	cdw_rv_t crv = cdw_string_security_parser(s, (char *) NULL);
+	cdw_rv_t crv = cdw_string_security_parser(iso->publisher, (char *) NULL);
 	if (crv != CDW_OK) {
 		*fi = f_xorrisorc_publisher_i;
 		return CDW_NO;
 	}
 
-	s = cdw_ncurses_get_field_string(*(cdw_form->fields + f_xorrisorc_volume_set_id_i));
-	crv = cdw_string_security_parser(s, (char *) NULL);
+	crv = cdw_string_security_parser(iso->volume_set_id, (char *) NULL);
 	if (crv != CDW_OK) {
 		*fi = f_xorrisorc_volume_set_id_i;
 		return CDW_NO;
 	}
 
-	s = cdw_ncurses_get_field_string(*(cdw_form->fields + f_xorrisorc_system_id_i));
-	crv = cdw_string_security_parser(s, (char *) NULL);
+	crv = cdw_string_security_parser(iso->system_id, (char *) NULL);
 	if (crv != CDW_OK) {
 		*fi = f_xorrisorc_system_id_i;
 		return CDW_NO;
@@ -146,19 +162,19 @@ cdw_rv_t cdw_xorrisorc_validate(cdw_form_t *cdw_form, int *fi)
 
 
 
-cdw_rv_t cdw_xorrisorc_save(cdw_form_t *cdw_form, cdw_task_t *task)
+cdw_rv_t cdw_xorrisorc_options_save(cdw_form_t *cdw_form, cdw_iso9660_t *iso)
 {
 	char *s = cdw_ncurses_get_field_string(*(cdw_form->fields + f_xorrisorc_volume_set_id_i));
-	strncpy(task->create_image.volume_set_id, s, CDW_ISO9660_VOLS_LEN);
-	task->create_image.volume_set_id[CDW_ISO9660_VOLS_LEN] = '\0';
+	strncpy(iso->volume_set_id, s, CDW_ISO9660_VOLS_LEN);
+	        iso->volume_set_id[CDW_ISO9660_VOLS_LEN] = '\0';
 
 	s = cdw_ncurses_get_field_string(*(cdw_form->fields + f_xorrisorc_publisher_i));
-	strncpy(task->create_image.publisher, s, CDW_ISO9660_PUBL_LEN);
-	task->create_image.publisher[CDW_ISO9660_PUBL_LEN] = '\0';
+	strncpy(iso->publisher, s, CDW_ISO9660_PUBL_LEN);
+	        iso->publisher[CDW_ISO9660_PUBL_LEN] = '\0';
 
 	s = cdw_ncurses_get_field_string(*(cdw_form->fields + f_xorrisorc_system_id_i));
-	strncpy(task->create_image.system_id, s, CDW_ISO9660_SYSI_LEN);
-	task->create_image.system_id[CDW_ISO9660_SYSI_LEN] = '\0';
+	strncpy(iso->system_id, s, CDW_ISO9660_SYSI_LEN);
+	        iso->system_id[CDW_ISO9660_SYSI_LEN] = '\0';
 
 	return CDW_OK;
 }
@@ -317,4 +333,3 @@ void cdw_xorrisorc_get_option_from_line(const char *line, const char *option_nam
 
 	return;
 }
-
