@@ -1,6 +1,6 @@
 /* cdw
  * Copyright (C) 2002 Varkonyi Balazs
- * Copyright (C) 2007 - 2012 Kamil Ignacak
+ * Copyright (C) 2007 - 2014 Kamil Ignacak
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 /**
@@ -58,7 +58,6 @@
 #include "cdw_utils.h"
 #include "cdw_logging.h"
 #include "cdw_ext_tools.h"
-#include "cdw_config.h"
 #include "cdw_file_manager.h"
 #include "cdw_main_window.h"
 #include "cdw_ncurses.h"
@@ -111,8 +110,8 @@ int main(int argc, char *argv[])
 
 	/* initialize ncurses - do this as soon as possible,
 	 * some error situations may require use of dialog windows */
-	cdw_rv_t crv = cdw_ncurses_init();
 	atexit(cdw_ncurses_clean);
+	cdw_rv_t crv = cdw_ncurses_init();
 	if (crv != CDW_OK) {
 		exit(EXIT_FAILURE);
 	}
@@ -120,8 +119,8 @@ int main(int argc, char *argv[])
 	cdw_colors_init_phase1();
 	/* there is no curses_colors_clean() to register with atexit() */
 
-	crv = cdw_fs_init();
 	atexit(cdw_fs_clean);
+	crv = cdw_fs_init();
 	if (crv != CDW_OK) {
 		/* 2TRANS: this is title of dialog window */
 		cdw_buttons_dialog(_("Error"),
@@ -139,9 +138,9 @@ int main(int argc, char *argv[])
 		/* cdw_config module reads in hardware configuration
 		   from configuration file; from now on "custom device"
 		   and "cdw drive" fields have some valid values */
-		cdw_config_module_init();
 		atexit(cdw_config_module_clean);
-		global_config.support_dvd_rp_dl = cdw_commandline_arguments.support_dvd_rp_dl;
+		cdw_config_module_init();
+		global_config.general.support_dvd_rp_dl = cdw_commandline_arguments.support_dvd_rp_dl;
 
 		/* now we have a config dir path, we can get colors config file */
 		cdw_colors_init_phase2();
@@ -150,28 +149,30 @@ int main(int argc, char *argv[])
 		/* cdw_cdio_drives module detects drives in user's system;
 		   it seems that it doesn't matter which of the two modules
 		   (config / cdio_drives) will be called first */
-		cdw_cdio_drives_init();
 		atexit(cdw_cdio_drives_clean);
+		cdw_cdio_drives_init();
 
 		/* cdw_drive checks data provided by cdw_config and
 		   cdw_cdio_drive modules and will be able to return
 		   correct value when cdw_drive_get_drive_fullpath()
 		   is called */
-		cdw_drive_init();
 		atexit(cdw_drive_clean);
+		cdw_drive_init();
+
 
 		/* cdw_cdio needs correct fullpath to currently selected
 		   drive - the path is provided by already configured
 		   cdw_drive module */
-		cdw_cdio_init();
 		atexit(cdw_cdio_clean);
+		cdw_cdio_init();
+
 	}
 
 	cdw_disc_init();
 	/* there is no cdw_disc_clean() to register with atexit() */
 
-	crv = cdw_logging_init();
-	atexit(cdw_logging_clean);
+	atexit(cdw_logging_module_clean);
+	crv = cdw_logging_module_init();
 	if (crv != CDW_OK) {
 		/* 2TRANS: this is title of dialog window */
 		cdw_buttons_dialog(_("Error"),
@@ -182,8 +183,8 @@ int main(int argc, char *argv[])
 		exit(EXIT_FAILURE);
 	}
 
-	crv = cdw_ext_tools_init();
 	atexit(cdw_ext_tools_clean);
+	crv = cdw_ext_tools_init();
 	if (crv == CDW_NO) {
 		/* 2TRANS: this is title of dialog window */
 		cdw_buttons_dialog(_("Error"),
@@ -205,8 +206,8 @@ int main(int argc, char *argv[])
 		;
 	}
 
-	crv = cdw_file_manager_init();
 	atexit(cdw_file_manager_clean);
+	crv = cdw_file_manager_init();
 	if (crv != CDW_OK) {
 		/* 2TRANS: this is title of dialog window */
 		cdw_buttons_dialog(_("Error"),
@@ -219,8 +220,8 @@ int main(int argc, char *argv[])
 	}
 
 	/* main app window */
-	crv = cdw_main_ui_init();
-	atexit(cdw_main_ui_clean);
+	atexit(cdw_main_window_module_clean);
+	crv = cdw_main_window_module_init();
 	if (crv != CDW_OK) {
 		/* 2TRANS: this is title of dialog window */
 		cdw_buttons_dialog(_("Error"),
@@ -260,8 +261,8 @@ int main(int argc, char *argv[])
  */
 int cdw_main_loop(void)
 {
-	MENU *menu = cdw_main_ui_get_main_menu();
-	WINDOW *window = cdw_main_ui_get_main_window();
+	MENU *menu = cdw_main_window_get_main_menu();
+	WINDOW *window = cdw_main_window_get_main_window();
 	int c = 'a';
 
 	while ((c = wgetch(window))
@@ -308,16 +309,19 @@ int cdw_main_loop(void)
 			break;
 		case 'r':
 		case 'R':
-			/* read disc meta information and display basic
+			/* Read disc meta information and display basic
 			   information in 'Disc info' area */
 			{
-				cdw_disc_t *disc = cdw_disc_new();
-				cdw_disc_get(disc);
-				cdw_main_ui_disc_info_view_display_data(disc);
-				/* update information about disc size and usage */
-				cdw_main_window_volume_info_view_update(disc->capacity.sectors_used, disc->capacity.sectors_total, true, global_config.follow_symlinks);
-				cdw_disc_delete(&disc);
+				int rv = cdw_drive_update_ui_with_disc(true);
+				if (rv == -1) {
+					cdw_buttons_dialog(_("Info"),
+							   /* 2TRANS: this is message in dialog window */
+							   _("No disc in drive or drive tray is open."),
+							   CDW_BUTTONS_OK, CDW_COLORS_DIALOG);
+				}
 			}
+
+
 			break;
 		case 'v':
 		case 'V':
@@ -353,7 +357,7 @@ int cdw_main_loop(void)
 		case KEY_F(10):
 			/* on some terminals F10 may be used/broken, so
 			   use F9 as well */
-			cdw_main_ui_show_license();
+			cdw_main_window_show_license();
 			break;
 
 #if 0 /* not in this release */
@@ -431,13 +435,13 @@ int cdw_main_loop(void)
 			   neatly correspond with menu item numbers */
 
 			if (ii == CDW_MENU_ADD_FILES) { /* Add files to list of files to be written to cd/image */
-				cdw_main_ui_add_to_selected_files();
+				cdw_main_window_add_to_selected_files();
 
 			} else if (ii == CDW_MENU_DELETE_FILES) {
 				/* Delete files from list of files to be
 				written to cd/image; this function regenerates
 				list of files and files info area */
-				cdw_main_ui_delete_from_selected_files();
+				cdw_main_window_delete_from_selected_files();
 
 			} else if (ii == CDW_MENU_CREATE_IMAGE) {
 				/* Create iso image using selected files */
@@ -461,6 +465,8 @@ int cdw_main_loop(void)
 				 * allows him modify the options, save options
 				 * to global variable and to disk file */
 				cdw_config_window();
+			} else if (ii == CDW_MENU_ABOUT) {
+				cdw_about();
 			} else if (ii == CDW_MENU_EXIT_CDW) { /* Quit - Exit cdw */
 				/* this function calls exit() only if user
 				   confirms closing appication */
@@ -484,7 +490,7 @@ int cdw_main_loop(void)
 		default:
 			break;
 		} /* switch(c) */
-		cdw_main_ui_main_window_wrefresh();
+		cdw_main_window_wrefresh();
 	} /* while (c = wgetch(main_cdw_win)) */
 
 	return 0;
@@ -529,7 +535,7 @@ void cdw_conditional_exit(void)
 #include <stdlib.h>
 
 #include "main.h"
-#include "config.h"
+#include "config_cdw.h"
 
 #include "cdw_dll.h"
 #include "cdw_string.h"
