@@ -1,6 +1,6 @@
 /* cdw
  * Copyright (C) 2002 Varkonyi Balazs
- * Copyright (C) 2007 - 2012 Kamil Ignacak
+ * Copyright (C) 2007 - 2014 Kamil Ignacak
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #define _GNU_SOURCE /* strndup() */
@@ -97,12 +97,11 @@ static cdw_rv_t    cdw_file_new_fullpath(cdw_file_t *file, const char *dirpath,
 */
 cdw_file_t *cdw_file_new(const char *dirpath, const char *name)
 {
-	cdw_assert (dirpath != (const char *) NULL, "ERROR: passed to the function NULL as dirpath\n");
+	cdw_assert (dirpath, "ERROR: \"dirpath\" argument is NULL\n");
 
-	cdw_file_t *file = (cdw_file_t *) NULL;
-	file = cdw_file_new_base();
-	if (file == (cdw_file_t *) NULL) {
-		cdw_vdm ("ERROR: failed to create new file with cdw_file_new()\n");
+	cdw_file_t *file = cdw_file_new_base();
+	if (!file) {
+		cdw_vdm ("ERROR: failed to create new file with cdw_file_new_base()\n");
 		return (cdw_file_t *) NULL;
 	}
 
@@ -118,7 +117,20 @@ cdw_file_t *cdw_file_new(const char *dirpath, const char *name)
 	} else {
 		file->is_ref_to_parent_dir = false;
 	}
+#if 0
+	/* 2014-02-24: I don't want a dirpath to end with a slash
+	   anymore. I'm almost certain that there is a difference in
+	   passing "/path/to/symlink/to/dir/" and
+	   "/path/to/symlink/to/dir". If such a path is on list of
+	   selected directories, lstat() will recognize first path as
+	   a dir (not what I want), and the second path as symlink
+	   (this is what I want). The difference is significant when
+	   you think about state of "follow symlinks when calculating
+	   space" checkbox in Configuration window.
 
+	   TODO: perhaps the function should be rewritten so that it
+	   makes sure that there is no trailing slash in its arg?
+	*/
 	if (file->type == CDW_FS_DIR) {
 		crv = cdw_fs_correct_dir_path_ending(&(file->fullpath));
 		if (crv != CDW_OK) {
@@ -127,7 +139,7 @@ cdw_file_t *cdw_file_new(const char *dirpath, const char *name)
 			return (cdw_file_t *) NULL;
 		}
 	}
-
+#endif
 	return file;
 }
 
@@ -152,10 +164,10 @@ cdw_rv_t cdw_file_new_stat(cdw_file_t *file)
 	int rv = lstat(file->fullpath, &stbuf);
 	if (rv != -1) {
 		if (S_ISLNK(stbuf.st_mode)) {
-			file->link = true;
+			file->is_link = true;
 			cdw_sdm ("IS a link: \"%s\"\n", file->fullpath);
 		} else {
-			file->link = false;
+			file->is_link = false;
 			cdw_sdm ("IN NOT a link: \"%s\"\n", file->fullpath);
 		}
 		file->invalid = false;
@@ -229,7 +241,7 @@ cdw_rv_t cdw_file_new_fullpath(cdw_file_t *file, const char *dirpath, const char
 	file->fullpath = cdw_string_concat(correct_dirpath, name, (char *) NULL);
 	free(correct_dirpath);
 	correct_dirpath = (char *) NULL;
-	if (file->fullpath == (char *) NULL) {
+	if (!file->fullpath) {
 		cdw_assert (0, "ERROR: failed to concatenate dirpath and name: \"%s\" + \"%s\"\n", dirpath, name);
 		return CDW_ERROR;
 	}
@@ -239,14 +251,14 @@ cdw_rv_t cdw_file_new_fullpath(cdw_file_t *file, const char *dirpath, const char
 		cdw_vdm ("ERROR: failed to get start of file name in fullpath \"%s\"\n", file->fullpath);
 		free(file->fullpath);
 		file->fullpath = (char *) NULL;
-		assert (0);
+		cdw_assert (0, "ERROR: failed to get filename start in \"%s\"\n", file->fullpath);
 		return CDW_ERROR;
 	}
 
 	file->printable_fullpath = cdw_string_get_printable_if_needed(file->fullpath);
 
 #ifndef NDEBUG
-	if (file->printable_fullpath != (char *) NULL) {
+	if (file->printable_fullpath) {
 		ssize_t i = cdw_fs_get_filename_start(file->fullpath);
 		ssize_t j = cdw_fs_get_filename_start(file->printable_fullpath);
 		cdw_assert (i == j, "ERROR: wrong assumption about file name start in path and printable path\n");
@@ -273,8 +285,8 @@ cdw_rv_t cdw_file_new_fullpath(cdw_file_t *file, const char *dirpath, const char
 */
 cdw_file_t *cdw_file_new_base(void)
 {
-	cdw_file_t *file = (cdw_file_t *) malloc (sizeof (cdw_file_t));
-	if (file == (cdw_file_t *) NULL) {
+	cdw_file_t *file = (cdw_file_t *) malloc(sizeof (cdw_file_t));
+	if (!file) {
 		cdw_vdm ("ERROR: failed to allocate memory for new file\n");
 		return (cdw_file_t *) NULL;
 	} else {
@@ -283,7 +295,7 @@ cdw_file_t *cdw_file_new_base(void)
 		file->name_start = -1;
 		file->size = 0;
 		file->invalid = true;
-		file->link = false;
+		file->is_link = false;
 		file->type = CDW_FS_OTHER;
 		file->is_ref_to_parent_dir = false;
 
@@ -307,34 +319,40 @@ cdw_file_t *cdw_file_new_base(void)
 */
 cdw_file_t *cdw_file_duplicate(const cdw_file_t *file)
 {
-	cdw_assert (file != (cdw_file_t *) NULL, "ERROR: passing NULL pointer for duplication\n");
-	cdw_assert (file->fullpath + file->name_start != (char *) NULL, "ERROR: passing file with NULL name for duplication\n");
-	cdw_assert (file->fullpath != (char *) NULL, "ERROR: passing file with NULL fullpath for duplication\n");
+	cdw_assert (file, "ERROR: \"file\" argument is NULL\n");
+	cdw_assert (file->fullpath + file->name_start, "ERROR: passing file with NULL name for duplication\n"); /* TODO: is this test valid? */
+	cdw_assert (file->fullpath, "ERROR: file's fullpath is NULL\n");
 
 	cdw_file_t *copy = (cdw_file_t *) malloc(sizeof(cdw_file_t));
-	if (copy == (cdw_file_t *) NULL) {
+	if (!copy) {
 		cdw_vdm ("ERROR: failed to allocate memory for duplicate of file\n");
 		return (cdw_file_t *) NULL;
 	}
 
-	if (file->printable_fullpath != (char *) NULL) {
+	if (file->printable_fullpath) {
 		copy->printable_fullpath = strdup(file->printable_fullpath);
+		if (!copy->printable_fullpath) {
+			cdw_file_delete(&copy);
+
+			cdw_vdm ("ERROR: failed to duplicate printable fullpath of file (\"%s\")\n", file->printable_fullpath);
+			return (cdw_file_t *) NULL;
+		}
 	} else {
 		copy->printable_fullpath = (char *) NULL;
 	}
 	copy->name_start = file->name_start;
 
 	copy->fullpath = strdup(file->fullpath);
-	if (copy->fullpath == (char *) NULL) {
+	if (!copy->fullpath) {
 		cdw_file_delete(&copy);
 
-		cdw_vdm ("ERROR: failed to duplicate fullpath of file\n");
+		cdw_vdm ("ERROR: failed to duplicate fullpath of file (\"%s\")\n", file->fullpath);
 		return (cdw_file_t *) NULL;
 	}
 
 	copy->type = file->type;
 	copy->size = file->size;
-	copy->link = file->link;
+	copy->is_link = file->is_link;
 	copy->invalid = file->invalid;
 	copy->is_ref_to_parent_dir = file->is_ref_to_parent_dir;
 
@@ -357,23 +375,24 @@ cdw_file_t *cdw_file_duplicate(const cdw_file_t *file)
 */
 cdw_rv_t cdw_file_delete(cdw_file_t **file)
 {
-	cdw_assert (file != (cdw_file_t **) NULL, "ERROR: passing null pointer to the function\n");
+	cdw_assert (file != (cdw_file_t **) NULL, "ERROR: \"file\" argument is NULL\n");
 
 	if (*file == (cdw_file_t *) NULL) {
-		cdw_vdm ("ERROR: passed pointer to NULL file to function\n");
+		/* TODO: shouldn't we issue only a warning and return CDW_OK? */
+		cdw_vdm ("ERROR: \"file\" pointer points to NULL file\n");
 		return CDW_ERROR;
 	}
 
-	if ((*file)->printable_fullpath != (char *) NULL) {
+	if ((*file)->printable_fullpath) {
 		free((*file)->printable_fullpath);
 		(*file)->printable_fullpath = (char *) NULL;
 	}
 
-	if ((*file)->fullpath == (char *) NULL) {
-		cdw_vdm ("WARNING: passed to function file with null fullpath\n");
-	} else {
+	if ((*file)->fullpath) {
 		free((*file)->fullpath);
 		(*file)->fullpath = (char *) NULL;
+	} else {
+		cdw_vdm ("WARNING: file's fullpath is NULL\n");
 	}
 
 	free(*file);
@@ -398,24 +417,26 @@ cdw_rv_t cdw_file_delete(cdw_file_t **file)
 */
 bool cdw_file_equal(const void *_file1, const void *_file2)
 {
-	cdw_assert (_file1 != (const cdw_file_t *) NULL, "ERROR: first argument is null\n");
-	cdw_assert (_file2 != (const cdw_file_t *) NULL, "ERROR: second argument is null\n");
+	cdw_assert (_file1, "ERROR: first argument is NULL\n");
+	cdw_assert (_file2, "ERROR: second argument is NULL\n");
 
 	const cdw_file_t *file1 = (const cdw_file_t *) _file1;
 	const cdw_file_t *file2 = (const cdw_file_t *) _file2;
 
+	cdw_assert (file1, "ERROR: file1 is NULL\n");
+	cdw_assert (file2, "ERROR: file2 is NULL\n");
 	cdw_assert (file1->name_start > 0, "ERROR: file1->name_start <= 0: %zd\n", file1->name_start);
 	cdw_assert (file2->name_start > 0, "ERROR: file1->name_start <= 0: %zd\n", file2->name_start);
-	cdw_assert (file1->fullpath != (char *) NULL, "ERROR: file1->fullpath is NULL\n");
-	cdw_assert (file2->fullpath != (char *) NULL, "ERROR: file2->fullpath is NULL\n");
+	cdw_assert (file1->fullpath, "ERROR: file1->fullpath is NULL\n");
+	cdw_assert (file2->fullpath, "ERROR: file2->fullpath is NULL\n");
 
-	if (file1 == (const cdw_file_t *) NULL || file2 == (const cdw_file_t *) NULL) {
-		cdw_vdm ("ERROR: one (or two) file was null\n");
+	if (!file1 || !file2) {
+		cdw_vdm ("ERROR: one (or two) file was NULL\n");
 		return false;
 	}
 
-	if (file1->fullpath == (char *) NULL || file2->fullpath == (char *) NULL) {
-		cdw_vdm ("ERROR: one (or two) fullpaths was null\n");
+	if (!file1->fullpath || !file2->fullpath) {
+		cdw_vdm ("ERROR: one (or two) fullpath was NULL\n");
 		return false;
 	} else {
 		if (!strcmp(file1->fullpath, file2->fullpath)) {
@@ -427,7 +448,8 @@ bool cdw_file_equal(const void *_file1, const void *_file2)
 	}
 
 
-	/* values of file names were tested when testing fullpaths */
+	/* Values of file names were tested when testing fullpaths.
+	   TODO: does this test make sense? */
 	if (file1->fullpath + file1->name_start == (char *) NULL
 	    || file2->fullpath + file2->name_start == (char *) NULL) {
 
@@ -435,9 +457,9 @@ bool cdw_file_equal(const void *_file1, const void *_file2)
 		return false;
 	}
 
-	if (file1->printable_fullpath == (char *) NULL && file2->printable_fullpath == (char *) NULL) {
-		/* null "printable_fullpath" strings are allowed */
-	} else if (file1->printable_fullpath != (char *) NULL && file2->printable_fullpath != (char *) NULL) {
+	if (!file1->printable_fullpath && !file2->printable_fullpath) {
+		/* NULL "printable_fullpath" strings are allowed. */
+	} else if (file1->printable_fullpath && file2->printable_fullpath) {
 		if (!strcmp(file1->printable_fullpath, file2->printable_fullpath)) {
 			;
 		} else {
@@ -445,7 +467,7 @@ bool cdw_file_equal(const void *_file1, const void *_file2)
 			return false;
 		}
 	} else {
-		cdw_sdm ("INFO: one printable fullpath is is null, the other is non-null\n");
+		cdw_sdm ("INFO: one printable fullpath is NULL, the other is non-NULL\n");
 		return false;
 
 	}
@@ -467,7 +489,7 @@ bool cdw_file_equal(const void *_file1, const void *_file2)
 		cdw_sdm ("INFO: files differ in file sizes\n");
 		return false;
 	}
-	if (file1->link != file2->link) {
+	if (file1->is_link != file2->is_link) {
 		cdw_sdm ("INFO: files differ in \"link\" values\n");
 		return false;
 	}
@@ -504,15 +526,15 @@ bool cdw_file_equal(const void *_file1, const void *_file2)
 */
 void cdw_file_display_file(void *display, void *data, size_t row, size_t h_offset, bool isreverse)
 {
-	cdw_assert (display != (CDW_LIST_DISPLAY *) NULL, "display is NULL\n");
+	cdw_assert (display, "ERROR: \"display\" argument is NULL\n");
 	CDW_LIST_DISPLAY *displ = (CDW_LIST_DISPLAY *) display;
-	cdw_assert (displ->subwindow != (WINDOW *) NULL, "subwindow of display is NULL\n");
+	cdw_assert (displ->subwindow, "ERROR: subwindow of display is NULL\n");
 
 	int n_cols = getmaxx(displ->subwindow);
 	int n_rows = getmaxy(displ->subwindow);
-	cdw_assert (n_cols > 0, "we have subwindow with 0 columns, or null subwindow\n");
-	cdw_assert (n_rows > (int) row, "row number larger than number of rows in subwindow\n");
-	cdw_assert (data != (void *) NULL, "you try to display null file\n");
+	cdw_assert (n_cols > 0, "ERROR: we have subwindow with 0 columns, or NULL subwindow\n");
+	cdw_assert (n_rows > (int) row, "ERROR: row number larger than number of rows in subwindow\n");
+	cdw_assert (data, "ERROR: you try to display NULL file\n");
 	cdw_file_t *file = (cdw_file_t *) data;
 
 	/* this fills space between item name on the left side of the
@@ -521,14 +543,14 @@ void cdw_file_display_file(void *display, void *data, size_t row, size_t h_offse
 
 	char *string = (char *) NULL;
 	if (displ->display_format == CDW_LIST_DISPLAY_FORMAT_SHORT) {
-		if (file->printable_fullpath != (char *) NULL) {
+		if (file->printable_fullpath) {
 			string = file->printable_fullpath + file->name_start;
 		} else {
 			string = file->fullpath + file->name_start;
 		}
 	} else if (displ->display_format == CDW_LIST_DISPLAY_FORMAT_LONG) {
-		cdw_assert (file->fullpath != (char *) NULL, "using file without fullpath\n");
-		if (file->printable_fullpath != (char *) NULL) {
+		cdw_assert (file->fullpath, "ERROR: using file without fullpath\n");
+		if (file->printable_fullpath) {
 			string = file->printable_fullpath;
 		} else {
 			string = file->fullpath;
@@ -557,7 +579,7 @@ void cdw_file_display_file(void *display, void *data, size_t row, size_t h_offse
 	if (file->invalid) {
 		strcpy(format, "!%.*s");
 	} else {
-		if (file->link == true) {
+		if (file->is_link) {
 			strcpy(format, "~%.*s");
 		} else {
 			strcpy(format, "%.*s");
@@ -575,16 +597,16 @@ void cdw_file_display_file(void *display, void *data, size_t row, size_t h_offse
 		wchar_t dest[1000];
 		size_t conv_len = mbstowcs(dest, string, 50);
 		size_t len = strlen(string);
-		fprintf(stderr, "analyzing \"%s\"\n", string);
+		fprintf(stderr, "INFO: analyzing \"%s\"\n", string);
 		for (size_t i = 0; i < len; i++) {
-			fprintf(stderr, " char: %u - > '%c'\n", (unsigned char) string[i], string[i]);
+			fprintf(stderr, "INFO: char: %u - > '%c'\n", (unsigned char) string[i], string[i]);
 		}
-		fprintf(stderr, " char: strlen(string) = %zd\n", strlen(string));
+		fprintf(stderr, "INFO: char: strlen(string) = %zd\n", strlen(string));
 		for (size_t i = 0; i < len; i++) {
-			fprintf(stderr, " wchar: %u - > '%c'\n", (unsigned char) dest[i], dest[i]);
+			fprintf(stderr, "INFO: wchar: %u - > '%c'\n", (unsigned char) dest[i], dest[i]);
 			//perror("d");
 		}
-		fprintf(stderr, " wchar: wcslen(dest) = %zd, mbstowcs(): %zd\n\n\n", wcslen(dest), conv_len);
+		fprintf(stderr, "INFO: wchar: wcslen(dest) = %zd, mbstowcs(): %zd\n\n\n", wcslen(dest), conv_len);
 	}
 #endif
 
@@ -641,13 +663,12 @@ void cdw_file_display_file(void *display, void *data, size_t row, size_t h_offse
 */
 cdw_rv_t cdw_file_dealloc_files_from_list(cdw_dll_item_t *list)
 {
-	if (list != (cdw_dll_item_t *) NULL) {
-		cdw_dll_item_t *item = list;
-		for ( ; item != (cdw_dll_item_t *) NULL; item = item->next) {
+	if (list) {
+		for (cdw_dll_item_t *item = list; item; item = item->next) {
 			cdw_file_delete((cdw_file_t **) &(item->data));
 		}
 	} else {
-		cdw_vdm ("INFO: passed NULL list to the function\n");
+		cdw_vdm ("WARNING: passed NULL list to the function\n");
 	}
 
 	return CDW_OK;
@@ -699,13 +720,13 @@ void test_cdw_file_new_base(void)
 
 	cdw_file_t *file = cdw_file_new_base();
 
-	cdw_assert_test (file != (cdw_file_t *) NULL, "ERROR: function cdw_file_new_base() failed to allocate file\n");
-	cdw_assert_test (file->fullpath == (char *) NULL, "ERROR: fullpath in new file base is not NULL\n");
+	cdw_assert_test (file, "ERROR: function cdw_file_new_base() failed to allocate file\n");
+	cdw_assert_test (!file->fullpath, "ERROR: fullpath in new file base is not NULL\n");
 	cdw_assert_test (file->name_start == -1, "ERROR: name start is -1 by default\n");
 
 	cdw_assert_test (file->size == 0, "ERROR: size of new file is not 0 by default\n");
 	cdw_assert_test (file->invalid == true, "ERROR: file is not invalid by default\n");
-	cdw_assert_test (file->link == false, "ERROR: file is link by default\n");
+	cdw_assert_test (file->is_link == false, "ERROR: file is link by default\n");
 	cdw_assert_test (file->type == CDW_FS_OTHER, "ERROR: file is not CDW_FS_OTHER by default\n");
 	cdw_assert_test (file->is_ref_to_parent_dir == false, "ERROR: file is not ref to parent by default\n");
 
@@ -737,8 +758,8 @@ void test_cdw_file_equal(void)
 	file2.type = CDW_FS_FILE;
 	file1.size = 123456;
 	file2.size = 123456;
-	file1.link = true;
-	file2.link = true;
+	file1.is_link = true;
+	file2.is_link = true;
 	file1.invalid = true;
 	file2.invalid = true;
 	file1.is_ref_to_parent_dir = true;
@@ -835,18 +856,18 @@ void test_cdw_file_equal(void)
 
 
 	/* testing with different "link" field values */
-	file1.link = true;
-	file2.link = true;
+	file1.is_link = true;
+	file2.is_link = true;
 	test = cdw_file_equal((const void *) &file1, (const void *) &file2);
 	cdw_assert_test (test == true, "ERROR: files with the same 'link' fields are recognized as different\n");
 
-	file1.link = false;
-	file2.link = true;
+	file1.is_link = false;
+	file2.is_link = true;
 	test = cdw_file_equal((const void *) &file1, (const void *) &file2);
 	cdw_assert_test (test == false, "ERROR: files with different 'link' fields are recognized as the same\n");
 
-	file1.link = false;
-	file2.link = false;
+	file1.is_link = false;
+	file2.is_link = false;
 	test = cdw_file_equal((const void *) &file1, (const void *) &file2);
 	cdw_assert_test (test == true, "ERROR: files with restored the same 'link' fields are recognized as different\n");
 
@@ -906,16 +927,16 @@ void test_cdw_file_equal(void)
 
 cdw_rv_t test_cdw_file_new_helper(char **cwd, char **dirpath, char **filename)
 {
-	cdw_assert_test (*cwd == (char *) NULL, "ERROR: cwd should be pointer to NULL");
-	cdw_assert_test (*dirpath == (char *) NULL, "ERROR: dirpath should be pointer to NULL");
-	cdw_assert_test (*filename == (char *) NULL, "ERROR: filename should be pointer to NULL");
+	cdw_assert_test (!(*cwd), "ERROR: cwd should be pointer to NULL");
+	cdw_assert_test (!(*dirpath), "ERROR: dirpath should be pointer to NULL");
+	cdw_assert_test (!(*filename), "ERROR: filename should be pointer to NULL");
 
 	/* first get some existing dir path */
 	*cwd = (char *) malloc(PATH_MAX); /* PATH_MAX alreay includes ending null */
-	cdw_assert_test (*cwd != (char *) NULL, "ERROR: failed to allocate memory for cwd\n");
+	cdw_assert_test (*cwd, "ERROR: failed to allocate memory for cwd\n");
 
 	char *res = getcwd(*cwd, PATH_MAX - 1);
-	cdw_assert_test (res != (char *) NULL, "ERROR: failed to get current working directory (1)\n");
+	cdw_assert_test (res, "ERROR: failed to get current working directory (1)\n");
 	cdw_assert_test (res == *cwd, "ERROR: failed to get current working directory (2)\n");
 	cdw_rv_t crv = cdw_fs_correct_dir_path_ending(cwd);
 	cdw_assert_test (crv == CDW_OK, "ERROR: failed to ensure proper ending of cwd\n");
@@ -926,8 +947,7 @@ cdw_rv_t test_cdw_file_new_helper(char **cwd, char **dirpath, char **filename)
 	// cdw_vdm ("INFO: cwd = \"%s\", start = %d\n", *cwd, start);
 	*filename = strdup(*cwd + start);
 	*dirpath = strndup(*cwd, (size_t) start);
-	cdw_assert_test (*filename != (char *) NULL && *dirpath != (char *) NULL,
-			 "ERROR: failed to strdup() filename and dirpath\n");
+	cdw_assert_test (*filename && *dirpath, "ERROR: failed to strdup() filename and dirpath\n");
 	// cdw_vdm ("INFO: dirtpath = \"%s\"\n", *dirpath);
 	// cdw_vdm ("INFO: filename = \"%s\"\n", *filename);
 
@@ -951,14 +971,14 @@ void test_cdw_file_new_file_delete(void)
 	/* create file and test it */
 
 	cdw_file_t *file = cdw_file_new(dirpath, filename);
-	cdw_assert_test (file != (cdw_file_t *) NULL, "ERROR: function cdw_file_new_base() failed to allocate file\n");
+	cdw_assert_test (file, "ERROR: function cdw_file_new_base() failed to allocate file\n");
 
-	cdw_assert_test (file->fullpath != (char *) NULL, "ERROR: fullpath in new file base is NULL\n");
+	cdw_assert_test (file->fullpath, "ERROR: fullpath in new file base is NULL\n");
 	cdw_assert_test (!strcmp(file->fullpath, cwd), "ERROR: incorrect fullpath: should be \"%s\", is: \"%s\"\n", cwd, file->fullpath);
 	cdw_assert_test (!strcmp(file->fullpath + file->name_start, filename), "ERROR: incorrect name: should be \"%s\", is: \"%s\"\n", filename, file->fullpath + file->name_start);
 	cdw_assert_test (file->size == 0, "ERROR: size of new file is not 0 for dir\n");
 	cdw_assert_test (file->invalid == false, "ERROR: existing file is invalid\n");
-	cdw_assert_test (file->link == false, "ERROR: dir is link\n");
+	cdw_assert_test (file->is_link == false, "ERROR: dir is link\n");
 	cdw_assert_test (file->type == CDW_FS_DIR, "ERROR: dir is not recognized as dir\n");
 	cdw_assert_test (file->is_ref_to_parent_dir == false, "ERROR: current dir should not be reference to parent dir\n");
 
@@ -966,7 +986,7 @@ void test_cdw_file_new_file_delete(void)
 
 	// char **f = &(file->fullpath);
 	cdw_file_delete(&file);
-	cdw_assert_test (file == (cdw_file_t *) NULL, "ERROR: failed to correctly delete file, file is not NULL\n");
+	cdw_assert_test (!file, "ERROR: failed to correctly delete file, file is not NULL\n");
 	/* on some occasions this assertion fails, but valgrind doesn't
 	   complain about leaking memory related to file->fullpath */
 	// cdw_assert_test (*f == (char *) NULL, "ERROR: failed to correctly nullify file->fullpath, it doesn't point to NULL\n");
@@ -1001,14 +1021,14 @@ void test_cdw_file_duplicate(void)
 	/* create file and test it (we tested creating file before, but just in case... */
 
 	cdw_file_t *file = cdw_file_new(dirpath, filename);
-	cdw_assert_test (file != (cdw_file_t *) NULL, "ERROR: function cdw_file_new_base() failed to allocate file\n");
+	cdw_assert_test (file, "ERROR: function cdw_file_new_base() failed to allocate file\n");
 
-	cdw_assert_test (file->fullpath != (char *) NULL, "ERROR: fullpath in new file base is NULL\n");
+	cdw_assert_test (file->fullpath, "ERROR: fullpath in new file base is NULL\n");
 	cdw_assert_test (!strcmp(file->fullpath, cwd), "ERROR: incorrect fullpath: should be \"%s\", is: \"%s\"\n", cwd, file->fullpath);
 	cdw_assert_test (!strcmp(file->fullpath + file->name_start, filename), "ERROR: incorrect name: should be \"%s\", is: \"%s\"\n", filename, file->fullpath + file->name_start);
 	cdw_assert_test (file->size == 0, "ERROR: size of new file is not 0 for dir\n");
 	cdw_assert_test (file->invalid == false, "ERROR: existing file is invalid\n");
-	cdw_assert_test (file->link == false, "ERROR: dir is link\n");
+	cdw_assert_test (file->is_link == false, "ERROR: dir is link\n");
 	cdw_assert_test (file->type == CDW_FS_DIR, "ERROR: dir is not recognized as dir\n");
 	cdw_assert_test (file->is_ref_to_parent_dir == false, "ERROR: current dir should not be reference to parent dir\n");
 
@@ -1020,7 +1040,7 @@ void test_cdw_file_duplicate(void)
 	/* now do the real testing */
 	cdw_file_t *duplicate = cdw_file_duplicate(file);
 
-	cdw_assert_test (duplicate != (cdw_file_t *) NULL, "ERROR: failed to create duplicate of a file\n");
+	cdw_assert_test (duplicate, "ERROR: failed to create duplicate of a file\n");
 	cdw_assert_test (!strcmp(file->fullpath, duplicate->fullpath),
 			 "ERROR: file and its duplicate have different fullpaths:\nfile->fullpath      = \"%s\"\nduplicate->fullpath = \"%s\"\n",
 			 file->fullpath, duplicate->fullpath);
@@ -1033,19 +1053,19 @@ void test_cdw_file_duplicate(void)
 	cdw_assert_test (file->invalid == duplicate->invalid,
 			 "ERROR: file and its duplicate have different \"invalid\" field values:\nfile->invalid      = %s\nduplicate->invalid = %s\n",
 			 file->invalid ? "true" : "false", duplicate->invalid ? "true" : "false");
-	cdw_assert_test (file->link == duplicate->link,
-			 "ERROR: file and its duplicate have different \"link\" field values:\nfile->link      = %s\nduplicate->link = %s\n",
-			 file->link ? "true" : "false", duplicate->link ? "true" : "false");
+	cdw_assert_test (file->is_link == duplicate->is_link,
+			 "ERROR: file and its duplicate have different \"link\" field values:\nfile->is_link      = %s\nduplicate->is_link = %s\n",
+			 file->is_link ? "true" : "false", duplicate->is_link ? "true" : "false");
 	cdw_assert_test (file->type == duplicate->type,
-			 "ERROR: file and its duplicate have different \"type\" field values:\nfile->link      = %d\nduplicate->link = %d\n",
+			 "ERROR: file and its duplicate have different \"type\" field values:\nfile->is_link      = %d\nduplicate->is_link = %d\n",
 			 file->type, duplicate->type);
 	cdw_assert_test (file->is_ref_to_parent_dir == duplicate->is_ref_to_parent_dir,
 			 "ERROR: file and its duplicate have different \"is reference to parent dir\" field values\n");
 
 	cdw_file_delete(&file);
-	cdw_assert_test (file == (cdw_file_t *) NULL, "ERROR: failed to correctly delete file, file is not NULL\n");
+	cdw_assert_test (!file, "ERROR: failed to correctly delete file, file is not NULL\n");
 	cdw_file_delete(&duplicate);
-	cdw_assert_test (duplicate == (cdw_file_t *) NULL, "ERROR: failed to correctly delete file duplicate, it is not NULL\n");
+	cdw_assert_test (!duplicate, "ERROR: failed to correctly delete file duplicate, it is not NULL\n");
 
 	free(cwd);
 	cwd = (char *) NULL;
@@ -1096,7 +1116,7 @@ void test_cdw_file_new_fullpath(void)
 	name = (char *) NULL;
 	free(file.fullpath);
 	file.fullpath = (char *) NULL;
-	if (file.printable_fullpath != (char *) NULL) {
+	if (file.printable_fullpath) {
 		free(file.printable_fullpath);
 		file.printable_fullpath = (char *) NULL;
 	}
@@ -1107,5 +1127,3 @@ void test_cdw_file_new_fullpath(void)
 
 
 #endif /* CDW_UNIT_TEST_CODE */
-
-
