@@ -1,6 +1,6 @@
 /* cdw
  * Copyright (C) 2002 Varkonyi Balazs
- * Copyright (C) 2007 - 2012 Kamil Ignacak
+ * Copyright (C) 2007 - 2014 Kamil Ignacak
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 /**
@@ -68,6 +68,7 @@
 #include "cdw_graftpoints.h"
 #include "cdw_config.h"
 #include "cdw_logging.h"
+#include "canonicalize.h"
 
 extern cdw_config_t global_config;
 
@@ -77,6 +78,8 @@ static struct {
 	double size_mb; /** \brief Size of currently selected files (in megabytes) */
 	bool has_4GB_file;
 	CDW_LIST_DISPLAY *display;
+
+	bool follow_symlinks;
 } selected_files;
 
 
@@ -123,6 +126,10 @@ void cdw_selected_files_init(void)
 	selected_files.has_4GB_file = false;
 	selected_files.display = (CDW_LIST_DISPLAY *) NULL;
 
+	/* The function is called during initialization of cdw, so
+	   this global variable holds the most recent value. */
+	selected_files.follow_symlinks = global_config.general.selected_follow_symlinks;
+
 	return;
 }
 
@@ -209,15 +216,16 @@ cdw_rv_t cdw_file_manager_init(void)
 */
 void cdw_file_manager_clean(void)
 {
-	if (selected_files.display != (CDW_LIST_DISPLAY *) NULL) {
+	/* This 'if ()' duplicates code from
+	   cdw_file_manager_delete_selected_files_view() and should be
+	   removed from here, but I will leave it for now. */
+	if (selected_files.display) {
 		cdw_file_dealloc_files_from_list(selected_files.display->list);
 		cdw_list_display_delete(&(selected_files.display));
 	}
 
-	if (file_selector.initial_fullpath != (char *) NULL) {
-		free(file_selector.initial_fullpath);
-		file_selector.initial_fullpath = (char *) NULL;
-	}
+	cdw_string_delete(&file_selector.initial_fullpath);
+
 	return;
 }
 
@@ -249,6 +257,22 @@ cdw_dll_item_t *cdw_file_manager_get_list_of_selected_files(void)
 
 
 
+/**
+   \brief Remember current setting regarding "follow selected symbolic links" policy
+
+   \param selected_follow_symlinks
+*/
+void cdw_file_manager_follow_symlinks(bool selected_follow_symlinks)
+{
+	selected_files.follow_symlinks = selected_follow_symlinks;
+
+	return;
+}
+
+
+
+
+
 /**
    \brief Top level function for process of selecting files from file system
 
@@ -274,7 +298,7 @@ cdw_rv_t cdw_file_manager_handle_adding_to_selected_files(void)
 	/* selector window, loop, key handling, adding files to list,
 	   etc. is done by this function */
 	cdw_rv_t crv = cdw_file_selector();
-	cdw_main_ui_main_window_wrefresh();
+	cdw_main_window_wrefresh();
 
 	cdw_rv_t retval = CDW_ERROR;
 	if (crv == CDW_ERROR) {
@@ -329,7 +353,7 @@ cdw_rv_t cdw_file_manager_handle_deleting_from_selected_files(void)
 		if (key == KEY_DC) {
 			crv = cdw_selected_files_remove_file(selected_files.display->current_item_ind);
 			if (crv == CDW_OK) {
-				crv = cdw_main_window_volume_info_view_update(-1, -1, false, global_config.follow_symlinks);
+				crv = cdw_main_window_volume_info_view_update(-1, -1, false);
 				if (crv == CDW_OK) {
 					crv = CDW_OK;
 				} else {
@@ -353,7 +377,7 @@ cdw_rv_t cdw_file_manager_handle_deleting_from_selected_files(void)
 	}
 	/* FIXME: this function does not inform user when some errors occur */
 
-	crv = cdw_main_window_volume_info_view_update(-1, -1, true, global_config.follow_symlinks);
+	crv = cdw_main_window_volume_info_view_update(-1, -1, true);
 	if (crv == CDW_OK) {
 		return CDW_OK;
 	} else {
@@ -512,7 +536,7 @@ cdw_rv_t cdw_file_selector(void)
 	if (selected_files.display->n_items > 0) {
 		/* true - upon finishing adding files recount size of
 		   selected files */
-		cdw_rv_t crv = cdw_main_window_volume_info_view_update(-1, -1, true, global_config.follow_symlinks);
+		cdw_rv_t crv = cdw_main_window_volume_info_view_update(-1, -1, true);
 		if (crv == CDW_OK) {
 			return CDW_OK;
 		} else {
@@ -554,7 +578,7 @@ cdw_rv_t cdw_file_manager_create_selected_files_view(WINDOW *parent)
 
 	/* 1, 1 - begin_y, begin_x */
 	selected_files.display = cdw_list_display_new(parent, n_lines - 2, n_cols - 2, 1, 1, CDW_COLORS_MAIN);
-	if (selected_files.display == (CDW_LIST_DISPLAY *) NULL) {
+	if (!selected_files.display) {
 		cdw_vdm ("ERROR: failed to create 'selected files' display\n");
 		cdw_file_manager_internal_error_dialog(CDW_FM_E_NO_SELECTED);
 
@@ -574,6 +598,20 @@ cdw_rv_t cdw_file_manager_create_selected_files_view(WINDOW *parent)
 
 
 
+void cdw_file_manager_delete_selected_files_view(void)
+{
+	if (selected_files.display) {
+		cdw_file_dealloc_files_from_list(selected_files.display->list);
+		cdw_list_display_delete(&(selected_files.display));
+	}
+
+	return;
+}
+
+
+
+
+
 /**
    \brief Display dialog window with error message
 
@@ -654,12 +692,12 @@ cdw_rv_t cdw_file_manager_regenerate_selected_files_view(void)
    \return size (in megabytes) of all files on 'selected list' on success
    \return -1 on error
 */
-double cdw_file_manager_calculate_selected_files_size_mb(bool follow_symlinks)
+double cdw_file_manager_calculate_selected_files_size_mb(void)
 {
 	cdw_fs_visitor_data_t vdata;
 	vdata.size = 0;
 	vdata.has_file_over_4GB = false;
-	vdata.follow_symlinks = follow_symlinks;
+	vdata.follow_symlinks = selected_files.follow_symlinks;
 	selected_files.size_mb = 0.0;
 	selected_files.size = 0;
 
@@ -670,7 +708,11 @@ double cdw_file_manager_calculate_selected_files_size_mb(bool follow_symlinks)
 			   "ERROR: NULL file #%zd was not found on the list of selected files\n", i);
 		cdw_assert(file->fullpath != (char *) NULL, "ERROR: file #%zd has no fullpath\n", i);
 
+#ifndef NDEBUG
+		fprintf(stderr, "\n\n");
+#endif
 		cdw_vdm ("INFO: traversing file \"%s\"\n", file->fullpath);
+
 		cdw_rv_t crv = cdw_fs_traverse_path(file->fullpath, cdw_fs_visitor, &vdata);
 		if (crv != CDW_OK) {
 			cdw_vdm ("ERROR: failed to get dirsize of \"%s\" item\n", file->fullpath);
@@ -678,7 +720,7 @@ double cdw_file_manager_calculate_selected_files_size_mb(bool follow_symlinks)
 		} else {
 			/* this is to update size displayed next to file name
 			   in "selected files" view - the size may have changed
-			   after toggling "follow_symlinks" flag */
+			   after toggling "selected_follow_symlinks" flag */
 			file->size = vdata.size;
 
 			selected_files.size += vdata.size;
@@ -898,6 +940,8 @@ long long cdw_selected_files_get_size(void)
 
 
 /**
+   \param fs_browser
+
    \return CDW_NO if type of currently highlighted file is non-appendable
    \return CDW_OK on success
    \return CDW_ERROR on errors
@@ -926,7 +970,7 @@ cdw_rv_t cdw_file_selector_add_file_to_selected(cdw_fs_browser_t *fs_browser)
 	cdw_fs_visitor_data_t vdata;
 	vdata.size = 0;
 	vdata.has_file_over_4GB = false;
-	vdata.follow_symlinks = global_config.follow_symlinks;
+	vdata.follow_symlinks = selected_files.follow_symlinks;
 
 	cdw_rv_t crv = cdw_fs_traverse_path(file->fullpath, cdw_fs_visitor, &vdata);
 	if (crv == CDW_OK) {
@@ -938,7 +982,7 @@ cdw_rv_t cdw_file_selector_add_file_to_selected(cdw_fs_browser_t *fs_browser)
 			   size of selected files was updated in
 			   cdw_selected_files_clone_and_append_file(), and
 			   will be recounted again on file selector exit */
-			crv = cdw_main_window_volume_info_view_update(-1, -1, false, global_config.follow_symlinks);
+			crv = cdw_main_window_volume_info_view_update(-1, -1, false);
 			/* updating files info view may disrupt part of file
 			   selector window; redraw file selector */
 			cdw_list_display_refresh(fs_browser->display);
@@ -970,3 +1014,66 @@ cdw_rv_t cdw_file_selector_add_file_to_selected(cdw_fs_browser_t *fs_browser)
 }
 
 
+
+
+
+/*
+  \brief Look for \p path on list of selected files
+
+  This is just a very simple implementation. It does not attempt to
+  follow symbolic links that may be in selected files list.
+
+  The \p path is canonicalized before function starts looking for it
+  on list of selected files.
+
+  \p can_mode is canonicalization mode, as seen in
+  gnulib/lib/canonicalize.h. Not completely sure if this argument is
+  useful at all.
+
+  TODO: improve the function so that it covers more cases.
+
+  \param path - path to look for on list of selected files
+  \param can_mode - canonicalization mode
+*/
+cdw_rv_t cdw_selected_files_search(const char *path, int can_mode)
+{
+	char *fullpath = canonicalize_filename_mode(path, can_mode);
+	if (!fullpath) {
+		cdw_vdm ("ERROR: failed to canonicalize path \"%s\"\n", path);
+		return CDW_ERROR;
+	} else {
+		cdw_vdm ("INFO: canonicalized: \"%s\"\n", fullpath);
+	}
+
+
+	size_t n = strlen(fullpath);
+
+	size_t i = 0;
+	for (cdw_dll_item_t *f = selected_files.display->list; f; f = f->next) {
+		cdw_file_t *file = (cdw_file_t *) f->data;
+		cdw_assert(file, "ERROR: NULL file #%zd was not found on the list of selected files\n", i);
+		cdw_assert(file->fullpath, "ERROR: file #%zd has no fullpath\n", i);
+
+		size_t sel = strlen(file->fullpath);
+		int cmp = 0;
+		if (sel >= n) {
+			cmp = strncmp(fullpath, file->fullpath, n);
+		} else {
+			cmp = strncmp(fullpath, file->fullpath, n);
+		}
+
+		if (!cmp) {
+			free(fullpath);
+			fullpath = (char *) NULL;
+
+			return CDW_OK;
+		}
+
+		i++;
+	}
+
+	free(fullpath);
+	fullpath = (char *) NULL;
+
+	return CDW_NO;
+}
