@@ -12,18 +12,21 @@
 
 
 cdw_rv_t cdw_file_manager_init(void);
-void cdw_file_manager_clean(void);
+void     cdw_file_manager_clean(void);
 
 cdw_rv_t cdw_file_manager_handle_adding_to_selected_files(void);
 cdw_rv_t cdw_file_manager_handle_deleting_from_selected_files(void);
 
+void cdw_file_manager_follow_symlinks(bool selected_follow_symlinks);
+
 cdw_rv_t cdw_file_manager_create_selected_files_view(WINDOW *window);
 cdw_rv_t cdw_file_manager_regenerate_selected_files_view(void);
+void     cdw_file_manager_delete_selected_files_view(void);
 
-bool cdw_file_manager_any_files_selected(void);
+bool   cdw_file_manager_any_files_selected(void);
 size_t cdw_file_manager_number_of_selected_files(void);
-double cdw_file_manager_calculate_selected_files_size_mb(bool follow_symlinks);
-void cdw_file_manager_scan_selected_files(void);
+double cdw_file_manager_calculate_selected_files_size_mb(void);
+void   cdw_file_manager_scan_selected_files(void);
 
 cdw_rv_t cdw_file_manager_create_graftpoints_file(void);
 void cdw_file_manager_delete_graftpoints_file(void);
@@ -33,8 +36,7 @@ cdw_dll_item_t *cdw_file_manager_get_list_of_selected_files(void);
 
 bool      cdw_selected_files_file_over_4gb_present(void);
 long long cdw_selected_files_get_size(void);
-
+cdw_rv_t  cdw_selected_files_search(const char *path, int can_mode);
 
 
 #endif /* H_CDW_FILE_MANAGER */
-
