@@ -1,6 +1,6 @@
 /* cdw
  * Copyright (C) 2002 Varkonyi Balazs
- * Copyright (C) 2007 - 2012 Kamil Ignacak
+ * Copyright (C) 2007 - 2014 Kamil Ignacak
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 #define _BSD_SOURCE /* strdup() */
 
@@ -91,9 +91,6 @@ static struct cdw_file_picker {
 
 
 
-//static cdw_rv_t cdw_fs_ui_get_path_check(char *fullpath, int cdw_file_type, int perms, int new_or_existing);
-//static cdw_rv_t cdw_fs_ui_get_safe_path(const char *title, const char *message, char **buffer);
-
 static void     cdw_fs_ui_file_picker_init(struct cdw_file_picker *picker);
 static cdw_rv_t cdw_fs_ui_file_picker_build(struct cdw_file_picker *picker, const char *title, const char *message, const char *initial_fullpath);
 static cdw_rv_t cdw_fs_ui_file_picker_driver(struct cdw_file_picker *picker);
@@ -325,15 +322,34 @@ cdw_rv_t cdw_fs_ui_file_picker_driver(struct cdw_file_picker *picker)
 					   be taken from fs_browser */
 					cdw_file_t *file = cdw_fs_browser_get_current_file(picker->fs_browser);
 					if (file->is_ref_to_parent_dir) {
-						/* don't synchronize: don't put
-						   "/some/path/.." in input line,
-						   because it is annoying */
+						/* Don't put
+						   "/some/path/.." in
+						   input line, because
+						   it is annoying. */
+						char *cut = strdup(file->fullpath);
+						if (cut) {
+							/* Just to be 100% sure that me and the code base agree on contents of the fullpath string. */
+							cdw_assert (cut[file->name_start] == '.'
+								    && cut[file->name_start + 1] == '.',
+								    "ERROR: fullpath to parent dir does not end with '..': \"%s\"\n", file->fullpath);
+
+							cut[file->name_start] = '\0';
+							cdw_input_line_refresh_with_string(picker->input.input_line, cut);
+							cdw_string_set(&picker->fullpath, cut);
+							free(cut);
+							cut = (char *) NULL;
+						} else {
+							cdw_input_line_refresh_with_string(picker->input.input_line, file->fullpath);
+							cdw_string_set(&picker->fullpath, file->fullpath);
+						}
 					} else {
 						cdw_input_line_refresh_with_string(picker->input.input_line, file->fullpath);
 						cdw_string_set(&picker->fullpath, file->fullpath);
-						cdw_vdm ("INFO: SYNCHRONIZATION POINT: non-escape key \"%s\" in fs browser\n", cdw_ncurses_key_label(key));
-						cdw_vdm ("INFO: fs browser fullpath at synchronization point: \"%s\"\n", file->fullpath);
+
 					}
+					cdw_vdm ("INFO: SYNCHRONIZATION POINT: non-escape key \"%s\" in fs browser\n", cdw_ncurses_key_label(key));
+					cdw_vdm ("INFO: fs browser fullpath at synchronization point: \"%s\"\n", picker->fullpath);
+
 					if (key == CDW_KEY_TAB) {
 						break;
 					}
@@ -672,6 +688,3 @@ int cdw_fs_ui_file_picker_driver_on_enter_policy(struct cdw_file_picker *picker,
 		return -1;
 	}
 }
-
-
-
