@@ -1,6 +1,6 @@
 /* cdw
  * Copyright (C) 2002 Varkonyi Balazs
- * Copyright (C) 2007 - 2012 Kamil Ignacak
+ * Copyright (C) 2007 - 2014 Kamil Ignacak
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 /**
@@ -46,6 +46,7 @@
 #include "canonicalize.h"
 #include "cdw_config.h"
 
+/* FIXME: get rid of this extern. */
 extern cdw_config_t global_config;
 
 
@@ -85,7 +86,7 @@ static cdw_rv_t            cdw_fs_browser_change_dir_on_enter(cdw_fs_browser_t *
 cdw_fs_browser_t *cdw_fs_browser_new(WINDOW *window, const char *initial_fullpath)
 {
 	cdw_fs_browser_t *browser = cdw_fs_browser_new_base(window);
-	if (browser == (cdw_fs_browser_t *) NULL) {
+	if (!browser) {
 		cdw_vdm ("ERROR: failed to create browser's base\n");
 		return (cdw_fs_browser_t *) NULL;
 	}
@@ -105,7 +106,7 @@ cdw_fs_browser_t *cdw_fs_browser_new(WINDOW *window, const char *initial_fullpat
 		cdw_vdm ("WARNING: failed to get file name start in \"%s\"\n", initial_fullpath);
 	} else {
 		char *parent = strndup(initial_fullpath, (size_t) i);
-		cdw_assert (parent != (char *) NULL, "ERROR: failed to strndup fullpath \"%s\"\n", initial_fullpath);
+		cdw_assert (parent, "ERROR: failed to strndup fullpath \"%s\"\n", initial_fullpath);
 		rv = cdw_fs_browser_browse_to(browser, parent);
 		free(parent);
 		parent = (char *) NULL;
@@ -119,8 +120,10 @@ cdw_fs_browser_t *cdw_fs_browser_new(WINDOW *window, const char *initial_fullpat
 	   cdw_fs_get_initial_dirpath() tries to return one of following:
 	   current working dir, "home" dir, "/tmp" dir, or "/" (root) dir */
 	char *tmp = cdw_fs_get_initial_dirpath();
-	if (tmp != (char *) NULL) {
+	if (tmp) {
 		rv = cdw_fs_browser_browse_to(browser, tmp);
+		free(tmp);
+		tmp = (char *) NULL;
 		if (rv == 0) {
 			/* success, browsed to given location and refreshed the view */
 			return browser;
@@ -131,7 +134,7 @@ cdw_fs_browser_t *cdw_fs_browser_new(WINDOW *window, const char *initial_fullpat
 		cdw_vdm ("ERROR: can't get any safe initial dirpath for fs browser, this is bad\n");
 	}
 
-	cdw_fs_browser_internal_error_dialog(CDW_ERROR);
+	cdw_fs_browser_internal_error_dialog(CDW_FS_CHECK_GEN_ERROR);
 	cdw_fs_browser_delete(&browser);
 	return (cdw_fs_browser_t *) NULL;
 }
@@ -154,10 +157,10 @@ cdw_fs_browser_t *cdw_fs_browser_new(WINDOW *window, const char *initial_fullpat
 */
 cdw_fs_browser_t *cdw_fs_browser_new_base(WINDOW *window)
 {
-	cdw_assert (window != (WINDOW *) NULL, "ERROR: \"window\" argument is NULL\n");
+	cdw_assert (window, "ERROR: \"window\" argument is NULL\n");
 
-	cdw_fs_browser_t *browser = (cdw_fs_browser_t *) malloc (sizeof (cdw_fs_browser_t));
-	if (browser == (cdw_fs_browser_t *) NULL) {
+	cdw_fs_browser_t *browser = (cdw_fs_browser_t *) malloc(sizeof (cdw_fs_browser_t));
+	if (!browser) {
 		cdw_vdm ("ERROR: failed to allocate memory for fs browser\n");
 		return (cdw_fs_browser_t *) NULL;
 	}
@@ -173,7 +176,7 @@ cdw_fs_browser_t *cdw_fs_browser_new_base(WINDOW *window)
 	browser->display = cdw_list_display_new(window, n_lines, n_cols, 1, 1, CDW_COLORS_DIALOG);
 	if (browser->display == (CDW_LIST_DISPLAY *) NULL) {
 		cdw_vdm ("ERROR: failed to create file_browser display\n");
-		cdw_fs_browser_internal_error_dialog(CDW_ERROR);
+		cdw_fs_browser_internal_error_dialog(CDW_FS_CHECK_GEN_ERROR);
 
 		free(browser);
 		browser = (cdw_fs_browser_t *) NULL;
@@ -277,7 +280,7 @@ unsigned long long cdw_fs_browser_read_dir_content(cdw_dll_item_t **list, const
 		   disc - the disc wasn't reconnected (?) after coming from
 		   suspension to RAM */
 		cdw_vdm ("ERROR: scandir() returns -1 for dirpath \"%s\"\n", dirpath);
-		cdw_fs_browser_internal_error_dialog(CDW_ERROR);
+		cdw_fs_browser_internal_error_dialog(CDW_FS_CHECK_GEN_ERROR);
 		return 0;
 	} else if (n_files == 0) {
 		/* not going to happen, with scandir() called with one(),
@@ -286,7 +289,7 @@ unsigned long long cdw_fs_browser_read_dir_content(cdw_dll_item_t **list, const
 		return 0;
 	} else {
 		unsigned long long n = (unsigned long long) n_files;
-		unsigned long long cp = cdw_fs_copy_dirent_to_list(list, dirpath, eps, n, global_config.fs.display_hidden_files);
+		unsigned long long cp = cdw_fs_copy_dirent_to_list(list, dirpath, eps, n, global_config.general.display_hidden_files);
 
 		/* eps is no longer needed, all interesting information about
 		   directory content is now in display->list */
@@ -306,6 +309,7 @@ unsigned long long cdw_fs_browser_read_dir_content(cdw_dll_item_t **list, const
 			cdw_vdm ("ERROR: failed to copy dirent to list for dirpath \"%s\"\n", dirpath);
 			return 0;
 		} else {
+#if 0
 #ifndef NDEBUG
 			cdw_vdm ("INFO: Content of current directory \"%s\":\n", dirpath);
 			for (unsigned long long i = 0; i < cp; i++) {
@@ -314,6 +318,7 @@ unsigned long long cdw_fs_browser_read_dir_content(cdw_dll_item_t **list, const
 				ssize_t f = cdw_fs_get_filename_start(file->fullpath);
 				cdw_vdm ("INFO:       file #%6lld = \"%s\"\n", i, file->fullpath + f);
 			}
+#endif
 #endif
 			return cp;
 		}
@@ -350,7 +355,7 @@ unsigned long long cdw_fs_browser_read_dir_content(cdw_dll_item_t **list, const
 */
 cdw_rv_t cdw_fs_browser_change_dir_on_enter(cdw_fs_browser_t *browser)
 {
-	cdw_assert (browser->display != (CDW_LIST_DISPLAY *) NULL, "ERROR: display is null\n");
+	cdw_assert (browser->display, "ERROR: display is NULL\n");
 	cdw_assert (browser->display->n_items > browser->display->current_item_ind,
 		    "ERROR, item index (0-based) is %zd but number of items is %zd\n",
 		    browser->display->current_item_ind, browser->display->n_items);
@@ -372,9 +377,16 @@ cdw_rv_t cdw_fs_browser_change_dir_on_enter(cdw_fs_browser_t *browser)
 	if (file->is_ref_to_parent_dir) {
 		/* "/some/dir/../", remove last dir from the path */
 		new_dirpath = cdw_fs_shorten_fullpath(file);
-		if (new_dirpath == (char *) NULL) {
+		if (!new_dirpath) {
 			cdw_vdm ("ERROR: failed to shorten fullpath \"%s\"\n", file->fullpath);
 			return CDW_ERROR;
+		} else if (!strcmp(new_dirpath, "/..") || !strcmp(new_dirpath, "/")) {
+			/* Don't attempt to re-read root directory
+			   again. This may fail because the code will
+			   try to find a (null) file to browse to. */
+			free(new_dirpath);
+			new_dirpath = (char *) NULL;
+			return CDW_OK;
 		}
 
 		/* browse_to_file() moves cursor (focus) to directory item from
@@ -384,7 +396,7 @@ cdw_rv_t cdw_fs_browser_change_dir_on_enter(cdw_fs_browser_t *browser)
 	} else {
 		/* canonicalize because current item may be a link */
 		new_dirpath = canonicalize_filename_mode(file->fullpath, CAN_MISSING);
-		if (new_dirpath == (char *) NULL) {
+		if (!new_dirpath) {
 			/* canonicalization of dirpath failed */
 			cdw_vdm ("ERROR: failed to canonicalize path \"%s\"\n", file->fullpath);
 			return CDW_ERROR;
@@ -393,24 +405,10 @@ cdw_rv_t cdw_fs_browser_change_dir_on_enter(cdw_fs_browser_t *browser)
 	}
 
 	if (rv != 0) {
-		cdw_vdm ("ERROR: failed to browse to new dirpath \"%s\"\n", new_dirpath);
+		cdw_vdm ("ERROR: failed to browse to new dirpath \"%s\": \"%s\"\n", new_dirpath, cdw_fs_check_get_debug_message(rv));
+		cdw_fs_browser_internal_error_dialog(rv);
 
-		if (rv == CDW_FS_CHECK_E_PERM_NO_X) {
-			cdw_vdm ("ERROR: no \"exec\" permissions\n");
-			cdw_fs_browser_internal_error_dialog(rv);
-
-		} else if (rv == CDW_FS_CHECK_E_PERM_NO_R) {
-			cdw_vdm ("ERROR: no \"read\" permissions\n");
-			cdw_fs_browser_internal_error_dialog(rv);
-
-		} else if (rv == CDW_FS_CHECK_SYS_ERROR) {
-			cdw_vdm ("ERROR: system error\n");
-			cdw_fs_browser_internal_error_dialog(rv);
-
-		} else {
-			cdw_vdm ("ERROR: reason unknown\n");
-			cdw_fs_browser_internal_error_dialog(CDW_ERROR);
-		}
+		/* Refresh the list after displaying dialog window. */
 		cdw_list_display_refresh(browser->display);
 	}
 	free(new_dirpath);
@@ -485,10 +483,10 @@ int cdw_fs_browser_driver(cdw_fs_browser_t *browser)
 				    "ERROR: index of current file is larger than number of files\n");
 #endif
 		} else if (key == '.') {
-			if (global_config.fs.display_hidden_files) {
-				global_config.fs.display_hidden_files = false;
+			if (global_config.general.display_hidden_files) {
+				global_config.general.display_hidden_files = false;
 			} else {
-				global_config.fs.display_hidden_files = true;
+				global_config.general.display_hidden_files = true;
 			}
 			char *f = cdw_fs_browser_get_current_fullpath(browser);
 			/* FIXME: check return values */
@@ -500,7 +498,7 @@ int cdw_fs_browser_driver(cdw_fs_browser_t *browser)
 		} else if (key == KEY_BACKSPACE) {
 			cdw_file_t *file = cdw_fs_browser_get_current_file(browser);
 			char *new_dir = cdw_fs_shorten_fullpath(file);
-			if (new_dir != (char *) NULL) {
+			if (new_dir) {
 				cdw_fs_browser_browse_to_file(browser, new_dir);
 				free(new_dir);
 				new_dir = (char *) NULL;
@@ -548,41 +546,13 @@ int cdw_fs_browser_driver(cdw_fs_browser_t *browser)
 
    Function displays dialog window with error message. Function created to
    avoid repetition of the same dialog in two places.
-
-   FIXME: the function accepts values of regular type int
-   and of type cdw_rv_t, but type of its argument is int.
 */
 void cdw_fs_browser_internal_error_dialog(int rv)
 {
-	char *message = (char *) NULL;
-	if (rv == CDW_ERROR) {
-		/* 2TRANS: this is message in dialog window */
-		message = _("Unexpected error, perhaps some file has been deleted. Please close this window and open it again.");
-	} else if (rv == CDW_FS_CHECK_E_PERM_NO_X) {
-		/* 2TRANS: this is message in dialog window;
-		   "change directory" means "enter into directory" */
-		message = _("Cannot change directory: wrong permissions.");
-	} else if (rv == CDW_FS_CHECK_E_PERM_NO_R) {
-		/* 2TRANS: this is message in dialog window;
-		   "read directory" means "read content of directory" */
-		message = _("Cannot read directory: wrong permissions.");
-	} else if (rv == CDW_FS_CHECK_SYS_ERROR) {
-		/* 2TRANS: this is message in dialog window:
-		   user highlighted a file and pressed enter,
-		   but the file probably does not exit */
-		message = _("File does not exists or cannot change directory.");
-	} else if (rv == CDW_NO) {
-		/* 2TRANS: this is message in dialog window. Some
-		   function returned error value. No further action
-		   will be performed, no other explanations provided */
-		message = _("Cannot display content of current directory. Please close this window and open it again.");
-	} else {
-		return;
-	}
+	const char *message = cdw_fs_check_get_message(rv);
 
 	/* 2TRANS: this is title of dialog window */
-	cdw_buttons_dialog(_("Error"), message,
-			   CDW_BUTTONS_OK, CDW_COLORS_ERROR);
+	cdw_buttons_dialog(_("Error"), message,  CDW_BUTTONS_OK, CDW_COLORS_ERROR);
 
 	return;
 }
@@ -593,11 +563,11 @@ void cdw_fs_browser_internal_error_dialog(int rv)
 
 cdw_file_t *cdw_fs_browser_get_current_file(cdw_fs_browser_t *browser)
 {
-	cdw_assert (browser != (cdw_fs_browser_t *) NULL, "ERROR: browser pointer is NULL\n");
+	cdw_assert (browser, "ERROR: browser pointer is NULL\n");
 
 	void *data = cdw_list_display_get_current_item_data(browser->display);
-	if (data == (void *) NULL) {
-		cdw_assert (data != (void *) NULL,
+	if (!data) {
+		cdw_assert (data,
 			    "ERROR: failed to fetch current file #%zd from fs browser->display\n",
 			    browser->display->current_item_ind);
 		return (cdw_file_t *) NULL;
@@ -616,7 +586,10 @@ int cdw_fs_browser_browse_to(cdw_fs_browser_t *browser, const char *fullpath)
 {
 	struct stat finfo;
 	if (stat(fullpath, &finfo) == -1) {
-		cdw_vdm ("ERROR: failed to stat() \"%s\"\n", fullpath);
+		/* This is not an error. It may be a perfectly normal
+		   situation that a file has existed at some point,
+		   but it no longer does. */
+		cdw_vdm ("WARNING: failed to stat() \"%s\"\n", fullpath);
 		return -1;
 	}
 
@@ -700,7 +673,7 @@ int cdw_fs_browser_browse_to_file(cdw_fs_browser_t *browser, const char *fullpat
 	ssize_t f = cdw_fs_get_filename_start(fullpath);
 	cdw_assert (f >= 0, "ERROR: can't get start of file name in \"%s\"\n", fullpath);
 	char *dirpath = strndup(fullpath, (size_t) f);
-	cdw_assert (dirpath != (char *) NULL, "ERROR: failed to strndup() dirpath from \"%s\"\n", fullpath);
+	cdw_assert (dirpath, "ERROR: failed to strndup() dirpath from \"%s\"\n", fullpath);
 
 	int rv = cdw_fs_browser_browse_into_dir(browser, dirpath);
 	if (rv != 0) {
@@ -746,7 +719,7 @@ int cdw_fs_browser_browse_to_file(cdw_fs_browser_t *browser, const char *fullpat
 			   this is not an error, handle this gracefully */
 			cdw_vdm ("WARNING: file \"%s\" not found in dir \"%s\"\n", fullpath + f, dirpath);
 			ssize_t start = cdw_fs_get_filename_start(fullpath);
-			if (cdw_fs_is_hidden(fullpath + start) && !global_config.fs.display_hidden_files) {
+			if (cdw_fs_is_hidden(fullpath + start) && !global_config.general.display_hidden_files) {
 				cdw_vdm ("INFO: it may be because displaying hidden files has been disabled\n");
 				cdw_list_display_scroll_to(browser->display, 0, 0, true);
 				return 0;
@@ -764,11 +737,11 @@ int cdw_fs_browser_browse_to_file(cdw_fs_browser_t *browser, const char *fullpat
 char *cdw_fs_browser_get_current_dirpath(cdw_fs_browser_t *browser)
 {
 	cdw_file_t *file = cdw_fs_browser_get_current_file(browser);
-	cdw_assert (file != (cdw_file_t *) NULL, "ERROR: can't get current file\n");
+	cdw_assert (file, "ERROR: can't get current file\n");
 	ssize_t i = cdw_fs_get_filename_start(file->fullpath);
 	cdw_assert (i > 0, "ERROR: can't get file name start\n");
 	char *dirpath = strndup(file->fullpath, (size_t) i);
-	cdw_assert (dirpath != (char *) NULL, "ERROR: can't strdup dirpath\n");
+	cdw_assert (dirpath, "ERROR: can't strdup dirpath\n");
 	return dirpath;
 }
 
@@ -779,12 +752,12 @@ char *cdw_fs_browser_get_current_dirpath(cdw_fs_browser_t *browser)
 char *cdw_fs_browser_get_current_printable_dirpath(cdw_fs_browser_t *browser)
 {
 	cdw_file_t *file = cdw_fs_browser_get_current_file(browser);
-	cdw_assert (file != (cdw_file_t *) NULL, "ERROR: can't get current file\n");
-	if (file->printable_fullpath != (char *) NULL) {
+	cdw_assert (file, "ERROR: can't get current file\n");
+	if (file->printable_fullpath) {
 		ssize_t i = cdw_fs_get_filename_start(file->printable_fullpath);
 		cdw_assert (i > 0, "ERROR: can't get file name start\n");
 		char *dirpath = strndup(file->printable_fullpath, (size_t) i);
-		cdw_assert (dirpath != (char *) NULL, "ERROR: can't strdup dirpath\n");
+		cdw_assert (dirpath, "ERROR: can't strdup dirpath\n");
 		return dirpath;
 	} else {
 		return cdw_fs_browser_get_current_dirpath(browser);
@@ -798,8 +771,8 @@ char *cdw_fs_browser_get_current_printable_dirpath(cdw_fs_browser_t *browser)
 char *cdw_fs_browser_get_current_fullpath(cdw_fs_browser_t *browser)
 {
 	cdw_file_t *file = cdw_fs_browser_get_current_file(browser);
-	cdw_assert (file != (cdw_file_t *) NULL, "ERROR: can't get current file\n");
-	cdw_assert (file->fullpath != (char *) NULL, "ERROR: current file has no fullpath\n");
+	cdw_assert (file, "ERROR: can't get current file\n");
+	cdw_assert (file->fullpath, "ERROR: current file has no fullpath\n");
 	/* file->fullpath is a valid pointer at this point, but if
 	   you will pass it to function that re-reads (and thus reallocates)
 	   list with current dir listing, then the pointer becomes
@@ -856,7 +829,7 @@ void cdw_fs_browser_help_window(cdw_fs_browser_t *browser)
 					_("Help"),
 					/* 2TRANS: this is helper text at the bottom of help window */
 					_("Press any key to close"));
-	if (window == (WINDOW *) NULL) {
+	if (!window) {
 		cdw_vdm ("ERROR: failed to create new window\n");
 		return;
 	}
@@ -874,5 +847,3 @@ void cdw_fs_browser_help_window(cdw_fs_browser_t *browser)
 
 	return;
 }
-
-
