@@ -1,6 +1,6 @@
 /* cdw
  * Copyright (C) 2002 Varkonyi Balazs
- * Copyright (C) 2007 - 2012 Kamil Ignacak
+ * Copyright (C) 2007 - 2014 Kamil Ignacak
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 
@@ -39,11 +39,14 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 
+#include <cdio/iso9660.h>
+
 #include <fcntl.h>
 
 #include "cdw_ofs.h"
 #include "cdw_debug.h"
 #include "cdw_ext_tools.h"
+#include "cdw_string.h"
 
 
 /* Look-up table for labels/names of optical file systems */
@@ -106,8 +109,8 @@ cdw_ofs_t *cdw_ofs_new(void)
 
 	ofs->fd = -1;
 	ofs->type = 0; /* none */
-	ofs->type_label = (char *) NULL;
-	ofs->n_sectors = -1;
+	ofs->type_label = strdup(cdw_ofs_short_label(ofs->type));
+	ofs->n_sectors = 0; /* Initially assume empty disc with no OFS. Its size would be zero, not -1. */
 
 	ofs->cdw_tool = -1; /* external_tools/cdw_ext_tools.h/enum cdw_tool/CDW_TOOL_NONE */
 
@@ -176,9 +179,9 @@ cdw_rv_t cdw_ofs_get(cdw_ofs_t *ofs, const char *fullpath, cdio_fs_t type)
 
 	ofs->type = type;
 
-	ofs->type_label = strdup(cdw_ofs_short_label(type));
+	cdw_string_set(&(ofs->type_label), cdw_ofs_short_label(type));
 	if (!ofs->type_label) {
-		cdw_vdm ("ERROR: strdup()\n");
+		cdw_vdm ("ERROR: cdw_string_set()\n");
 		return CDW_ERROR;
 	}
 
@@ -504,7 +507,7 @@ cdw_ofs_t *cdw_ofs_copy(cdw_ofs_t *ofs)
 	copy->type = ofs->type;
 
 	if (success && ofs->type_label) {
-		copy->type_label = strdup(ofs->type_label);
+		cdw_string_set(&(copy->type_label), ofs->type_label);
 		if (!copy->type_label) {
 			success = false;
 		}
@@ -592,3 +595,20 @@ void cdw_ofs_resolve_tool(cdw_ofs_t *ofs)
 
 	return;
 }
+
+
+
+
+
+bool cdw_ofs_is_iso9660_file(const char *fullpath)
+{
+	iso9660_t *iso = iso9660_open(fullpath);
+	if (!iso) {
+		cdw_vdm ("INFO: %s is not ISO\n", fullpath);
+		return false;
+	} else {
+		cdw_vdm ("INFO: %s is ISO\n", fullpath);
+		iso9660_close(iso);
+		return true;
+	}
+}
