@@ -1,6 +1,6 @@
 /* cdw
  * Copyright (C) 2002 Varkonyi Balazs
- * Copyright (C) 2007 - 2012 Kamil Ignacak
+ * Copyright (C) 2007 - 2014 Kamil Ignacak
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #include <stdlib.h>
@@ -141,7 +141,7 @@ cdw_rv_t cdw_calculate_digest(cdw_id_t mode, const char *file_fullpath)
 		/* when cdw is run in login console and there are some
 		   disc read errors, OS prints some error messages to the
 		   console that overwrite cdw ui; this line fixes it */
-		cdw_main_ui_main_window_wrefresh();
+		cdw_main_window_wrefresh();
 		cdw_processwin_wrefresh();
 
 		if (crv != CDW_OK) {
@@ -296,7 +296,7 @@ void cdw_calculate_digest_summary(cdw_id_t mode, cdw_id_t tool_id)
 				   CDW_BUTTONS_OK, CDW_COLORS_WARNING);
 		}
 
-		cdw_main_ui_main_window_wrefresh();
+		cdw_main_window_wrefresh();
 
 		/* Add some '\n' chars to keep strings grouped and aligned;
 		   especially important for digest strings - if they start in the
@@ -646,8 +646,8 @@ cdw_rv_t cdw_verify(void)
 	}
 
 	char *fullpath = (char *) NULL;
-	if (global_config.iso_image_full_path != (char *) NULL) {
-		fullpath = strdup(global_config.iso_image_full_path);
+	if (global_config.general.image_fullpath) {
+		fullpath = strdup(global_config.general.image_fullpath);
 	} else {
 		fullpath = cdw_fs_get_initial_dirpath();
 	}
@@ -663,11 +663,13 @@ cdw_rv_t cdw_verify(void)
 						     &fullpath, CDW_FS_FILE, R_OK, CDW_FS_EXISTING);
 
 		if (crv == CDW_CANCEL || crv == CDW_ERROR) {
+			free(fullpath);
+			fullpath = (char *) NULL;
 			return crv;
 		}
 	}
 
-	cdw_main_ui_main_window_wrefresh();
+	cdw_main_window_wrefresh();
 
 	cdw_rv_t crv = cdw_calculate_digest(mode, fullpath);
 	free(fullpath);
@@ -675,4 +677,3 @@ cdw_rv_t cdw_verify(void)
 
 	return crv;
 }
-
