@@ -1,6 +1,6 @@
 /* cdw
  * Copyright (C) 2002 Varkonyi Balazs
- * Copyright (C) 2007 - 2012 Kamil Ignacak
+ * Copyright (C) 2007 - 2014 Kamil Ignacak
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #define _GNU_SOURCE /* strndup */
@@ -117,7 +117,7 @@ cdw_rv_t cdw_read_disc(void)
 	cdw_disc_t *disc = cdw_disc_new();
 	cdw_rv_t crv = cdw_disc_get(disc);
 	if (crv != CDW_OK) {
-		cdw_main_ui_main_window_wrefresh();
+		cdw_main_window_wrefresh();
 		cdw_disc_delete(&disc);
 		return crv;
 	}
@@ -142,7 +142,7 @@ cdw_rv_t cdw_read_disc(void)
 		crv = cdw_read_disc_read_data_disc_prepare(disc);
 	}
 	/* this refreshes UI after file picker and before processwin */
-	cdw_main_ui_main_window_wrefresh();
+	cdw_main_window_wrefresh();
 
 	if (crv != CDW_OK) {
 		if (crv == CDW_ERROR) {
@@ -154,7 +154,7 @@ cdw_rv_t cdw_read_disc(void)
 					   _("Cannot open disc."),
 					   CDW_BUTTONS_OK, CDW_COLORS_ERROR);
 		}
-		cdw_main_ui_main_window_wrefresh();
+		cdw_main_window_wrefresh();
 
 		if (audio_file_name != (char *) NULL) {
 			free(audio_file_name);
@@ -176,27 +176,27 @@ cdw_rv_t cdw_read_disc(void)
 		free(audio_file_name);
 		audio_file_name = (char *) NULL;
 	} else {
-		crv = cdw_read_disc_read_data_track(disc, global_config.iso_image_full_path);
+		crv = cdw_read_disc_read_data_track(disc, global_config.general.image_fullpath);
 	}
 
 	cdw_disc_delete(&disc);
 
 	/* when cdw is run in login console and there are some disc read
 	   errors, OS prints some error messages to the console that
-	   overwrite cdw ui; call to cdw_main_ui_main_window_wrefresh()
+	   overwrite cdw ui; call to cdw_main_window_wrefresh()
 	   conveniently fixes it */
 	if (crv == CDW_OK) {
 		/* 2TRANS: this is message in dialog window: reading
 		   a disc is finished. I'm not adding "successfully",
 		   because this is not 100% sure. */
 		cdw_processwin_destroy(_("Finished."), true);
-		cdw_main_ui_main_window_wrefresh();
+		cdw_main_window_wrefresh();
 		return CDW_OK;
 	} else {
 		/* 2TRANS: this is message in dialog window: reading
 		   a disc is finished, but with errors */
 		cdw_processwin_destroy(_("Finished. Some errors occurred."), true);
-		cdw_main_ui_main_window_wrefresh();
+		cdw_main_window_wrefresh();
 		/* 2TRANS: this is title of dialog window */
 		cdw_buttons_dialog(_("Error"),
 				   /* 2TRANS: this is message in dialog window */
@@ -220,7 +220,7 @@ cdw_rv_t cdw_read_disc_read_audio_disc_prepare(char **audio_file_name)
 					     _("Enter path to existing output directory"),
 					     &(global_config.audiodir),
 					     CDW_FS_DIR, R_OK|W_OK|X_OK, CDW_FS_EXISTING);
-	cdw_main_ui_main_window_wrefresh();
+	cdw_main_window_wrefresh();
 	if (crv != CDW_OK) {
 		/* user failed to provide correct path when
 		   asked X times, or pressed ESCAPE */
@@ -248,7 +248,7 @@ cdw_rv_t cdw_read_disc_read_data_disc_prepare(cdw_disc_t *disc)
 						  /* 2TRANS: this is message in dialog window */
 						  _("You are attempting to read multi-track disc. cdw can't read second and following tracks, so only first track will be read. Continue?"),
 						  CDW_BUTTONS_OK_CANCEL, CDW_COLORS_WARNING);
-		cdw_main_ui_main_window_wrefresh();
+		cdw_main_window_wrefresh();
 		if (crv != CDW_OK) {
 			cdw_vdm ("INFO: returning after multi-track prompt\n");
 			return crv;
@@ -261,7 +261,7 @@ cdw_rv_t cdw_read_disc_read_data_disc_prepare(cdw_disc_t *disc)
 					     /* 2TRANS: this is label in dialog
 						window below it is input field */
 					     _("Select new or existing image file"),
-					     &(global_config.iso_image_full_path),
+					     &(global_config.general.image_fullpath),
 					     CDW_FS_FILE, R_OK|W_OK,
 					     CDW_FS_NEW | CDW_FS_EXISTING);
 	if (crv != CDW_OK) {
@@ -322,7 +322,7 @@ cdw_rv_t cdw_read_disc_read_audio_tracks(cdw_disc_t *disc, const char *filename)
 		   disrupt cdw UI; these lines refresh the UI; sleep time
 		   was selected by experimenting on my old 686 machine */
 		sleep(1);
-		cdw_main_ui_main_window_wrefresh();
+		cdw_main_window_wrefresh();
 		cdw_processwin_wrefresh();
 
 	} /* for */
@@ -358,7 +358,7 @@ cdw_rv_t cdw_read_disc_read_data_track(cdw_disc_t *disc, const char *fullpath)
 	   disrupt cdw UI; these lines refresh the UI; sleep time
 	   was selected by experimenting on my old 686 machine */
 	sleep(1);
-	cdw_main_ui_main_window_wrefresh();
+	cdw_main_window_wrefresh();
 	cdw_processwin_wrefresh();
 
 	if (retval != CDW_OK) {
@@ -490,7 +490,7 @@ bool cdw_read_disc_is_proper(cdw_disc_t *disc)
 				   /* 2TRANS: this message in dialog window */
 				   _("Disc in drive is empty, can't read any data from the disc."),
 				   CDW_BUTTONS_OK, CDW_COLORS_DIALOG);
-		cdw_main_ui_main_window_wrefresh();
+		cdw_main_window_wrefresh();
 
 		return false;
 	} else if (disc->state_empty == CDW_UNKNOWN) {
@@ -499,7 +499,7 @@ bool cdw_read_disc_is_proper(cdw_disc_t *disc)
 						  /* 2TRANS: this message in dialog window */
 						  _("Disc in drive may be empty and reading from disc may fail. Continue?"),
 						  CDW_BUTTONS_OK_CANCEL, CDW_COLORS_DIALOG);
-		cdw_main_ui_main_window_wrefresh();
+		cdw_main_window_wrefresh();
 		if (crv != CDW_OK) {
 			return false;
 		}
@@ -513,7 +513,7 @@ bool cdw_read_disc_is_proper(cdw_disc_t *disc)
 		cdw_buttons_dialog(_("Information"),
 				   message,
 				   CDW_BUTTONS_OK, CDW_COLORS_DIALOG);
-		cdw_main_ui_main_window_wrefresh();
+		cdw_main_window_wrefresh();
 		return false;
 	}
 
@@ -525,36 +525,25 @@ bool cdw_read_disc_is_proper(cdw_disc_t *disc)
 
 char *cdw_read_disc_get_audio_file_name(void)
 {
+	char filename[CDW_READ_DICS_TRACK_CORE_NAME_LEN + 1];
 	/* 2TRANS: this is main part of name of audio tracks ripped from
-	   cd, no more than TRACK_CORE_NAME_LEN = 30 chars */
-	char *filename = strndup(_("track"), CDW_READ_DICS_TRACK_CORE_NAME_LEN);
-	if (filename == (char *) NULL) {
-		return (char *) NULL;
-	}
+	   CD, no more than TRACK_CORE_NAME_LEN = 30 chars */
+	strncpy(filename, _("track"), CDW_READ_DICS_TRACK_CORE_NAME_LEN);
+	filename[CDW_READ_DICS_TRACK_CORE_NAME_LEN] = '\0';
 
-	cdw_input_data_t data;
-
-	data.attempts_max = 3; /* how many attempts? */
 	/* 2TRANS: this is title of dialog window where user have to
-	   enter core of track file names */
-	data.window_title = _("File name");   /* title of input window and error dialogs */
-	/* 2TRANS: this is label in dialog window, below it is an input field */
-	data.prompt_message = _("Enter core of track file names (no more than 30 characters).");  /* message in input window */
-	data.input_type = CDW_NCURSES_INPUT_NONE;
-	data.chars_max = CDW_READ_DICS_TRACK_CORE_NAME_LEN;    /* maximal length of string */
-	data.buffer = &filename;
-	/* error message displayed at the end in case of failure */
-	/* 2TRANS: this is error message displayed in dialog window
-	   when getting a file name from user failed */
-	data.error_message = _("Can't get valid file name, aborting.");
-
-	cdw_rv_t crv = cdw_input_dialog(&data);
-	cdw_main_ui_main_window_wrefresh();
+	   enter core of track file names. */
+	cdw_rv_t crv = cdw_input_dialog(_("File name"),
+					/* 2TRANS: this is label in
+					   dialog window, below it is
+					   an input field */
+					_("Enter core of track file names (no more than 30 characters)."),
+					  CDW_READ_DICS_TRACK_CORE_NAME_LEN,
+					  filename);
+	cdw_main_window_wrefresh();
 	if (crv == CDW_OK) {
-		return filename;
+		return strdup(filename);
 	} else {
-		free(filename);
-		filename = (char *) NULL;
 		if (crv == CDW_CANCEL) {
 			;
 		} else {
