@@ -1,6 +1,6 @@
 /* cdw
  * Copyright (C) 2002 Varkonyi Balazs
- * Copyright (C) 2007 - 2012 Kamil Ignacak
+ * Copyright (C) 2007 - 2014 Kamil Ignacak
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 #define _BSD_SOURCE /* strdup() */
 
@@ -58,9 +58,6 @@ static CDW_DROPDOWN *cdw_erase_wizard_make_format_mode_dropdown(WINDOW *window,
 static cdw_rv_t cdw_erase_wizard_initial_warning(cdw_disc_type_t disc_type);
 static void     cdw_erase_wizard_print_debug_info(cdw_task_t *task, bool format_mode_visible);
 
-static int cdw_erase_wizard_on_enter_on_cancel(cdw_form_t *cdw_form, void *dummy);
-static int cdw_erase_wizard_on_enter_on_erase(cdw_form_t *cdw_form, void *dummy);
-
 
 static struct {
 	cdw_form_t *cdw_form;
@@ -90,12 +87,6 @@ static cdw_task_t *local_task = (cdw_task_t *) NULL;
 #define first_col                  2 /* main message and some labels start in leftmost column */
 #define second_col                40
 #define top_label_row              2 /* main message is displayed on top of window */
-#define erase_mode_row             2
-#define erase_speed_row            5
-#define format_mode_row            8 /* label above of button invoking configuration window */
-#define eject_row                 11
-#define buttons_row               13 /* Erase and Cancel buttons are at the bottom of window */
-
 #define window_n_cols             52
 #define window_n_lines            20
 #define subwindow_n_cols           (window_n_cols - 2)
@@ -121,8 +112,8 @@ enum {
 	f_eject_cb,
 	f_eject_l,
 
-	f_erase_button_i,
-	f_cancel_button_i
+	f_erase_button_b,
+	f_cancel_button_b
 };
 
 
@@ -165,7 +156,7 @@ cdw_rv_t cdw_erase_wizard(cdw_task_t *task, cdw_disc_t *disc)
 	if (crv == CDW_CANCEL) {
 		return CDW_CANCEL;
 	}
-	cdw_main_ui_main_window_wrefresh();
+	cdw_main_window_wrefresh();
 
 	/* TODO: there is a problem with implicit initialization of
 	   dropdowns in the wizard: dropdowns are initialized with
@@ -196,7 +187,7 @@ cdw_rv_t cdw_erase_wizard(cdw_task_t *task, cdw_disc_t *disc)
 		CDW_DROPDOWN *dd = (CDW_DROPDOWN *) NULL;
 		if (wizard.format_mode_dropdown_visible) {
 			dd = cdw_form_get_dropdown(wizard.cdw_form, f_format_mode_dd);
-			task->erase.format_mode = cdw_dropdown_get_current_item_id(dd);
+			task->erase.dvd_rw_format_mode = cdw_dropdown_get_current_item_id(dd);
 		}
 		dd = cdw_form_get_dropdown(wizard.cdw_form, f_erase_speed_dd);
 		task->erase.speed_id = cdw_dropdown_get_current_item_id(dd);
@@ -213,7 +204,7 @@ cdw_rv_t cdw_erase_wizard(cdw_task_t *task, cdw_disc_t *disc)
 	cdw_erase_wizard_destroy();
 
 	/* redraw parent */
-	cdw_main_ui_main_window_wrefresh();
+	cdw_main_window_wrefresh();
 
 	return crv;
 }
@@ -224,7 +215,7 @@ cdw_rv_t cdw_erase_wizard(cdw_task_t *task, cdw_disc_t *disc)
 
 cdw_rv_t cdw_erase_wizard_driver(void)
 {
-	int fi = f_cancel_button_i; /* initial focus on "cancel" button */
+	int fi = f_cancel_button_b; /* initial focus on "cancel" button */
 	int key = 'a'; /* safe initial value */
 
 	while (key != CDW_KEY_ESCAPE && key != 'q' && key != 'Q') {
@@ -235,13 +226,13 @@ cdw_rv_t cdw_erase_wizard_driver(void)
 		   buttons */
 		if (key == CDW_KEY_ENTER) {
 			fi = field_index(current_field(wizard.cdw_form->form));
-			if (fi == f_erase_button_i) {
+			if (fi == f_erase_button_b) {
 
 				/* flush */
 				form_driver(wizard.cdw_form->form, REQ_VALIDATION);
 
 				return CDW_OK;
-			} else if (fi == f_cancel_button_i) {
+			} else if (fi == f_cancel_button_b) {
 				return CDW_CANCEL;
 			} else {
 				;
@@ -285,20 +276,12 @@ void cdw_erase_wizard_init(void)
 */
 void cdw_erase_wizard_destroy(void)
 {
-	if (wizard.cdw_form->subwindow != (WINDOW *) NULL) {
-		delwin(wizard.cdw_form->subwindow);
-		wizard.cdw_form->subwindow = (WINDOW *) NULL;
-	}
-
-	if (wizard.cdw_form->window != (WINDOW *) NULL) {
-		delwin(wizard.cdw_form->window);
-		wizard.cdw_form->window = (WINDOW *) NULL;
-	}
-
-	if (wizard.cdw_form != (cdw_form_t *) NULL) {
-		cdw_form_delete_form_objects(wizard.cdw_form);
-		cdw_form_delete(&(wizard.cdw_form));
-	}
+	/* This order of these four function calls minimizes number of
+	   problems reported by valgrind. */
+	cdw_form_delete_form_objects(wizard.cdw_form);
+	cdw_window_delete(&wizard.cdw_form->subwindow);
+	cdw_window_delete(&wizard.cdw_form->window);
+	cdw_form_delete(&(wizard.cdw_form));
 
 	return;
 }
@@ -377,7 +360,7 @@ cdw_rv_t cdw_erase_wizard_build(cdw_task_t *task, cdw_disc_t *disc)
 	}
 
 	wizard.cdw_form = cdw_form_new(CDW_ERASE_WIZARD_N_FIELDS);
-	if (wizard.cdw_form == (cdw_form_t *) NULL) {
+	if (!wizard.cdw_form) {
 		cdw_vdm ("ERROR: failed to create cdw form\n");
 		return CDW_ERROR;
 	}
@@ -394,7 +377,7 @@ cdw_rv_t cdw_erase_wizard_build(cdw_task_t *task, cdw_disc_t *disc)
 						 /* 2TRANS: this is tip at the bottom of window - user can
 						    switch between window elements using tab key */
 						 _("Use 'Tab' key to move"));
-	if (wizard.cdw_form->window == (WINDOW *) NULL) {
+	if (!wizard.cdw_form->window) {
 		cdw_vdm ("ERROR: failed to create window\n");
 		return CDW_ERROR;
 	}
@@ -404,7 +387,7 @@ cdw_rv_t cdw_erase_wizard_build(cdw_task_t *task, cdw_disc_t *disc)
 						    3, 1,
 						    CDW_COLORS_DIALOG, (char *) NULL, (char *) NULL);
 
-	if (wizard.cdw_form->subwindow == (WINDOW *) NULL) {
+	if (!wizard.cdw_form->subwindow) {
 		cdw_vdm ("ERROR: failed to create subwindow\n");
 		return CDW_ERROR;
 	}
@@ -420,7 +403,7 @@ cdw_rv_t cdw_erase_wizard_build(cdw_task_t *task, cdw_disc_t *disc)
 	wizard.cdw_form->form = cdw_ncurses_new_form(wizard.cdw_form->window,
 						     wizard.cdw_form->subwindow,
 						     wizard.cdw_form->fields);
-	if (wizard.cdw_form->form == (FORM *) NULL) {
+	if (!wizard.cdw_form->form) {
 		cdw_vdm ("ERROR: failed to create form\n");
 		return CDW_ERROR;
 	}
@@ -439,8 +422,8 @@ cdw_rv_t cdw_erase_wizard_build(cdw_task_t *task, cdw_disc_t *disc)
 
 	cdw_form_add_return_chars(wizard.cdw_form, CDW_KEY_ENTER, CDW_KEY_ESCAPE, 'q', 'Q', 0);
 
-	cdw_form_set_function(wizard.cdw_form, f_erase_button_i, cdw_erase_wizard_on_enter_on_erase);
-	cdw_form_set_function(wizard.cdw_form, f_cancel_button_i, cdw_erase_wizard_on_enter_on_cancel);
+	cdw_form_set_button_return_key(wizard.cdw_form, f_erase_button_b, CDW_KEY_ENTER);
+	cdw_form_set_button_return_key(wizard.cdw_form, f_cancel_button_b, CDW_KEY_ESCAPE);
 
 	wrefresh(wizard.cdw_form->subwindow);
 	wrefresh(wizard.cdw_form->window);
@@ -455,32 +438,32 @@ cdw_rv_t cdw_erase_wizard_build(cdw_task_t *task, cdw_disc_t *disc)
 cdw_rv_t cdw_erase_wizard_build_fields(cdw_task_t *task)
 {
 	cdw_form_descr_t descr[] = {
-		/*    widget type       begin_y               begin_x         n_cols                   n_lines    field enum         data1                        data2 */
+		/* widget type           begin_y    begin_x         n_cols                 n_lines    field enum          data1                            data2 */
 
 		/* 2TRANS: this is label in erase wizard */
-		{ CDW_WIDGET_LABEL,      erase_mode_row,       first_col,      label_n_cols,                1,    f_erase_mode_l,     _("Mode of erasing:"),   0 },
-		{ CDW_WIDGET_DROPDOWN,   erase_mode_row + 1,   first_col + 1,  wide_dropdown_n_cols - 2,    1,    f_erase_mode_dd,    dropdown_makers,                0 },
+		{ CDW_WIDGET_ID_STATIC_LABEL,  2,   first_col,      label_n_cols,                1,    f_erase_mode_l,     _("Mode of erasing:"),           0 },
+		{ CDW_WIDGET_ID_DROPDOWN,      3,   first_col + 1,  wide_dropdown_n_cols - 2,    1,    f_erase_mode_dd,    dropdown_makers,                 0 },
 
 		/* 2TRANS: this is label in erase wizard */
-		{ CDW_WIDGET_LABEL,      erase_speed_row,      first_col,      label_n_cols,                1,    f_erase_speed_l,    _("Speed of erasing:") ,  0 },
-		{ CDW_WIDGET_DROPDOWN,   erase_speed_row + 1,  first_col + 1,  narrow_dropdown_n_cols - 2,  1,    f_erase_speed_dd,    dropdown_makers,                1 },
+		{ CDW_WIDGET_ID_STATIC_LABEL,  5,   first_col,      label_n_cols,                1,    f_erase_speed_l,    _("Speed of erasing:"),          0 },
+		{ CDW_WIDGET_ID_DROPDOWN,      6,   first_col + 1,  narrow_dropdown_n_cols - 2,  1,    f_erase_speed_dd,   dropdown_makers,                 1 },
 
 		/* 2TRANS: this is label in erase wizard, it's about target
 		   format for a DVD-RW disc */
-		{ CDW_WIDGET_LABEL,      format_mode_row,      first_col,      label_n_cols,                1,    f_format_mode_l,    _("Format of DVD-RW:"),      0 },
-		{ CDW_WIDGET_DROPDOWN,   format_mode_row + 1,  first_col + 1,  wide_dropdown_n_cols - 2,    1,    f_format_mode_dd,    dropdown_makers,                2 },
+		{ CDW_WIDGET_ID_STATIC_LABEL,  8,   first_col,      label_n_cols,                1,    f_format_mode_l,    _("Format of DVD-RW:"),          0 },
+		{ CDW_WIDGET_ID_DROPDOWN,      9,   first_col + 1,  wide_dropdown_n_cols - 2,    1,    f_format_mode_dd,   dropdown_makers,                 2 },
 
-		{ CDW_WIDGET_CHECKBOX,   eject_row,            first_col + 2,  1,                           1,    f_eject_cb,         (void *) NULL,  task->erase.eject ? 1 : 0 },
+		{ CDW_WIDGET_ID_CHECKBOX,      11,  first_col + 2,  1,                           1,    f_eject_cb,         (void *) NULL,  task->erase.eject ? 1 : 0 },
 		/* 2TRANS: this is label of checkbox; "tray" is a tray of CD burner; "erasing" refers to blanking of optical disc */
-		{ CDW_WIDGET_LABEL,      eject_row,            first_col + 5,  label_n_cols - 5,            1,    f_eject_l,          _("Eject tray after erasing") ,  0 },
+		{ CDW_WIDGET_ID_STATIC_LABEL,  11,  first_col + 5,  label_n_cols - 5,            1,    f_eject_l,          _("Eject tray after erasing"),   0 },
 
 		/* 2TRANS: button label, it refers to erasing optical disc */
-		{ CDW_WIDGET_BUTTON,     buttons_row,          3,              2,                           1,    f_erase_button_i,   _("Erase"),      CDW_COLORS_DIALOG },
+		{ CDW_WIDGET_ID_BUTTON,        13,  3,              2,                           1,    f_erase_button_b,   _("Erase"),      CDW_COLORS_DIALOG },
 		/* 2TRANS: button label */
-		{ CDW_WIDGET_BUTTON,     buttons_row,          15,             2,                           1,    f_cancel_button_i,  _("Cancel"),     CDW_COLORS_DIALOG },
+		{ CDW_WIDGET_ID_BUTTON,        13,  15,             2,                           1,    f_cancel_button_b,  _("Cancel"),     CDW_COLORS_DIALOG },
 
 		/* guard */
-		{ -1,                    0,                    0,              0,                           0,    0,                  (void *) NULL,                   0 }};
+		{ -1,                          0,   0,              0,                           0,    0,                  (void *) NULL,                   0 }};
 
 
 	wizard.cdw_form->n_fields = CDW_ERASE_WIZARD_N_FIELDS;
@@ -504,7 +487,7 @@ CDW_DROPDOWN *cdw_erase_wizard_make_erase_mode_dropdown(WINDOW *window, int begi
 	CDW_DROPDOWN *dropdown = cdw_dropdown_new(window, begin_y, begin_x, width,
 						  2, /* n_items_max */
 						  CDW_COLORS_DIALOG);
-	if (dropdown == (CDW_DROPDOWN *) NULL) {
+	if (!dropdown) {
 		cdw_vdm ("ERROR: failed to create new dropdown\n");
 		return (CDW_DROPDOWN *) NULL;
 	}
@@ -552,7 +535,7 @@ CDW_DROPDOWN *cdw_erase_wizard_make_speed_dropdown(WINDOW *window, int begin_y,
 	CDW_DROPDOWN *dropdown = cdw_dropdown_new(window, begin_y, begin_x, width,
 						  local_disc->write_speeds.n_speeds,   /* n_items_max */
 						  CDW_COLORS_DIALOG);
-	if (dropdown == (CDW_DROPDOWN *) NULL) {
+	if (!dropdown) {
 		cdw_vdm ("ERROR: failed to create new dropdown\n");
 		return (CDW_DROPDOWN *) NULL;
 	}
@@ -590,23 +573,18 @@ CDW_DROPDOWN *cdw_erase_wizard_make_format_mode_dropdown(WINDOW *window, int beg
 
 	/* 2TRANS: this is label in dropdown: it means "don't change
 	   format of DVD-RW during process of erasing disc" */
-	char *dont_change = _("Don't change format of DVD-RW");
+	const char *dont_change = _("Don't change format of DVD-RW");
 	/* 2TRANS: this is label in dropdown: 'Sequential' is one of two
 	   possible formats of DVD-RW */
-	char *seq = _("Change format to Sequential");
+	const char *seq = _("Change format to Sequential");
 	/* 2TRANS: this is label in dropdown: 'Restricted' is one of two
 	   possible formats of DVD-RW */
-	char *res = _("Change format to Restricted");
-
-	if (seq == (char *) NULL || res == (char *) NULL || dont_change == (char *) NULL) {
-		cdw_vdm ("ERROR: failed to create initial labels for format mode dropdown\n");
-		return (CDW_DROPDOWN *) NULL;
-	}
+	const char *res = _("Change format to Restricted");
 
 	CDW_DROPDOWN *dropdown = cdw_dropdown_new(window, begin_y, begin_x, width,
 						  3,                    /* n_items_max */
 						  CDW_COLORS_DIALOG);
-	if (dropdown == (CDW_DROPDOWN *) NULL) {
+	if (!dropdown) {
 		cdw_vdm ("ERROR: failed to create new dropdown\n");
 		return (CDW_DROPDOWN *) NULL;
 	}
@@ -663,32 +641,15 @@ void cdw_erase_wizard_print_debug_info(cdw_task_t *task, bool format_mode_dropdo
 	cdw_vdm ("INFO:    eject tray after erasing = \"%s\"\n", task->erase.eject ? "true" : "false");
 
 	if (format_mode_dropdown_visible) {
-		if (task->erase.format_mode == CDW_ERASE_DVD_RW_FORMAT_SEQ) {
+		if (task->erase.dvd_rw_format_mode == CDW_ERASE_DVD_RW_FORMAT_SEQ) {
 			cdw_vdm ("INFO: selected DVD-RW format mode = \"Sequential\"\n");
-		} else if (task->erase.format_mode == CDW_ERASE_DVD_RW_FORMAT_RES) {
+		} else if (task->erase.dvd_rw_format_mode == CDW_ERASE_DVD_RW_FORMAT_RES) {
 			cdw_vdm ("INFO: selected DVD-RW format mode = \"Restricted overwrite\"\n");
 		} else {
-			cdw_vdm ("ERROR: incorrect format mode = %lld\n", task->erase.format_mode);
+			cdw_vdm ("ERROR: incorrect format mode = %lld\n", task->erase.dvd_rw_format_mode);
 		}
 	} else {
 		cdw_vdm ("INFO: DVD-RW format mode dropdown is NOT visible\n");
 	}
 	return;
 }
-
-
-
-
-
-int cdw_erase_wizard_on_enter_on_cancel(__attribute__((unused)) cdw_form_t *cdw_form, __attribute__((unused)) void *dummy)
-{
-	return CDW_KEY_ESCAPE;
-}
-
-
-
-int cdw_erase_wizard_on_enter_on_erase(__attribute__((unused)) cdw_form_t *cdw_form, __attribute__((unused)) void *dummy)
-{
-	return CDW_KEY_ENTER;
-}
-
