@@ -1,6 +1,6 @@
 /* cdw
  * Copyright (C) 2002 Varkonyi Balazs
- * Copyright (C) 2007 - 2012 Kamil Ignacak
+ * Copyright (C) 2007 - 2014 Kamil Ignacak
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 
@@ -119,10 +119,10 @@ static int cdw_list_display_driver_loop(CDW_LIST_DISPLAY *display, size_t *h_off
 */
 CDW_LIST_DISPLAY *cdw_list_display_new(WINDOW *parent, int n_lines, int n_cols, int begin_y, int begin_x, cdw_colors_t colors)
 {
-	cdw_assert (parent != (WINDOW *) NULL, "ERROR: called the function with null parent window\n");
+	cdw_assert (parent, "ERROR: called the function with null parent window\n");
 
 	CDW_LIST_DISPLAY *display = (CDW_LIST_DISPLAY *) malloc(sizeof(CDW_LIST_DISPLAY));
-	if (display == (CDW_LIST_DISPLAY *) NULL) {
+	if (!display) {
 		cdw_vdm ("ERROR: failed to allocate memory for display\n");
 		return (CDW_LIST_DISPLAY *) NULL;
 	}
@@ -146,7 +146,7 @@ CDW_LIST_DISPLAY *cdw_list_display_new(WINDOW *parent, int n_lines, int n_cols,
 	display->subwindow = derwin(display->window,
 				    (int) display->n_lines, (int) display->n_cols,
 				    (int) display->begin_y, (int) display->begin_x);
-	if (display->subwindow == (WINDOW *) NULL) {
+	if (!display->subwindow) {
 		cdw_vdm ("ERROR: failed to create subwindow for embedded display\n");
 
 		free(display);
@@ -195,14 +195,14 @@ void cdw_list_display_delete(CDW_LIST_DISPLAY **display)
 		return;
 	}
 
-	if ((*display)->subwindow == (WINDOW *) NULL) {
+	if (!(*display)->subwindow) {
 		cdw_vdm ("ERROR: \"display->subwindow\" is NULL\n");
 	} else {
 		delwin((*display)->subwindow);
 		(*display)->subwindow = (WINDOW *) NULL;
 	}
 
-	if ((*display)->window == (WINDOW *) NULL) {
+	if (!(*display)->window) {
 		cdw_vdm ("ERROR: \"display->window\" is NULL\n");
 	} /* no "else", we can't free parent window */
 
@@ -266,8 +266,8 @@ void cdw_list_display_delete(CDW_LIST_DISPLAY **display)
 */
 int cdw_list_display_driver(CDW_LIST_DISPLAY *display)
 {
-	cdw_assert (display != (CDW_LIST_DISPLAY *) NULL, "ERROR: \"display\" argument in NULL\n");
-	cdw_assert (display->display_item != NULL, "ERROR: the display doesn't have ->display_item() set\n");
+	cdw_assert (display, "ERROR: \"display\" argument in NULL\n");
+	cdw_assert (display->display_item, "ERROR: the display doesn't have ->display_item() set\n");
 
 	size_t h_offset = 0; /* indicates if and how much content of the window was moved to left */
 
@@ -418,9 +418,9 @@ int cdw_list_display_driver_loop(CDW_LIST_DISPLAY *display, size_t *h_offset)
 */
 void cdw_list_display_refresh(CDW_LIST_DISPLAY *display)
 {
-	cdw_assert (display != (CDW_LIST_DISPLAY *) NULL, "ERROR: \"display\" argument is NULL\n");
-	cdw_assert (display->window != (WINDOW *) NULL, "ERROR: \"display->window\" is NULL\n");
-	cdw_assert (display->subwindow != (WINDOW *) NULL, "ERROR: \"display->subwindow\" is NULL\n");
+	cdw_assert (display, "ERROR: \"display\" argument is NULL\n");
+	cdw_assert (display->window, "ERROR: \"display->window\" is NULL\n");
+	cdw_assert (display->subwindow, "ERROR: \"display->subwindow\" is NULL\n");
 
 	wrefresh(display->subwindow);
 	redrawwin(display->window);
@@ -461,9 +461,9 @@ void cdw_list_display_refresh(CDW_LIST_DISPLAY *display)
 */
 void cdw_list_display_scroll_to_current(CDW_LIST_DISPLAY *display, size_t h_offset, bool highlight)
 {
-	cdw_assert (display != (CDW_LIST_DISPLAY *) NULL, "ERROR: \"display\" argument is NULL\n");
-	cdw_assert (display->subwindow != (WINDOW *) NULL, "ERROR: \"display->subwindow\" is NULL\n");
-	cdw_assert (display->display_item != NULL, "ERROR: ->display_item() function pointer is NULL\n");
+	cdw_assert (display, "ERROR: \"display\" argument is NULL\n");
+	cdw_assert (display->subwindow, "ERROR: \"display->subwindow\" is NULL\n");
+	cdw_assert (display->display_item, "ERROR: ->display_item() function pointer is NULL\n");
 
 	if (display->n_items == 0) {
 		/* perfectly normal situation, but it means that we have
@@ -531,7 +531,7 @@ void cdw_list_display_scroll_to_current(CDW_LIST_DISPLAY *display, size_t h_offs
 */
 void cdw_list_display_add_return_key(CDW_LIST_DISPLAY *display, int c)
 {
-	cdw_assert (display != (CDW_LIST_DISPLAY *) NULL, "ERROR: \"display\" argument is NULL\n");
+	cdw_assert (display, "ERROR: \"display\" argument is NULL\n");
 	cdw_assert (display->n_return_chars < N_RETURN_KEYS_MAX,
 		    "ERROR: there are already %d / %d return chars in the display, can't add another one\n",
 		    display->n_return_chars, N_RETURN_KEYS_MAX);
@@ -567,7 +567,7 @@ void cdw_list_display_add_return_key(CDW_LIST_DISPLAY *display, int c)
 */
 void cdw_list_display_add_return_keys(CDW_LIST_DISPLAY *display, ...)
 {
-	cdw_assert (display != (CDW_LIST_DISPLAY *) NULL, "ERROR: \"display\" argument is NULL\n");
+	cdw_assert (display, "ERROR: \"display\" argument is NULL\n");
 	cdw_assert (display->n_return_chars < N_RETURN_KEYS_MAX,
 		    "ERROR: there are already %d / %d return keys in the form, can't add another one\n",
 		    display->n_return_chars, N_RETURN_KEYS_MAX);
@@ -602,11 +602,10 @@ void cdw_list_display_add_return_keys(CDW_LIST_DISPLAY *display, ...)
 */
 bool cdw_list_display_is_return_key(CDW_LIST_DISPLAY *display, int c)
 {
-	cdw_assert (display != (CDW_LIST_DISPLAY *) NULL, "ERROR: \"display\" argument is NULL\n");
+	cdw_assert (display, "ERROR: \"display\" argument is NULL\n");
 	cdw_assert (c != 0, "ERROR: asking for 0, which is an initialization value\n");
 
-	int i = 0;
-	for (i = 0; i < display->n_return_chars; i++) {
+	for (int i = 0; i < display->n_return_chars; i++) {
 		if (display->return_chars[i] == c) {
 			return true;
 		}
@@ -640,7 +639,7 @@ bool cdw_list_display_is_return_key(CDW_LIST_DISPLAY *display, int c)
 */
 cdw_rv_t cdw_list_display_remove_item(CDW_LIST_DISPLAY *display, size_t item_i)
 {
-	cdw_assert (display != (CDW_LIST_DISPLAY *) NULL, "ERROR: display is null\n");
+	cdw_assert (display, "ERROR: display is null\n");
 	cdw_assert (display->n_items > 0, "ERROR: you called the function for display with empty list\n");
 	cdw_assert (display->list != (cdw_dll_item_t *) NULL, "ERROR: list associated with the display is null\n");
 
@@ -648,7 +647,7 @@ cdw_rv_t cdw_list_display_remove_item(CDW_LIST_DISPLAY *display, size_t item_i)
 
 #ifndef NDEBUG
 	cdw_dll_item_t *item = cdw_dll_ith_item(display->list, display->current_item_ind);
-	cdw_assert (item->data == NULL, "ERROR: item payload is not NULL, trying to leak memory?\n");
+	cdw_assert (!item->data, "ERROR: item payload is not NULL, trying to leak memory?\n");
 #endif
 
 #ifndef NDEBUG
@@ -736,7 +735,7 @@ cdw_rv_t cdw_list_display_add_item(CDW_LIST_DISPLAY *display, void *data, bool (
 
 void cdw_list_display_scroll_to(CDW_LIST_DISPLAY *display, size_t current_item_ind, size_t h_offset, bool highlight)
 {
-	cdw_assert (display != (CDW_LIST_DISPLAY *) NULL, "ERROR: passed NULL display to function\n");
+	cdw_assert (display, "ERROR: passed NULL display to function\n");
 	if (display->n_items > 0) {
 		cdw_assert (current_item_ind < display->n_items, "ERROR: item index %zd is larger than number of items %zd\n",
 			    current_item_ind, display->n_items);
@@ -754,7 +753,7 @@ void cdw_list_display_scroll_to(CDW_LIST_DISPLAY *display, size_t current_item_i
 
 void *cdw_list_display_get_current_item_data(CDW_LIST_DISPLAY *display)
 {
-	cdw_assert (display != (CDW_LIST_DISPLAY *) NULL, "ERROR: passed NULL display to function\n");
+	cdw_assert (display, "ERROR: passed NULL display to function\n");
 	cdw_assert (display->n_items > display->current_item_ind,
 		    "ERROR, current item index (0-based) is %zd but number of items is %zd\n",
 		    display->current_item_ind, display->n_items);
@@ -788,7 +787,7 @@ void *cdw_list_display_get_current_item_data(CDW_LIST_DISPLAY *display)
 */
 bool cdw_list_display_is_member(CDW_LIST_DISPLAY *display, void *data, bool (*pred)(const void *, const void *))
 {
-	cdw_assert (display != (CDW_LIST_DISPLAY *) NULL, "ERROR: display is NULL\n");
+	cdw_assert (display, "ERROR: display is NULL\n");
 	cdw_assert (pred != (bool (*)(const void *, const void *)) NULL, "ERROR: predicate function is NULL\n");
 	return cdw_dll_is_member(display->list, data, pred);
 }
