@@ -69,9 +69,9 @@ void    *cdw_list_display_get_current_item_data(CDW_LIST_DISPLAY *display);
 /* basically a wrapper around cdw_dll_is_member() */
 bool     cdw_list_display_is_member(CDW_LIST_DISPLAY *display, void *data, bool (*pred)(const void *, const void *));
 
-void cdw_list_display_add_return_char(CDW_LIST_DISPLAY *display, int c);
+void cdw_list_display_add_return_key(CDW_LIST_DISPLAY *display, int c);
 void cdw_list_display_add_return_keys(CDW_LIST_DISPLAY *display, ...);
-bool cdw_list_display_is_return_char(CDW_LIST_DISPLAY *display, int c);
+bool cdw_list_display_is_return_key(CDW_LIST_DISPLAY *display, int c);
 
 void cdw_list_display_refresh(CDW_LIST_DISPLAY *display);
 
