@@ -1,6 +1,6 @@
 /* cdw
  * Copyright (C) 2002 Varkonyi Balazs
- * Copyright (C) 2007 - 2012 Kamil Ignacak
+ * Copyright (C) 2007 - 2014 Kamil Ignacak
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 #define _BSD_SOURCE /* strdup() */
 
@@ -23,8 +23,9 @@
 #include <unistd.h>
 #include <errno.h>
 
+#include "config_cdw.h"
+
 #include "cdw_fs.h"
-#include "config.h"
 #include "cdw_main_window.h"
 #include "cdw_config.h"
 #include "gettext.h"
@@ -40,11 +41,11 @@
 
 extern cdw_config_t global_config; /* main cdw configuration variable */
 
-static void cdw_main_ui_init_values(void);
-static void cdw_main_ui_recalculate_sizes(void);
+static void cdw_main_window_init_values(void);
+static void cdw_main_window_recalculate_sizes(void);
 
 /** \brief Number of items in main cdw menu on the left; does not include last NULL item */
-#define MENU_ITEMS 10
+#define MENU_ITEMS 11
 /* in theory this is just a length of labels in menu, and indirectly
    width of menu; but it also (indirectly) influences width of
    "disc info" box below menu */
@@ -93,13 +94,13 @@ static struct {
 
 
 
-static cdw_rv_t cdw_main_ui_main_menu_view_create(void);
-static cdw_rv_t cdw_main_ui_files_list_view_create(void);
-static cdw_rv_t cdw_main_ui_volume_info_view_create(void);
-static cdw_rv_t cdw_main_ui_disc_info_view_create(void);
-static cdw_rv_t cdw_main_ui_tooltips_view_create(void);
+static cdw_rv_t cdw_main_window_main_menu_view_create(void);
+static cdw_rv_t cdw_main_window_files_list_view_create(void);
+static cdw_rv_t cdw_main_window_volume_info_view_create(void);
+static cdw_rv_t cdw_main_window_disc_info_view_create(void);
+static cdw_rv_t cdw_main_window_tooltips_view_create(void);
 
-static void cdw_main_ui_volume_info_view_display_data_new(bool show_disc_info, size_t n_files, double used_space, double selected_size, int total_space);
+static void cdw_main_window_volume_info_view_display_data_new(bool show_disc_info, size_t n_files, double used_space, double selected_size, int total_space);
 
 
 
@@ -114,67 +115,80 @@ static void cdw_main_ui_volume_info_view_display_data_new(bool show_disc_info, s
    \return CDW_GEN_ERROR if some other error occurred
    \return CDW_OK if user interface was initialized properly
 */
-cdw_rv_t cdw_main_ui_init(void)
+cdw_rv_t cdw_main_window_module_init(void)
 {
-	cdw_main_ui_init_values();
+	cdw_main_window_init_values();
 
 	/* main NCURSES window */
 	cdw_ui.window = newwin(cdw_ui.n_rows, cdw_ui.n_cols, 0, 0);
 	if (!cdw_ui.window) {
-		cdw_main_ui_clean();
+		cdw_main_window_module_clean();
 		cdw_vdm ("ERROR: failed to create main app window\n");
 		return CDW_ERROR;
 	}
 
-	keypad(cdw_ui.window, TRUE);
-	wbkgd(cdw_ui.window, A_NORMAL | COLOR_PAIR(CDW_COLORS_MAIN));
+	int rv = wrefresh(cdw_ui.window);
+	cdw_vdm_n ("wrefresh", rv, "");
+
+	rv = keypad(cdw_ui.window, TRUE);
+	cdw_vdm_n ("keypad", rv, "");
+	rv = wbkgd(cdw_ui.window, A_NORMAL | COLOR_PAIR(CDW_COLORS_MAIN));
+	cdw_vdm_n ("wbkgd", rv, "");
 
 	/* left-hand, main app menu */
-	cdw_rv_t crv = cdw_main_ui_main_menu_view_create();
+	cdw_rv_t crv = cdw_main_window_main_menu_view_create();
 	if (crv != CDW_OK) {
-		cdw_main_ui_clean();
+		cdw_main_window_module_clean();
 		cdw_vdm ("ERROR: failed to create main app menu\n");
 		return CDW_ERROR;
 	}
 
-	mvwaddch(cdw_ui.window, 0, 1, ACS_RTEE);
-	wattrset(cdw_ui.window, A_BOLD | COLOR_PAIR(CDW_COLORS_TITLE));
-	mvwprintw(cdw_ui.window, 0, 2, " ::: %s %s ::: ", PACKAGE, VERSION);
-	wattrset(cdw_ui.window, A_NORMAL | COLOR_PAIR(CDW_COLORS_MAIN));
-	waddch(cdw_ui.window, ACS_LTEE);
+	rv = mvwaddch(cdw_ui.window, 0, 1, ACS_RTEE);
+	cdw_vdm_n ("mvwaddch", rv, "");
+	rv = wattrset(cdw_ui.window, A_BOLD | COLOR_PAIR(CDW_COLORS_TITLE));
+	cdw_vdm_n ("wattrset", rv, "");
+	rv = mvwprintw(cdw_ui.window, 0, 2, " ::: %s %s ::: ", PACKAGE, VERSION);
+	cdw_vdm_n ("mvwprintw", rv, "");
+	rv = wattrset(cdw_ui.window, A_NORMAL | COLOR_PAIR(CDW_COLORS_MAIN));
+	cdw_vdm_n ("wattrset", rv, "");
+	rv = waddch(cdw_ui.window, ACS_LTEE);
+	cdw_vdm_n ("waddch", rv, "");
+
+	rv = wrefresh(cdw_ui.window);
+	cdw_vdm_n ("wrefresh", rv, "");
 
 	/* window in which selected files are displayed */
-	crv = cdw_main_ui_files_list_view_create();
+	crv = cdw_main_window_files_list_view_create();
 	if (crv != CDW_OK) {
-		cdw_main_ui_clean();
+		cdw_main_window_module_clean();
 		cdw_vdm ("ERROR: failed to create selected files list view\n");
 		return CDW_ERROR;
 	}
 
 	/* area displaying summarized information about selected files
 	   and disc capacity/usage/estimated future usage */
-	crv = cdw_main_ui_volume_info_view_create();
+	crv = cdw_main_window_volume_info_view_create();
 	if (crv != CDW_OK) {
-		cdw_main_ui_clean();
+		cdw_main_window_module_clean();
 		cdw_vdm ("ERROR: failed to create selected files info view\n");
 		return CDW_ERROR;
 	}
 
-	cdw_main_window_volume_info_view_update(-1, -1, true, global_config.follow_symlinks);
+	cdw_main_window_volume_info_view_update(-1, -1, true);
 	//selected_files_size_mb = 0.0;
 	//cdw_ui_volume_info_view_display_data();
 
 	/* area displaying information about current optical disc */
-	crv = cdw_main_ui_disc_info_view_create();
+	crv = cdw_main_window_disc_info_view_create();
 	if (crv != CDW_OK) {
-		cdw_main_ui_clean();
+		cdw_main_window_module_clean();
 		cdw_vdm ("ERROR: failed to create disc info view\n");
 		return CDW_ERROR;
 	}
 
-	crv = cdw_main_ui_tooltips_view_create();
+	crv = cdw_main_window_tooltips_view_create();
 	if (crv != CDW_OK) {
-		cdw_main_ui_clean();
+		cdw_main_window_module_clean();
 		cdw_vdm ("ERROR: failed to create help view\n");
 		return CDW_ERROR;
 	}
@@ -195,12 +209,11 @@ cdw_rv_t cdw_main_ui_init(void)
    this functions and all functions called check if resource was allocated,
    and if so, then proceeds with cleaning resource.
 */
-void cdw_main_ui_clean(void)
+void cdw_main_window_module_clean(void)
 {
 	if (cdw_ui.main_menu.menu) {
-		unpost_menu(cdw_ui.main_menu.menu);
 		cdw_ncurses_delete_menu_and_items(&(cdw_ui.main_menu.menu));
-		cdw_assert (!cdw_ui.main_menu.menu, "failed to set cdw_ui.main_menu.menu to NULL\n")
+		cdw_assert (!cdw_ui.main_menu.menu, "ERROR: failed to set cdw_ui.main_menu.menu to NULL\n")
 	}
 
 	/* IMPORTANT: first clean subwindows, then parent window */
@@ -220,10 +233,11 @@ void cdw_main_ui_clean(void)
 	   and then you press 'q' again and then select 'ok'
 	   2. if you run cdw in 81x26 terminal */
 
+
+	cdw_file_manager_delete_selected_files_view();
 	cdw_window_delete(&cdw_ui.files_list_view.subwindow);
+
 	cdw_window_delete(&cdw_ui.main_menu.menu_subwindow);
-	cdw_assert (cdw_ui.main_menu.menu_subwindow == (WINDOW *) NULL,
-		    "ERROR: delete() function didn't set a window to NULL\n");
 	cdw_window_delete(&cdw_ui.main_menu.subwindow);
 	cdw_window_delete(&cdw_ui.volume_info_view.subwindow);
 	cdw_window_delete(&cdw_ui.disc_info_view.subwindow);
@@ -247,7 +261,7 @@ void cdw_main_ui_clean(void)
    also called when application receives information that terminal size has
    changed (TODO: catching signal is to be implemented).
 */
-void cdw_main_ui_recalculate_sizes(void)
+void cdw_main_window_recalculate_sizes(void)
 {
 	/* There are only few known limitations on UI layout:
 	    - tooltips area at the bottom of window must have exactly 1 line;
@@ -331,7 +345,7 @@ static const char *menu_labels[] = {
 	/* 2TRANS: label of item in main menu: write
 	   selected dirs/files to optical disc */
 	gettext_noop(" Write files to disc "),
-	/* 2TRANS: label of item in main menu: create ISO9660 image file
+	/* 2TRANS: label of item in main menu: create ISO9660 or UDF image file
 	   using selected files/directories */
 	gettext_noop(" Create image "),
 	/* 2TRANS: label of item in main menu: write (burn) ISO9660 image
@@ -346,6 +360,9 @@ static const char *menu_labels[] = {
 	gettext_noop(" Verify data "),
 	/* 2TRANS: label of item in main menu: change configuration of cdw */
 	gettext_noop(" Configuration "),
+	/* 2TRANS: label of item in main menu: information about the
+	   application (authors, license, web address). */
+	gettext_noop(" About "),
 	/* 2TRANS: label of item in main menu: exit cdw */
 	gettext_noop(" Quit ") };
 
@@ -362,7 +379,7 @@ static const char *menu_labels[] = {
    \return CDW_MEM_ERROR if some malloc() error occurred
    \return CDW_ERROR if some other error
 */
-cdw_rv_t cdw_main_ui_main_menu_view_create(void)
+cdw_rv_t cdw_main_window_main_menu_view_create(void)
 {
 	cdw_assert (cdw_ui.window, "calling the function for null main window\n");
 
@@ -456,7 +473,7 @@ cdw_rv_t cdw_main_ui_main_menu_view_create(void)
    \return CDW_OK on success
    \return CDW_ERROR if some error occurred
 */
-cdw_rv_t cdw_main_ui_files_list_view_create(void)
+cdw_rv_t cdw_main_window_files_list_view_create(void)
 {
 	cdw_assert (cdw_ui.window, "ERROR: calling the function for null main window\n");
 
@@ -503,7 +520,7 @@ cdw_rv_t cdw_main_ui_files_list_view_create(void)
    \return CDW_OK on success
    \return CDW_ERROR if some error occurred
 */
-cdw_rv_t cdw_main_ui_disc_info_view_create(void)
+cdw_rv_t cdw_main_window_disc_info_view_create(void)
 {
 	cdw_ui.disc_info_view.subwindow = derwin(cdw_ui.window,
 						 cdw_ui.disc_info_view.n_rows,
@@ -530,7 +547,7 @@ cdw_rv_t cdw_main_ui_disc_info_view_create(void)
 
 	   cdw_disc_get(disc); */
 
-	cdw_main_ui_disc_info_view_display_data(disc);
+	cdw_main_window_disc_info_view_display_data(disc);
 	cdw_disc_delete(&disc);
 
 	return CDW_OK;
@@ -551,7 +568,7 @@ cdw_rv_t cdw_main_ui_disc_info_view_create(void)
 
    \param disc - variable from which to take values to display
 */
-void cdw_main_ui_disc_info_view_display_data(const cdw_disc_t *disc)
+void cdw_main_window_disc_info_view_display_data(const cdw_disc_t *disc)
 {
 	cdw_assert (cdw_ui.disc_info_view.subwindow, "called the function for NULL subwindow\n");
 	cdw_assert (disc, "called the function with NULL argument\n");
@@ -596,6 +613,7 @@ void cdw_main_ui_disc_info_view_display_data(const cdw_disc_t *disc)
 		   "refresh" means - (re)read disc information and display
 		   it in disc information area */
 		mvwprintw(cdw_ui.disc_info_view.subwindow, row_h + 2, pcol, _("'R' key - refresh"));
+		wrefresh(cdw_ui.disc_info_view.subwindow);
 		return;
 	} else {
 		if (disc->state_empty == CDW_TRUE) {
@@ -664,9 +682,9 @@ void cdw_main_ui_disc_info_view_display_data(const cdw_disc_t *disc)
 /**
    Refresh part of main application window.
 */
-void cdw_main_ui_main_window_wrefresh_part(int n_lines, int n_cols, int begin_y, int begin_x)
+void cdw_main_window_wrefresh_part(int n_lines, int n_cols, int begin_y, int begin_x)
 {
-	if (cdw_ui.window == (WINDOW *) NULL) {
+	if (!cdw_ui.window) {
 		/* previously there was an assert() here, but this function
 		   may be called by dialogbox when main ui (and thus main
 		   window) is not initialized yet; example: when after starting
@@ -674,12 +692,12 @@ void cdw_main_ui_main_window_wrefresh_part(int n_lines, int n_cols, int begin_y,
 		   main window is still not created, but cdw displays dialog
 		   that informs user about resetting path, and the dialog
 		   window calls this function */
-		cdw_vdm ("ERROR: called the function for null window\n");
+		cdw_vdm ("ERROR: called the function for NULL window\n");
 		return;
 	}
 
 	WINDOW *window = derwin(cdw_ui.window, n_lines, n_cols, begin_y, begin_x);
-	if (window == (WINDOW *) NULL) {
+	if (!window) {
 		cdw_vdm ("ERROR: failed to create derived window for refresh\n");
 	} else {
 		wrefresh(window);
@@ -696,9 +714,9 @@ void cdw_main_ui_main_window_wrefresh_part(int n_lines, int n_cols, int begin_y,
 /**
    \brief Redraw content of main app window
 */
-void cdw_main_ui_main_window_wrefresh(void)
+void cdw_main_window_wrefresh(void)
 {
-	cdw_assert (cdw_ui.window, "called the function for null window\n");
+	cdw_assert (cdw_ui.window, "ERROR: called the function for NULL window\n");
 
 	redrawwin(cdw_ui.window);
 	wrefresh(cdw_ui.window);
@@ -710,7 +728,7 @@ void cdw_main_ui_main_window_wrefresh(void)
 
 
 
-cdw_rv_t cdw_main_window_volume_info_view_update(long long disc_sectors_used, long long disc_sectors_total, bool rescan_selected_files, bool follow_symlinks)
+cdw_rv_t cdw_main_window_volume_info_view_update(long long disc_sectors_used, long long disc_sectors_total, bool rescan_selected_files)
 {
 	static long long disc_capacity_sectors_used = 0;
 	static long long disc_capacity_sectors_total = 0;
@@ -730,7 +748,7 @@ cdw_rv_t cdw_main_window_volume_info_view_update(long long disc_sectors_used, lo
 	double selected_files_size_mb = 0.0;
 	if (n_files != 0) {
 		if (rescan_selected_files) {
-			selected_files_size_mb = cdw_file_manager_calculate_selected_files_size_mb(follow_symlinks);
+			selected_files_size_mb = cdw_file_manager_calculate_selected_files_size_mb();
 			if (selected_files_size_mb < 0.0) {
 				error = true;
 			}
@@ -744,7 +762,7 @@ cdw_rv_t cdw_main_window_volume_info_view_update(long long disc_sectors_used, lo
 	double used_space =  0.0;
 	bool show_disc_info = false;
 
-	if (global_config.volume_size_id == CDW_CONFIG_VOLUME_SIZE_AUTO) {
+	if (global_config.general.volume_size_id == CDW_CONFIG_VOLUME_SIZE_AUTO) {
 		used_space = (double) disc_capacity_sectors_used / 512.0;
 		total_space = (int) disc_capacity_sectors_total / 512;
 
@@ -760,10 +778,10 @@ cdw_rv_t cdw_main_window_volume_info_view_update(long long disc_sectors_used, lo
 	} else {
 		/* either custom value, or constant value corresponding
 		   to total capacity of some preselected disc type */
-		total_space = (int) cdw_config_get_current_volume_size_value();
+		total_space = (int) cdw_config_get_current_volume_size_value_megabytes();
 	}
 
-	cdw_main_ui_volume_info_view_display_data_new(show_disc_info, n_files, used_space, selected_files_size_mb, total_space);
+	cdw_main_window_volume_info_view_display_data_new(show_disc_info, n_files, used_space, selected_files_size_mb, total_space);
 
 	if (error) {
 		cdw_vdm ("ERROR: size of selected files is < 0\n");
@@ -772,7 +790,7 @@ cdw_rv_t cdw_main_window_volume_info_view_update(long long disc_sectors_used, lo
 				   /* 2TRANS: this is message in dialog window */
 				   _("One or more of selected files may be missing. Check log file for more information - press 'L' key in main window."),
 				   CDW_BUTTONS_OK, CDW_COLORS_WARNING);
-		cdw_main_ui_main_window_wrefresh();
+		cdw_main_window_wrefresh();
 		return CDW_ERROR;
 	} else {
 		return CDW_OK;
@@ -807,10 +825,9 @@ cdw_rv_t cdw_main_window_volume_info_view_update(long long disc_sectors_used, lo
    \param selected_size - size of selected files
    \param total_space - total capacity of optical disc
 */
-void cdw_main_ui_volume_info_view_display_data_new(bool show_disc_info, size_t n_files, double used_space, double selected_size, int total_space)
+void cdw_main_window_volume_info_view_display_data_new(bool show_disc_info, size_t n_files, double used_space, double selected_size, int total_space)
 {
-	cdw_assert (cdw_ui.volume_info_view.subwindow != (WINDOW *) NULL,
-		    "ERROR: called the function for NULL subwindow\n");
+	cdw_assert (cdw_ui.volume_info_view.subwindow, "ERROR: called the function for NULL subwindow\n");
 	WINDOW *subwindow = cdw_ui.volume_info_view.subwindow;
 	wattrset(subwindow, A_BOLD | COLOR_PAIR(CDW_COLORS_MAIN));
 
@@ -880,7 +897,8 @@ void cdw_main_ui_volume_info_view_display_data_new(bool show_disc_info, size_t n
 		}
 		wattrset(subwindow, COLOR_PAIR(CDW_COLORS_MAIN));
 
-		mvwhline(subwindow, bar_row, col + 1, ACS_BLOCK, n); /* +1 to skip left brace [ */
+		/* ACS_BLOCK may be displayed incorrectly (i.e. not at all) on some terminals. Use '#' instead. */
+		mvwhline(subwindow, bar_row, col + 1, '#', n); /* +1 to skip left brace [ */
 		mvwhline(subwindow, bar_row, col + 1 + n, '+', m); /* +1 to skip left brace [ */
 		mvwprintw(subwindow, bar_row, col + bar_width + 3, /* 3 to move past indicator bar */
 			  /* 2TRANS: this is information about usage of disc space:
@@ -897,6 +915,26 @@ void cdw_main_ui_volume_info_view_display_data_new(bool show_disc_info, size_t n
 	}
 
 	wattrset(subwindow, A_NORMAL | COLOR_PAIR(CDW_COLORS_MAIN));
+
+
+	/* 2TRANS: this is title of area showing basic info
+	   (total size, usage of space on optical disc) about
+	   selected files. "Volume" as in "disc volume", or
+	   "ISO9660 volume". */
+	const char *title = _("Volume");
+	const char *message = global_config.general.selected_follow_symlinks ?
+		/* 2TRANS: this is a message saying that when
+		   calculating size of selected files, cdw will follow
+		   symbolic links that it will find among selected
+		   files. */
+		_("Calculated size includes symlinked files")
+		/* 2TRANS: this is a message saying that when
+		   calculating size of selected files, cdw will not
+		   follow symbolic links that it will find among
+		   selected files. */
+		: _("Calculated size does NOT include symlinked files");
+	cdw_window_add_strings(subwindow, title, message);
+
 	wrefresh(subwindow);
 
 	return;
@@ -917,7 +955,7 @@ void cdw_main_ui_volume_info_view_display_data_new(bool show_disc_info, size_t n
    is deleted because it is outdated (new one should be created only
    when attempting to do sth using selected files).
 */
-cdw_rv_t cdw_main_ui_delete_from_selected_files(void)
+cdw_rv_t cdw_main_window_delete_from_selected_files(void)
 {
         size_t num = cdw_file_manager_number_of_selected_files();
 
@@ -948,7 +986,7 @@ cdw_rv_t cdw_main_ui_delete_from_selected_files(void)
 
 
 
-cdw_rv_t cdw_main_ui_add_to_selected_files(void)
+cdw_rv_t cdw_main_window_add_to_selected_files(void)
 {
 	cdw_file_manager_handle_adding_to_selected_files();
 
@@ -966,7 +1004,7 @@ cdw_rv_t cdw_main_ui_add_to_selected_files(void)
    \return CDW_OK on success
    \return CDW_ERROR if some error occurred
 */
-cdw_rv_t cdw_main_ui_volume_info_view_create(void)
+cdw_rv_t cdw_main_window_volume_info_view_create(void)
 {
 	cdw_assert (cdw_ui.window, "calling the function for null main window\n");
 
@@ -982,9 +1020,13 @@ cdw_rv_t cdw_main_ui_volume_info_view_create(void)
 	}
 
 	cdw_window_add_strings(cdw_ui.volume_info_view.subwindow,
-			       /* 2TRANS: this is title of area showing basic info (total
-				  size, CD usage) about selected files */
-			       _("ISO volume"), (char *) NULL);
+			       /* 2TRANS: this is title of area
+				  showing basic info (total size,
+				  usage of space on optical disc)
+				  about selected files. "Volume" as in
+				  "disc volume", or "ISO9660
+				  volume". */
+			       _("Volume"), (char *) NULL);
 
 	return CDW_OK;
 }
@@ -999,7 +1041,7 @@ cdw_rv_t cdw_main_ui_volume_info_view_create(void)
    Try to display GPL-2 file from system-default location, if this fails
    then display basic license info in dialog box.
 */
-void cdw_main_ui_show_license(void)
+void cdw_main_window_show_license(void)
 {
 	size_t len1 = strlen(COMMON);
 	size_t len2 = strlen("/GPL-2");
@@ -1027,7 +1069,7 @@ void cdw_main_ui_show_license(void)
 		   directly as function's argument */
 		/* 2TRANS: this is standard information about licensing
 		   program under GPL; it may be non-translatable in your area */
-		char *msg = strdup(_("This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.\n\nThis program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.\n\nYou should have received a copy of the GNU General Public License along with this program; if not, write to the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA"));
+		char *msg = strdup(_("This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.\n\nThis program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.\n\nYou should have received a copy of the GNU General Public License along with this program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA."));
 		if (msg) {
 			/* 2TRANS: this is title of dialog window, in which
 			   basic information about licensing is displayed */
@@ -1054,7 +1096,7 @@ void cdw_main_ui_show_license(void)
 
 
 
-cdw_rv_t cdw_main_ui_tooltips_view_create(void)
+cdw_rv_t cdw_main_window_tooltips_view_create(void)
 {
 	cdw_assert (cdw_ui.window, "calling the function for null main window\n");
 
@@ -1079,7 +1121,7 @@ cdw_rv_t cdw_main_ui_tooltips_view_create(void)
 
 
 
-WINDOW *cdw_main_ui_get_tooltips_subwindow(void)
+WINDOW *cdw_main_window_get_tooltips_subwindow(void)
 {
 	cdw_assert(cdw_ui.tooltips_view.subwindow,
 		   "called help tooltip before initializing cdw ui -> tooltips view\n");
@@ -1090,7 +1132,7 @@ WINDOW *cdw_main_ui_get_tooltips_subwindow(void)
 
 
 
-MENU *cdw_main_ui_get_main_menu(void)
+MENU *cdw_main_window_get_main_menu(void)
 {
 	cdw_assert(cdw_ui.main_menu.menu,
 		   "called help tooltip before initializing cdw ui -> menu\n");
@@ -1101,7 +1143,7 @@ MENU *cdw_main_ui_get_main_menu(void)
 
 
 
-WINDOW *cdw_main_ui_get_main_window(void)
+WINDOW *cdw_main_window_get_main_window(void)
 {
 	cdw_assert(cdw_ui.window,
 		   "called help tooltip before initializing cdw ui -> window\n");
@@ -1113,7 +1155,7 @@ WINDOW *cdw_main_ui_get_main_window(void)
 
 
 
-void cdw_main_ui_init_values(void)
+void cdw_main_window_init_values(void)
 {
 	cdw_ui.tooltips_view.subwindow = (WINDOW *) NULL;
 	cdw_ui.disc_info_view.subwindow = (WINDOW *) NULL;
@@ -1126,7 +1168,7 @@ void cdw_main_ui_init_values(void)
 	cdw_ui.window = (WINDOW *) NULL;
 
 	/* 'sizes' are layout constraints and parameters */
-	cdw_main_ui_recalculate_sizes();
+	cdw_main_window_recalculate_sizes();
 
 	return;
 }
@@ -1135,14 +1177,15 @@ void cdw_main_ui_init_values(void)
 
 
 
-void cdw_main_ui_handle_follow_symlinks_change(bool old_state, bool current_state)
+void cdw_main_window_handle_follow_symlinks_change(bool old_state, bool current_state)
 {
 	if (current_state != old_state) {
 		/* user changed the way how symlinks should be treated,
 		   and this may affect size of selected files */
 		cdw_vdm ("INFO: changed \"follow symlinks\" to %s, recalculating files size\n",
 			 current_state ? "true" : "false");
-		cdw_main_window_volume_info_view_update(-1, -1, true, current_state);
+		cdw_file_manager_follow_symlinks(current_state);
+		cdw_main_window_volume_info_view_update(-1, -1, true);
 		cdw_file_manager_regenerate_selected_files_view();
 	} else {
 		cdw_vdm ("INFO: \"follow symlinks\" is still %s\n", current_state ? "true" : "false");
@@ -1154,91 +1197,22 @@ void cdw_main_ui_handle_follow_symlinks_change(bool old_state, bool current_stat
 
 
 
-/* *** unused code *** */
-
-#if 0
-
-/**
-   \brief Display CD usage summary on bottom of cdw window
-
-   Display amount of space used by selected files, amount of
-   space that would stay free on disk, and percent of CD disk usage.
-   CD/DVD size is taken from config panel/file.
-
-   I try to pack all information in just two lines, so that it is always
-   visible and always updated when file selector is on top and files_info area
-   is partially covered by file selector.
-
-   The function does not collect nor calculate any data (except for some local
-   variables), it just uses current values from some global variables.
-*/
-void cdw_main_ui_volume_info_view_display_data(size_t n_files, double size_mb)
+void cdw_about(void)
 {
-	cdw_assert (cdw_ui.volume_info_view.subwindow != (WINDOW *) NULL,
-		    "called the function for null subwindow\n");
-	WINDOW *subwindow = cdw_ui.volume_info_view.subwindow;
-	wattrset(subwindow, A_BOLD | COLOR_PAIR(CDW_COLORS_MAIN));
+	cdw_buttons_dialog(_("About cdw"),
+			   /* 2TRANS: this is message in dialog window */
+			   _("cdw 0.8.0 - front end for tools creating ISO9660 and UDF file systems and writing data to optical discs.\n"
 
-	int s_row = 3;    /* "Size: " row */
-	int b_row = 4;    /* usage bar row */
-        const int col = 2;        /* start column for content drawn in window */
-	const int bar_width = 30; /* number of cells in bar, does not include borders */
+			     "Copyright (C) 2002 Varkonyi Balazs\n"
+			     "Copyright (C) 2007 - 2014 Kamil Ignacak\n"
 
-	/* clean row in which usage bar and information about space usage is displayed */
-	mvwhline(subwindow, s_row, 1, ' ', cdw_ui.volume_info_view.n_cols - 2);
-	mvwhline(subwindow, b_row, 1, ' ', cdw_ui.volume_info_view.n_cols - 2);
+			     "This program is free software; you can redistribute it and/or modify\n"
+			     "it under the terms of the GNU General Public License as published by\n"
+			     "the Free Software Foundation; either version 2 of the License, or\n"
+			     "(at your option) any later version.\n"
 
-	/* left and right border of usage bar */
-	mvwaddch(subwindow, b_row, col, '[');
-	mvwaddch(subwindow, b_row, col + bar_width + 1, ']');
-
-	bool too_much = false;
-	if (size_mb > (double) global_config.volume_size_value) {
-		too_much = true;
-		wattrset(subwindow, COLOR_PAIR(CDW_COLORS_ERROR));
-	} else {
-		/* 0.8 (80%): arbitrary value of 'safe' level of disc usage */
-		if (size_mb <= ((double) global_config.volume_size_value * 0.8)) {
-			wattrset(subwindow, COLOR_PAIR(CDW_COLORS_MAIN));
-		} else {
-			wattrset(subwindow, COLOR_PAIR(CDW_COLORS_WARNING));
-		}
-	}
-
-	double percent = size_mb * 100 / ((double) global_config.volume_size_value);
-	int n = 0;
-	if (too_much) { /* files size is larger than available space */
-		/* 2TRANS: this string displays total size of dirs/files
-		   selected ('%.1f'), total available space ('%d') and
-		   number of items selected (second '%d'). */
-		mvwprintw(subwindow, s_row, col, _("%.1f/%ld MB in %d items"),
-			  size_mb, global_config.volume_size_value, n_files);
-
-		n = bar_width;
-	} else {
-		/* 2TRANS: this string displays total size of dirs/files
-		   selected ('%.1f'), total available space ('%d'), number of
-		   items selected (second '%d'), and free space left ('%.0f'). */
-		mvwprintw(subwindow, s_row, col, _("%.1f/%ld MB in %d items, %.0f MB free"),
-			  size_mb, global_config.volume_size_value,
-			  n_files, (double) global_config.volume_size_value - size_mb);
-
-		n = (int) ((percent * (double) bar_width) / 100);
-	}
-
-	mvwhline(subwindow, b_row, col + 1, ACS_BLOCK, n); /* +1 to skip left brace [ */
-
-	mvwprintw(subwindow, b_row, col + bar_width + 3, /* 3 to move past indicator bar */
-		  /* 2TRANS: this is information about usage of CD space:
-		     '%2.1f%%' is information about used space, displayed
-		     as percentage of total disc size */
-		  _("%2.1f%%"), percent);
-
-	wattrset(subwindow, A_NORMAL | COLOR_PAIR(CDW_COLORS_MAIN));
-	wrefresh(subwindow);
+			     "Press F9 or F10 key in main window to see full license text."),
+			   CDW_BUTTONS_OK, CDW_COLORS_DIALOG);
 
 	return;
 }
-
-#endif
-
