@@ -1,6 +1,6 @@
 /* cdw
  * Copyright (C) 2002 Varkonyi Balazs
- * Copyright (C) 2007 - 2012 Kamil Ignacak
+ * Copyright (C) 2007 - 2014 Kamil Ignacak
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 #define _GNU_SOURCE /* strndup() */
 
@@ -110,10 +110,16 @@ static void cdw_ncurses_make_custom_key_definitions(void);
 cdw_rv_t cdw_ncurses_init(void)
 {
 	initscr();
-	start_color();
-	cbreak();
-	noecho();
-	keypad(stdscr, TRUE);
+	int rv = start_color();
+	cdw_vdm_n ("start_color", rv, "");
+	rv = cbreak();
+	cdw_vdm_n ("cbreak", rv, "");
+	rv = noecho();
+	cdw_vdm_n ("noecho", rv, "");
+	rv = keypad(stdscr, TRUE);
+	cdw_vdm_n ("keypad", rv, "");
+	rv = refresh();
+	cdw_vdm_n ("refresh", rv, "");
 
 	if (cdw_commandline_arguments.escdelay_ms != -1) {
 		set_escdelay(cdw_commandline_arguments.escdelay_ms);
@@ -220,7 +226,7 @@ cdw_rv_t cdw_ncurses_get_field_buffer(FIELD *field, char **buffer, size_t limit)
 
 	cdw_vdm ("INFO: reallocing buffer for len = %zd\n", len);
 	char *tmp = (char *) realloc(*buffer, len + 1);
-	if (tmp == (char *) NULL) {
+	if (!tmp) {
 		cdw_vdm ("ERROR: failed to reallocate buffer with new len %zd\n", len);
 		return CDW_ERROR;
 	} else {
@@ -324,28 +330,20 @@ void cdw_ncurses_delete_menu_and_items(MENU **menu)
 		   # Free the menu, using free_menu().
 		   # Free the items using free_item(). */
 
-		unpost_menu(*menu);
+		int rv = unpost_menu(*menu);
+		cdw_vdm_n ("unpost_menu", rv, "");
+
 		ITEM **items = menu_items(*menu);
 
-		int rv = free_menu(*menu);
+		rv = free_menu(*menu);
 		*menu = (MENU *) NULL;
-		if (rv == E_OK) {
-			;
-		} else if (rv == E_SYSTEM_ERROR) {
-			int e = errno;
-			cdw_vdm ("ERROR: failed to free menu, error = \"%s\"\n", strerror(e));
-		} else if (rv == E_BAD_ARGUMENT) {
-			cdw_vdm ("ERROR: failed to free menu, bad argument\n");
-		} else if (rv == E_POSTED) {
-			cdw_vdm ("ERROR: failed to free menu, menu is posted\n");
-		} else {
-			cdw_vdm ("ERROR: unrecognized error when calling free_menu: %d\n", rv);
-		}
+		cdw_vdm_n ("free_menu", rv, "");
 
 		if (items != (ITEM **) NULL) {
 			for (int i = 0; items[i] != (ITEM *) NULL; i++){
-				free_item(items[i]);
+				rv = free_item(items[i]);
 				items[i] = (ITEM *) NULL;
+				cdw_vdm_n ("free_item", rv, "");
 			}
 
 			free(items);
@@ -374,9 +372,11 @@ static cdw_id_clabel_t cdw_ncurses_key_labels[] =
 		{ KEY_NPAGE,    "Page Down" },
 		{ KEY_HOME,     "KEY_HOME" },
 		{ KEY_END,      "KEY_END" },
+		{ KEY_EXIT,     "KEY_EXIT" },
 		{ ' ',          "SPACE" },
 		{ '\t',         "TAB" },
 		{ CDW_KEY_TAB,  "TAB" },
+		{ KEY_BTAB,     "BackTAB" },
 		{ KEY_F(1),     "F1" },
 		{ KEY_F(2),     "F2" },
 		{ KEY_F(3),     "F3" },
@@ -484,7 +484,7 @@ FIELD *cdw_ncurses_new_input_field(int n_lines, int n_cols, int begin_y, int beg
 			cdw_vdm ("ERROR: failed to turn off O_PUBLIC with field_opts_off(), error = \"%s\"\n", cdw_ncurses_error_string(e));
 		}
 	} else {
-		if (initial_value != (char *) NULL) {
+		if (initial_value) {
 			/* this may also set content of buffer to "" */
 			e = set_field_buffer(field, 0, initial_value);
 			if (e != E_OK) {
@@ -538,6 +538,7 @@ FIELD *cdw_ncurses_new_label_field(int n_lines, int n_cols, int begin_y, int beg
 	if (!field) {
 		int e = errno;
 		cdw_vdm ("ERROR: failed to create a field with new_field(), \"%s\"\n", cdw_ncurses_error_string(e));
+		cdw_vdm ("ERROR: n_lines = %d, n_cols = %d, begin_y = %d, begin_x = %d\n", n_lines, n_cols, begin_y, begin_x);
 		return (FIELD *) NULL;
 	}
 
@@ -592,12 +593,12 @@ FIELD *cdw_ncurses_new_checkbox_field(int begin_y, int begin_x, const char *init
 	                    int offscreen, int nbuffers); */
 
 	FIELD *field = new_field(1, 1, begin_y, begin_x, 0, 0);
-	if (field == (FIELD *) NULL) {
+	if (!field) {
 		cdw_vdm ("ERROR: failed to create a field with new_field\n");
 		return (FIELD *) NULL;
 	}
 	int rv = 0;
-	if (initial_value != (char *) NULL) {
+	if (initial_value) {
 		rv = set_field_buffer(field, 0, initial_value);
 		if (rv != E_OK) {
 			cdw_vdm ("ERROR: set_field_buffer() returns !E_OK\n");
@@ -685,37 +686,36 @@ void cdw_ncurses_make_custom_key_definitions(void)
 */
 FORM *cdw_ncurses_new_form(WINDOW *window, WINDOW *subwindow, FIELD *field[])
 {
-	cdw_assert (window != (WINDOW *) NULL, "ERROR: function called with window == NULL\n");
-	cdw_assert (subwindow != (WINDOW *) NULL, "ERROR: function called with subwindow == NULL\n");
+	cdw_assert (window, "ERROR: function called with window == NULL\n");
+	cdw_assert (subwindow, "ERROR: function called with subwindow == NULL\n");
 	cdw_assert (field != (FIELD **) NULL, "ERROR: function called with fields array == NULL\n");
 
 	FORM *form = new_form(field);
-	if (form == (FORM *) NULL) {
+	if (!form) {
 #ifndef NDEBUG
 		int e = errno;
-		cdw_vdm ("ERROR: failed to create form with new_form(), error code is \"%s\"\n",
-			 cdw_ncurses_error_string(e));
+		cdw_vdm ("ERROR: failed to create form with new_form(): \"%s\"\n", cdw_ncurses_error_string(e));
 #endif
 		return (FORM *) NULL;
 	}
 	int r;
 	r = set_form_win(form, window);
 	if (r != E_OK) {
-		cdw_vdm ("ERROR: failed to set form window with set_form_win(), error code is \"%s\"\n", cdw_ncurses_error_string(r));
+		cdw_vdm ("ERROR: failed to set form window with set_form_win(): \"%s\"\n", cdw_ncurses_error_string(r));
 		free_form(form);
 		form = (FORM *) NULL;
 		return (FORM *) NULL;
 	}
 	r = set_form_sub(form, subwindow);
 	if (r != E_OK) {
-		cdw_vdm ("ERROR: failed to set form subwindow with set_form_sub(), error code is \"%s\"\n", cdw_ncurses_error_string(r));
+		cdw_vdm ("ERROR: failed to set form subwindow with set_form_sub(): \"%s\"\n", cdw_ncurses_error_string(r));
 		free_form(form);
 		form = (FORM *) NULL;
 		return (FORM *) NULL;
 	}
 	r = post_form(form);
 	if (r != E_OK) {
-		cdw_vdm ("ERROR: failed to post form with post_form(), error code is \"%s\"\n", cdw_ncurses_error_string(r));
+		cdw_vdm ("ERROR: failed to post form with post_form(): \"%s\"\n", cdw_ncurses_error_string(r));
 		free_form(form);
 		form = (FORM *) NULL;
 		return (FORM *) NULL;
@@ -731,7 +731,7 @@ FORM *cdw_ncurses_new_form(WINDOW *window, WINDOW *subwindow, FIELD *field[])
 /**
    \brief Get string from given field's buffer
 
-   Function removes trailing white chars from te string before returning it.
+   Function removes trailing white chars from the string before returning it.
 
    Function returns empty string ("") if given field's buffer is NULL.
 
@@ -741,10 +741,10 @@ FORM *cdw_ncurses_new_form(WINDOW *window, WINDOW *subwindow, FIELD *field[])
 */
 char *cdw_ncurses_get_field_string(FIELD *field)
 {
-	assert(field != (FIELD *) NULL);
+	cdw_assert (field, "ERROR: \"field\" argument is NULL\n");
 
 	char *s = field_buffer(field, 0);
-	if (s == (char *) NULL) {
+	if (!s) {
 		return empty_string;
 	} else {
 		cdw_vdm ("INFO: returning field string \"%s\"\n", s);
@@ -752,36 +752,3 @@ char *cdw_ncurses_get_field_string(FIELD *field)
 	}
 
 }
-
-
-
-/* *** unused code below */
-
-
-
-
-
-# if 0
-
-
-
-/**
-   \brief Get 0/1 state from a checkbox widget associated with given field
-
-   Check content of field's buffer (if it is "X" or not) and return 0 or 1.
-
-   The field must be configured and used as a checkbox (field of size 1x1),
-   because only first character of field's buffer is checked.
-
-   \param field - field that you want to inspect
-
-   \return true if given field's buffer contains "X" string
-   \return false if given field's buffer does not contain "X" string
-*/
-bool cdw_ncurses_get_field_bit(FIELD *field)
-{
-	cdw_assert (field != (FIELD *) NULL, "ERROR: field argument passed for examination is NULL\n");
-	return !strncmp(field_buffer(field, 0), "X", 1) ? true : false;
-}
-
-#endif
