@@ -1,6 +1,6 @@
 /* cdw
  * Copyright (C) 2002 Varkonyi Balazs
- * Copyright (C) 2007 - 2012 Kamil Ignacak
+ * Copyright (C) 2007 - 2014 Kamil Ignacak
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #include <stdio.h>
@@ -29,6 +29,7 @@
 #include "cdw_window.h"
 #include "cdw_processwin.h"
 #include "cdw_debug.h"
+#include "cdw_string.h"
 
 
 /* *** some processwin layout constants *** */
@@ -52,7 +53,7 @@
 
 
 /* this string is used to erase parts of processwin - it has to be
- * filled with spaces (and ended with \0') first */
+  filled with spaces (and ended with \0') first */
 #define EMPTY_STRING_LEN PROCESSWIN_COLS - 2 - 1
 static char processwin_empty_string[EMPTY_STRING_LEN + 1];
 
@@ -61,11 +62,13 @@ static char processwin_empty_string[EMPTY_STRING_LEN + 1];
    changes, avoiding useless refreshes. It must be set to zero every time
    new processwin is created. Perhaps 'float' type is too fine-grained and
    processwin is updated too often. Or perhaps it is not so. */
-static float static_percent;
-
+static double static_percent;
 
 
+static cdw_rv_t cdw_processwin_progress_sub(char *progress_string, double percent_done, const char *description);
 static void cdw_processwin_display_text_info(int row, const char *string);
+static void cdw_processwin_reset_progressbar(void);
+
 
 static struct {
 	/* has the window been created and displayed? can
@@ -74,10 +77,15 @@ static struct {
 
 	WINDOW *window;
 
-	/* area where progress bar is displayed;
-	   may be used only by some instances of processwin */
+	/* Area where progress bar is displayed.
+	   May be used only by some instances of processwin. */
 	WINDOW *progressbar_sub;
 
+	/* Value indicated by progressbar. The variable is used to
+	   check how the progressbar should be drawn.  */
+	int progressbar_value;
+	int progressbar_cols;
+
 	WINDOW *subwindow_txt1;
 	WINDOW *subwindow_txt2;
 
@@ -93,19 +101,19 @@ static struct {
 
 
 /**
- * \brief Create UI window in which progress of some process (perhaps created by fork()) is shown
- *
- * Create UI window to show progress of process, make some initialization, too.
- * Put \p window_title string in title area of window.
- * Put \p window_label in first row of window (below title).
- *
- * \param window_title - title of processwin window
- * \param window_label - initial information displayed in window
- * \param show_progress - should progress bar be displayed?
- *
- * \return CDW_OK on success
- * \return CDW_GEN_ERROR if function failed to create progress window
- */
+   \brief Create UI window in which progress of some process (perhaps created by fork()) is shown
+
+   Create UI window to show progress of process, make some initialization, too.
+   Put \p window_title string in title area of window.
+   Put \p window_label in first row of window (below title).
+
+   \param window_title - title of processwin window
+   \param window_label - initial information displayed in window
+   \param show_progress - should progress bar be displayed?
+
+   \return CDW_OK on success
+   \return CDW_GEN_ERROR if function failed to create progress window
+*/
 cdw_rv_t cdw_processwin_create(const char *window_title, const char *window_label, bool show_progress)
 {
 	if (processwin.active) {
@@ -129,7 +137,7 @@ cdw_rv_t cdw_processwin_create(const char *window_title, const char *window_labe
 				   processwin.begin_y,
 				   processwin.begin_x);
 
-	if (processwin.window == (WINDOW *) NULL) {
+	if (!processwin.window) {
 		cdw_vdm ("ERROR: failed to create process window with newwin()\n");
 		return CDW_ERROR;
 	}
@@ -143,7 +151,7 @@ cdw_rv_t cdw_processwin_create(const char *window_title, const char *window_labe
 					   processwin.n_cols - 2,
 					   processwin.subwindow_txt1_row, 1);
 
-	if (processwin.subwindow_txt1 == (WINDOW *) NULL) {
+	if (!processwin.subwindow_txt1) {
 		delwin(processwin.window);
 		processwin.window = (WINDOW *) NULL;
 		cdw_vdm ("ERROR: failed to create subwindow_txt1 with derwin()\n");
@@ -152,7 +160,7 @@ cdw_rv_t cdw_processwin_create(const char *window_title, const char *window_labe
 	processwin.subwindow_txt2 = derwin(processwin.window, 2,
 					   processwin.n_cols - 2,
 					   processwin.subwindow_txt2_row, 1);
-	if (processwin.subwindow_txt2 == (WINDOW *) NULL) {
+	if (!processwin.subwindow_txt2) {
 		delwin(processwin.subwindow_txt1);
 		processwin.subwindow_txt1 = (WINDOW *) NULL;
 		delwin(processwin.window);
@@ -166,6 +174,7 @@ cdw_rv_t cdw_processwin_create(const char *window_title, const char *window_labe
 	if (show_progress) {
 		cdw_processwin_add_progress_bar();
 	}
+	processwin.progressbar_value = 0;
 
 	processwin.active = true;
 
@@ -182,21 +191,21 @@ cdw_rv_t cdw_processwin_create(const char *window_title, const char *window_labe
 
 
 /**
- * \brief Destroy UI window created by processwin_create()
- *
- * This is just wrapper for simple destroying of curses window
- * Set second argument as true if you want to wait for user key
- * before destroying the window - user will have time and opportunity
- * to read \p status_string. The string will be displayed
- * as primary information string in processwin. Secondary information
- * string will be sth like "press any key". If \p is false, then
- * \p status_string won't be displayed, and window will be destroyed
- * without waiting for any user action.
- *
- * \param status_string - text displayed in process window
- * \param wait - decides if the window should wait for a key from
- *                    user before closing.
- */
+   \brief Destroy UI window created by processwin_create()
+
+   This is just wrapper for simple destroying of curses window
+   Set second argument as true if you want to wait for user key
+   before destroying the window - user will have time and opportunity
+   to read \p status_string. The string will be displayed
+   as primary information string in processwin. Secondary information
+   string will be sth like "press any key". If \p is false, then
+   \p status_string won't be displayed, and window will be destroyed
+   without waiting for any user action.
+
+   \param status_string - text displayed in process window
+   \param wait - decides if the window should wait for a key from
+   user before closing.
+*/
 void cdw_processwin_destroy(const char *status_string, bool wait)
 {
 	if (!processwin.active) {
@@ -226,10 +235,10 @@ void cdw_processwin_destroy(const char *status_string, bool wait)
 	processwin.window = (WINDOW *) NULL;
 	processwin.active = false;
 
-	cdw_main_ui_main_window_wrefresh_part(processwin.n_rows,
-					      processwin.n_cols,
-					      processwin.begin_y,
-					      processwin.begin_x);
+	cdw_main_window_wrefresh_part(processwin.n_rows,
+				      processwin.n_cols,
+				      processwin.begin_y,
+				      processwin.begin_x);
 
 	return;
 }
@@ -249,9 +258,11 @@ bool cdw_processwin_is_active(void)
 
 void cdw_processwin_add_progress_bar(void)
 {
-	/* build progress bar */
-	/* 27 = 25 + 2: 2 chars for borders and 25 chars for progress bar (4% per char) */
-	int n_cols = 27;
+	/* Build progress bar. */
+	cdw_assert (PROCESSWIN_COLS == 50, "ERROR: recalculate width of progress bar.\n");
+
+	processwin.progressbar_cols = 40; /* Value smaller than PROCESSWIN_COLS - borders. */
+	int n_cols = processwin.progressbar_cols + 2; /* 2 chars for borders of progress bar area. */
 	int n_rows = 3; /* upper border + progress bar strip + lower border */
         int begin_y = PROCESSWIN_PROGRESSBAR_CENTRAL_ROW - 1;
 	int begin_x = (processwin.n_cols - n_cols) / 2;
@@ -265,6 +276,8 @@ void cdw_processwin_add_progress_bar(void)
 	cdw_processwin_display_progress(0, 100, "");
 	cdw_processwin_wrefresh();
 
+	processwin.progressbar_value = 0;
+
 	return;
 }
 
@@ -279,7 +292,7 @@ void cdw_processwin_delete_progress_bar(void)
 		return;
 	}
 
-	if (processwin.progressbar_sub == (WINDOW *) NULL) {
+	if (!processwin.progressbar_sub) {
 		cdw_vdm ("ERROR: called the function for process window without progress bar\n");
 		return;
 	}
@@ -298,6 +311,8 @@ void cdw_processwin_delete_progress_bar(void)
 	delwin(processwin.progressbar_sub);
 	processwin.progressbar_sub = (WINDOW *) NULL;
 
+	processwin.progressbar_value = 0;
+
 	return;
 }
 
@@ -306,14 +321,14 @@ void cdw_processwin_delete_progress_bar(void)
 
 
 /**
- * \brief Display ETA string in progress window
- *
- * The function itself doesn't know anything about calculation of ETA, it just
- * knows if and where to display it. You can erase place where usually
- * ETA string is displayed by providing null string ((char *) NULL) as an argument.
- *
- * \param eta_string - string containing ETA information
- */
+   \brief Display ETA string in progress window
+
+   The function itself doesn't know anything about calculation of ETA, it just
+   knows if and where to display it. You can erase place where usually
+   ETA string is displayed by providing null string ((char *) NULL) as an argument.
+
+   \param eta_string - string containing ETA information
+*/
 void cdw_processwin_display_eta(const char *eta_string)
 {
 	if (!processwin.active) {
@@ -354,21 +369,25 @@ void cdw_processwin_erase_eta(void)
 
 
 /**
- * \brief Draw progress bar strip in processwin
- *
- * Draw progress bar strip (not the borders, those should be created
- * when processwin itself is created) of length=value. Maximal value of
- * variable 'value' should be normalized by caller to width of processwin.
- *
- * \param value - current length of progress bar to draw
- * \param color1 - color name used for drawing a progress bar
- * \param color2 - name of normal color of process window
- * \param c - character to be used to draw bar
- */
+   \brief Draw progress bar strip in processwin
+
+   Draw progress bar strip (not the borders, those should be created
+   when processwin itself is created) of length=value. Maximal value of
+   variable 'value' should be normalized by caller to width of processwin.
+
+   \param value - current length of progress bar to draw
+   \param color1 - color name used for drawing a progress bar
+   \param color2 - name of normal color of process window
+   \param c - character to be used to draw bar
+*/
 void cdw_processwin_draw_progress_bar(int value, cdw_colors_t color1, cdw_colors_t color2, chtype c)
 {
-	cdw_assert (processwin.progressbar_sub != (WINDOW *) NULL,
-		    "ERROR: called %s() for processwin without progressbar\n", __func__);
+	cdw_assert (processwin.progressbar_sub, "ERROR: called %s() for processwin without progressbar\n", __func__);
+
+	if (value < processwin.progressbar_value) {
+		/* Progress bar will have to be drawn from scratch. */
+		cdw_processwin_reset_progressbar();
+	}
 
 	const int start_col = 1;
 	(void) wattrset(processwin.progressbar_sub, COLOR_PAIR(color1));
@@ -379,6 +398,8 @@ void cdw_processwin_draw_progress_bar(int value, cdw_colors_t color1, cdw_colors
 	(void) wattrset(processwin.progressbar_sub, COLOR_PAIR(color2));
 	wrefresh(processwin.progressbar_sub);
 
+	processwin.progressbar_value = value;
+
 	return;
 }
 
@@ -387,20 +408,20 @@ void cdw_processwin_draw_progress_bar(int value, cdw_colors_t color1, cdw_colors
 
 
 /**
- * Show (in processwin window) information about progress of process. Do this only if necessary.
- *
- * Check if value describing current status (in terms of percentage of task
- * done) has changed. If yes, then update processwin with new information
- * (which requires call of ncurses wrefresh()). If not then do nothing.
- *
- * \param current - current status of task - this is value of arbitrary unit,
- *                  reflecting current amount of work done
- * \param total - total size of task - this is value of arbitrary unit (but
- *                  the same as of 'current'), reflecting maximal amount of
- *                  work that has to be done
- * \param description - string containing data or information
- *                  prepared by caller (can be NULL or empty)
- */
+   \brief Show (in processwin window) information about progress of process. Do this only if necessary.
+
+   Check if value describing current status (in terms of percentage of task
+   done) has changed. If yes, then update processwin with new information
+   (which requires call of ncurses wrefresh()). If not then do nothing.
+
+   \param current - current status of task - this is value of arbitrary unit,
+                    reflecting current amount of work done
+   \param total - total size of task - this is value of arbitrary unit (but
+                    the same as of 'current'), reflecting maximal amount of
+                    work that has to be done
+   \param description - string containing data or information
+                    prepared by caller (can be NULL or empty)
+*/
 void cdw_processwin_display_progress_conditional(long current, long total, const char *description)
 {
 	/* assertion may fail if caller botched calculations of
@@ -409,11 +430,11 @@ void cdw_processwin_display_progress_conditional(long current, long total, const
 		    "ERROR: value of \"current\" or \"total\" is negative: %ld / %ld\n", current, total);
 	/* new_static_percent reflects current amount of work done
 	   at given specific call to this function */
-	float new_static_percent = 0.0;
+	double new_static_percent = 0.0;
 	if (total != 0) {
 		/* FIXME: don't allow passing total == 0,
 		   improve interface of the function */
-		new_static_percent = (float) current / (float) total;
+		new_static_percent = (double) current / (double) total;
 	}
 
 	/* static_percent reflects amount of work done at
@@ -432,46 +453,70 @@ void cdw_processwin_display_progress_conditional(long current, long total, const
 
 
 /**
- * \brief Show (in processwin window) information about progress of process.
- *
- * Show to user updated information about progress of current process. This
- * can be done in two ways: by displaying text line prepared by caller or by
- * showing percentage information.
- *
- * Third argument can have any character, even descriptive, but since this
- * function is called cdw_processwin_display_progress(), it would be nice if
- * this argument hold some sort of numerical information, perhaps with units
- * of measure.
- *
- * First and second argument should be provided without any preprocessing,
- * because they will be recalculated to percents like this:
- * percentage_info = (current_amount * 100) / total_amount.
- *
- * Percentage information is shown both in form of "x% done" text and in form
- * of progress bar.
- *
- * All information is displayed in one line, in following format:
- * "xx% done (current_value_string)". Both parts ('xx%done' and
- * 'current_value_string') can be omitted (set to 0 or (char *) NULL).
- *
- * \p description should be no longer than (PROCESSWIN_COLS - 2) chars,
- * including ending '\0'. It should be even shorter to make place for
- * numeric data displayed in the same line as \p description.
- *
- * \param current_amount - value representing current state (stage) of process
- * \param total_amount - value representing final, expected state (stage) of process
- * \param description - string containing details on data or other information
- */
-void cdw_processwin_display_progress(long current_amount, long total_amount, const char *description)
-{
-	bool has_descr = false; /* is description string non-empty? */
-	char progress_string[PROCESSWIN_MAX_RTEXT_LEN + 1];
+   \brief Show (in processwin window) information about progress of process in percents. Do this only if necessary.
 
-	/* first check for NULLness, so strlen arg will be safe */
-	if (description && (strlen(description)) ) {
-		has_descr = true;
+   Check if value describing current status (in terms of percentage of task
+   done) has changed. If yes, then update processwin with new information
+   (which requires call of ncurses wrefresh()). If not then do nothing.
+
+   \param current_percent - current status of task in percents - this value reflects current amount of work done
+   \param description - string containing data or information prepared by caller (can be NULL or empty)
+*/
+void cdw_processwin_display_percentage_progress_conditional(double current_percent, const char *description)
+{
+	/* Assertion may fail if caller botched calculations of
+	   current_percent, causing overflows. */
+	cdw_assert (current_percent >= -0.0001,  "ERROR: value of \"current percent\" is negative: %f\n", current_percent);
+
+	/* static_percent reflects amount of work done at
+	   previous call to this function */
+	if (current_percent - static_percent > 0.0001) {
+		/* if they differ then information in processwin should be updated */
+		static_percent = current_percent;
+		cdw_processwin_display_percentage_progress(current_percent, description);
 	}
 
+	return;
+}
+
+
+
+
+
+/**
+   \brief Show (in processwin window) information about progress of process.
+
+   Show to user updated information about progress of current process. This
+   can be done in two ways: by displaying text line prepared by caller or by
+   showing percentage information.
+
+   Third argument can have any character, even descriptive, but since this
+   function is called cdw_processwin_display_progress(), it would be nice if
+   this argument hold some sort of numerical information, perhaps with units
+   of measure.
+
+   First and second argument should be provided without any preprocessing,
+   because they will be recalculated to percents like this:
+   percentage_info = (current_amount  100) / total_amount.
+
+   Percentage information is shown both in form of "x% done" text and in form
+   of progress bar.
+
+   All information is displayed in one line, in following format:
+   "xx% done (current_value_string)". Both parts ('xx%done' and
+   'current_value_string') can be omitted (set to 0 or (char *) NULL).
+
+   \p description should be no longer than (PROCESSWIN_COLS - 2) chars,
+   including ending '\0'. It should be even shorter to make place for
+   numeric data displayed in the same line as \p description.
+
+   \param current_amount - value representing current state (stage) of process
+   \param total_amount - value representing final, expected state (stage) of process
+   \param description - string containing details on data or other information
+*/
+void cdw_processwin_display_progress(long current_amount, long total_amount, const char *description)
+{
+	char progress_string[PROCESSWIN_MAX_RTEXT_LEN + 1];
 	memset(progress_string, ' ', PROCESSWIN_MAX_RTEXT_LEN + 1);
 	progress_string[PROCESSWIN_MAX_RTEXT_LEN] = '\0';
 	mvwprintw(processwin.window, PROCESSWIN_AMOUNT_ROW, 1, "%s", progress_string);
@@ -479,26 +524,12 @@ void cdw_processwin_display_progress(long current_amount, long total_amount, con
 	if (total_amount) {
 		/* we are able to calculate percentage and display progress bar */
 
-		int percent_done = (int) ((current_amount * 100) / total_amount);
+		double percent_done = 100.0 * ((double) current_amount / (double) total_amount);
+
+		cdw_processwin_progress_sub(progress_string, percent_done, description);
 
-		if (has_descr) {
-			snprintf(progress_string, PROCESSWIN_MAX_RTEXT_LEN + 1,
-				 /* 2TRANS: status message displayed in progress
-				    window: %d%% is percent amount of task finished,
-				    %s is previously prepared string displaying
-				    some additional information about %d, e.g. units */
-				 _("%d%% done (%s)"), percent_done, description);
-		} else {
-			snprintf(progress_string, PROCESSWIN_MAX_RTEXT_LEN + 1,
-				 /* 2TRANS: status message displayed in progress
-				    window: %d%% is percent amount of task finished */
-				 _("%d%% done"), percent_done);
-		}
-		cdw_processwin_draw_progress_bar((percent_done / 4) - 1,
-						 CDW_COLORS_DIALOG,
-						 CDW_COLORS_DIALOG, ACS_BLOCK);
 	} else { /* total_amount == 0, so there is no way we can show percentage information */
-		if (has_descr) {
+		if (description && strlen(description)) {
 			strncpy(progress_string, description, PROCESSWIN_MAX_RTEXT_LEN);
 			progress_string[PROCESSWIN_MAX_RTEXT_LEN] = '\0';
 		} else {
@@ -518,15 +549,91 @@ void cdw_processwin_display_progress(long current_amount, long total_amount, con
 
 
 
+cdw_rv_t cdw_processwin_progress_sub(char *progress_string, double percent_done, const char *description)
+{
+	if (description && strlen(description)) {
+		snprintf(progress_string, PROCESSWIN_MAX_RTEXT_LEN + 1,
+			 /* 2TRANS: status message displayed in progress
+			    window: %.2f%% is percent amount of task finished,
+			    %s is previously prepared string displaying
+			    some additional information about %d, e.g. units */
+			 _("%.2f%% done (%s)"), percent_done, description);
+	} else {
+		snprintf(progress_string, PROCESSWIN_MAX_RTEXT_LEN + 1,
+			 /* 2TRANS: status message displayed in progress
+			    window: %.2f%% is percent amount of task finished */
+			 _("%.2f%% done"), percent_done);
+	}
+
+	double factor = 100.0 / processwin.progressbar_cols;
+	cdw_processwin_draw_progress_bar((int) ((percent_done / factor) - 1),
+					 CDW_COLORS_DIALOG,
+					 /* While it would be nice to
+					    have a 'block' character
+					    to be used to draw
+					    progress bar, the
+					    character is not displayed
+					    correctly on some
+					    terminals. */
+					 // CDW_COLORS_DIALOG, ACS_BLOCK);
+					 CDW_COLORS_DIALOG, '#');
+
+	return CDW_OK;
+}
+
+
+
+
+
+/**
+   \brief Show (in processwin window) information about progress of process in percents
+
+   Show to user updated information about progress of current process. This
+   can be done in two ways: by displaying text line prepared by caller or by
+   showing percentage information.
+
+   Percentage information is shown both in form of "x% done" text and in form
+   of progress bar.
+
+   \p description should be no longer than (PROCESSWIN_COLS - 2) chars,
+   including ending '\0'. It should be even shorter to make place for
+   numeric data displayed in the same line as \p description.
+
+   \param percent_done - value representing current state (stage) of process in percents
+   \param description - string containing details on data or other information
+*/
+void cdw_processwin_display_percentage_progress(double percent_done, const char *description)
+{
+	char progress_string[PROCESSWIN_MAX_RTEXT_LEN + 1];
+	memset(progress_string, ' ', PROCESSWIN_MAX_RTEXT_LEN + 1);
+	progress_string[PROCESSWIN_MAX_RTEXT_LEN] = '\0';
+	mvwprintw(processwin.window, PROCESSWIN_AMOUNT_ROW, 1, "%s", progress_string);
+
+	cdw_processwin_progress_sub(progress_string, percent_done, description);
+
+	int col = (processwin.n_cols / 2) - ((int) strlen(progress_string) / 2);
+	mvwprintw(processwin.window, PROCESSWIN_AMOUNT_ROW, col, "%s", progress_string);
+
+	wrefresh(processwin.window);
+
+	return;
+}
+
+
+
+
+
 void cdw_processwin_display_main_info(const char *string)
 {
 	cdw_processwin_display_text_info(1, string);
+	cdw_processwin_force_refresh();
 	return;
 }
 
 void cdw_processwin_display_sub_info(const char *string)
 {
 	cdw_processwin_display_text_info(2, string);
+	cdw_processwin_force_refresh();
 	return;
 }
 
@@ -535,18 +642,18 @@ void cdw_processwin_display_sub_info(const char *string)
 
 
 /**
- * \brief Show (in processwin window) text information about status of process
- *
- * Display string with information, or erase (blank) it. The string is
- * displayed in first or second topmost row, depending on value of
- * first argument. Accepted values of \p row are 1 or 2.
- *
- * Set second argument to (char *) NULL if you want to erase it, or set
- * it to pointer to a valid string if you want to display the string.
- *
- * \param row - index of row that you want to update
- * \param string - string displayed in processwin
- */
+   \brief Show (in processwin window) text information about status of process
+
+   Display string with information, or erase (blank) it. The string is
+   displayed in first or second topmost row, depending on value of
+   first argument. Accepted values of \p row are 1 or 2.
+
+   Set second argument to (char *) NULL if you want to erase it, or set
+   it to pointer to a valid string if you want to display the string.
+
+   \param row - index of row that you want to update
+   \param string - string displayed in processwin
+*/
 void cdw_processwin_display_text_info(int row, const char *string)
 {
 	cdw_assert (row == 1 || row == 2, "ERROR: incorrect id of row to print in (%d), should be 1 or 2\n", row);
@@ -563,10 +670,10 @@ void cdw_processwin_display_text_info(int row, const char *string)
 	} else {
 		window = processwin.subwindow_txt2;
 	}
-	cdw_assert (window != (WINDOW *) NULL, "ERROR: attempting to print to NULL window\n");
+	cdw_assert (window, "ERROR: attempting to print to NULL window\n");
 
 	werase(window);
-	if (string != (char *) NULL && (strcmp(string, ""))) {
+	if (string && (strcmp(string, ""))) {
 		cdw_window_print_message(window, string, CDW_ALIGN_CENTER);
 	} else {
 		/* user may pass null pointer or empty string ("")
@@ -582,14 +689,14 @@ void cdw_processwin_display_text_info(int row, const char *string)
 
 
 /**
- * \brief Display fifo buffer information
- *
- * This function displays test string in form of "Fifo: %d%%" in
- * process window. It is useful when writing data to a disc.
- * If fifo value is lower than 25, the text background is highlighted.
- *
- * \param fifo_level - FIFO buffer usage value (0 - 100)
- */
+   \brief Display fifo buffer information
+
+   This function displays test string in form of "Fifo: %d%%" in
+   process window. It is useful when writing data to a disc.
+   If fifo value is lower than 25, the text background is highlighted.
+
+   \param fifo_level - FIFO buffer usage value (0 - 100)
+*/
 void cdw_processwin_display_fifo_and_speed(int fifo_level, int speed_decimal, int speed_fract)
 {
 	if (!processwin.active) {
@@ -644,7 +751,7 @@ void cdw_processwin_display_fifo_and_speed(int fifo_level, int speed_decimal, in
 		   "Speed" is writing speed, %d and %d are decimal and fractional
 		   parts of writing speed, e.g. "Speed: 2.5x" */
 		sprintf(speed_string, _("Speed: %2d.%dx"), speed_decimal, speed_fract);
-		cdw_vdm ("INFO: speed: decimal = %d, fract = %d -> string = \"%s\"\n",
+		cdw_sdm ("INFO: speed: decimal = %d, fract = %d -> string = \"%s\"\n",
 			 speed_decimal, speed_fract, speed_string);
 
 		int col = 0;
@@ -720,10 +827,10 @@ void cdw_processwin_wgetch(void)
 
 
 /**
- * \brief Very simple wrapper for functions refreshing processwin window
- *
- * First the window is touchwin()ed and then it is wrefresh()ed.
- */
+   \brief Very simple wrapper for functions refreshing processwin window
+
+   First the window is touchwin()ed and then it is wrefresh()ed.
+*/
 void cdw_processwin_force_refresh(void)
 {
 	if (!processwin.active) {
@@ -732,6 +839,7 @@ void cdw_processwin_force_refresh(void)
 	}
 	touchwin(processwin.window);
 	wrefresh(processwin.window);
+	redrawwin(processwin.window);
 
 	return;
 }
@@ -741,8 +849,8 @@ void cdw_processwin_force_refresh(void)
 
 
 /**
- * \brief Reset any information about progress accumulated so far in progress window
- */
+   \brief Reset any information about progress accumulated so far in progress window
+*/
 void cdw_processwin_reset_progress(void)
 {
 	if (!processwin.active) {
@@ -758,15 +866,25 @@ void cdw_processwin_reset_progress(void)
 	progress_string[PROCESSWIN_MAX_RTEXT_LEN] = '\0';
 	mvwprintw(processwin.window, PROCESSWIN_AMOUNT_ROW, 1, "%s", progress_string);
 
-	int ncols = getmaxx(processwin.progressbar_sub);
-	for (int i = 1; i < ncols - 1; i++) {
-		mvwprintw(processwin.progressbar_sub, 1, i, " ");
-	}
+	cdw_processwin_reset_progressbar();
 
-	wrefresh(processwin.progressbar_sub);
 	wrefresh(processwin.window);
 
 	return;
 }
 
 
+
+
+
+void cdw_processwin_reset_progressbar(void)
+{
+	int ncols = getmaxx(processwin.progressbar_sub);
+	for (int i = 1; i < ncols - 1; i++) {
+		mvwprintw(processwin.progressbar_sub, 1, i, " ");
+	}
+
+	wrefresh(processwin.progressbar_sub);
+
+	return;
+}
