@@ -1,6 +1,6 @@
 /* cdw
  * Copyright (C) 2002 Varkonyi Balazs
- * Copyright (C) 2007 - 2012 Kamil Ignacak
+ * Copyright (C) 2007 - 2014 Kamil Ignacak
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 #define _GNU_SOURCE /* asprintf() */
 #include <stdio.h>
@@ -75,7 +75,7 @@ static void cdw_tabs_window_refresh_current_tab(cdw_tabs_window_t *twindow);
 cdw_tabs_window_t *cdw_tabs_window_init(int n_tabs, const char *title, const char *subtitle)
 {
 	cdw_tabs_window_t *twindow = (cdw_tabs_window_t *) malloc(sizeof (cdw_tabs_window_t));
-	if (twindow == (cdw_tabs_window_t *) NULL) {
+	if (!twindow) {
 		cdw_vdm ("ERROR: failed to create tabs window\n");
 		return (cdw_tabs_window_t *) NULL;
 	}
@@ -96,7 +96,7 @@ cdw_tabs_window_t *cdw_tabs_window_init(int n_tabs, const char *title, const cha
 	twindow->geometry.tabs_width = 0;
 
 	twindow->tabs = (cdw_tab_t *) malloc((long unsigned int) n_tabs * sizeof (cdw_tab_t));
-	if (twindow->tabs == (cdw_tab_t *) NULL) {
+	if (!twindow->tabs) {
 		cdw_vdm ("ERROR: failed to create tabs in twindow\n");
 		free(twindow);
 		twindow = (cdw_tabs_window_t *) NULL;
@@ -105,7 +105,7 @@ cdw_tabs_window_t *cdw_tabs_window_init(int n_tabs, const char *title, const cha
 
 	twindow->title = strdup(title);
 	twindow->subtitle = strdup(subtitle);
-	if (twindow->title == (char *) NULL || twindow->subtitle == (char *) NULL) {
+	if (!twindow->title || !twindow->subtitle) {
 		cdw_vdm ("ERROR: failed to strdup window title \"%s\" or subtitle \"%s\"\n",
 			 title, subtitle);
 		cdw_tabs_window_delete(&twindow);
@@ -138,12 +138,12 @@ cdw_tabs_window_t *cdw_tabs_window_init(int n_tabs, const char *title, const cha
 
 cdw_rv_t cdw_tabs_window_append_tab(cdw_tabs_window_t *twindow, cdw_id_t id, int hotkey, const char *label)
 {
-	cdw_assert (twindow != (cdw_tabs_window_t *) NULL, "ERROR: twindow is NULL\n");
-	cdw_assert (label != (char *) NULL, "ERROR: tab label is NULL\n");
+	cdw_assert (twindow, "ERROR: twindow is NULL\n");
+	cdw_assert (label, "ERROR: tab label is NULL\n");
 
 	/* search for first free slot and "insert" a new tab there */
 	for (int i = 0; i < twindow->n_tabs; i++) {
-		if (twindow->tabs[i].label == (char *) NULL) {
+		if (!twindow->tabs[i].label) { /* Yes, this is a lame test of free slot. */
 			twindow->tabs[i].id = id;
 			asprintf(&(twindow->tabs[i].label), "<%s>%s", cdw_ncurses_key_label(hotkey), label);
 			cdw_vdm ("INFO: added label #%d: \"%s\"\n", i, twindow->tabs[i].label);
@@ -198,7 +198,7 @@ void cdw_tabs_window_draw_tabs(cdw_tabs_window_t *twindow)
 	for (int i = 0; i < twindow->n_tabs; i++) {
 		WINDOW *window = twindow->tabs[i].subwindow;
 		/* this may happen if there are less tabs attached than n_tabs */
-		cdw_assert (window != (WINDOW *) NULL, "ERROR: subwindow #%d is NULL\n", i);
+		cdw_assert (window, "ERROR: subwindow #%d is NULL\n", i);
 
 		int start_col = twindow->geometry.n_cols - twindow->geometry.tabs_width;
 		mvwvline(window, 0, start_col, ACS_VLINE, twindow->geometry.n_cols);
@@ -251,7 +251,7 @@ cdw_rv_t cdw_tabs_window_finalize(cdw_tabs_window_t *twindow)
 							 (LINES - twindow->geometry.n_lines) / 2,
 							 (COLS - twindow->geometry.n_cols) / 2,
 							 CDW_COLORS_DIALOG, twindow->title, twindow->subtitle);
-		if (twindow->tabs[i].window == (WINDOW *) NULL) {
+		if (!twindow->tabs[i].window) {
 			cdw_vdm ("ERROR: failed to create window #%d\n", i);
 			return CDW_ERROR;
 		}
@@ -260,13 +260,13 @@ cdw_rv_t cdw_tabs_window_finalize(cdw_tabs_window_t *twindow)
 							    twindow->geometry.n_lines - 2,
 							    twindow->geometry.n_cols - 2, 1, 1,
 							    CDW_COLORS_DIALOG, (char *) NULL, (char *) NULL);
-		if (twindow->tabs[i].subwindow == (WINDOW *) NULL) {
+		if (!twindow->tabs[i].subwindow) {
 			cdw_vdm ("ERROR: failed to create subwindow #%d\n", i);
 			return CDW_ERROR;
 		}
 
 		twindow->tabs[i].panel = new_panel(twindow->tabs[i].window);
-		if (twindow->tabs[i].panel == (PANEL *) NULL) {
+		if (!twindow->tabs[i].panel) {
 			cdw_vdm ("ERROR: failed to create panel #%d with new_panel()\n", i);
 			return CDW_ERROR;
 		}
@@ -312,7 +312,7 @@ int cdw_tabs_window_driver(cdw_tabs_window_t *twindow)
 
 			show_panel(twindow->tabs[twindow->current_tab].panel);
 			update_panels();
-			cdw_main_ui_main_window_wrefresh();
+			cdw_main_window_wrefresh();
 			cdw_tabs_window_refresh_current_tab(twindow);
 
 		} else if (cdw_tabs_window_is_return_key(twindow, key)) {
@@ -360,42 +360,28 @@ bool cdw_tabs_window_is_hotkey(cdw_tabs_window_t *twindow, int key, int *ti)
 
 void cdw_tabs_window_delete(cdw_tabs_window_t **twindow)
 {
-	if (*twindow == (cdw_tabs_window_t *) NULL) {
+	if (!*twindow) {
 		cdw_vdm ("WARNING: passed NULL twindow to the function\n");
 		return;
 	}
 
-	if ((*twindow)->title != (char *) NULL) {
-		free((*twindow)->title);
-		(*twindow)->title = (char *) NULL;
-	}
-	if ((*twindow)->subtitle != (char *) NULL) {
-		free((*twindow)->subtitle);
-		(*twindow)->subtitle = (char *) NULL;
-	}
+	cdw_string_delete(&(*twindow)->title);
+	cdw_string_delete(&(*twindow)->subtitle);
 
-	if ((*twindow)->tabs != (cdw_tab_t *) NULL) {
+	if ((*twindow)->tabs) {
 
 		for (int i = 0; i < (*twindow)->n_tabs; i++) {
 
-			if ((*twindow)->tabs[i].panel != (PANEL *) NULL) {
-				del_panel((*twindow)->tabs[i].panel);
+			if ((*twindow)->tabs[i].panel) {
+				int rv = del_panel((*twindow)->tabs[i].panel);
+				cdw_vdm_n ("del_panel", rv, "");
 				(*twindow)->tabs[i].panel = (PANEL *) NULL;
 			}
 
-			if ((*twindow)->tabs[i].subwindow != (WINDOW *) NULL) {
-				delwin((*twindow)->tabs[i].subwindow);
-				(*twindow)->tabs[i].subwindow = (WINDOW *) NULL;
-			}
+			cdw_window_delete(&(*twindow)->tabs[i].subwindow);
+			cdw_window_delete(&(*twindow)->tabs[i].window);
 
-			if ((*twindow)->tabs[i].window != (WINDOW *) NULL) {
-				delwin((*twindow)->tabs[i].window);
-				(*twindow)->tabs[i].window = (WINDOW *) NULL;
-			}
-			if ((*twindow)->tabs[i].label != (char *) NULL) {
-				free((*twindow)->tabs[i].label);
-				(*twindow)->tabs[i].label = (char *) NULL;
-			}
+			cdw_string_delete(&(*twindow)->tabs[i].label);
 		}
 
 		free((*twindow)->tabs);
@@ -426,7 +412,7 @@ void cdw_tabs_window_refresh_current_tab(cdw_tabs_window_t *twindow)
 
 void cdw_tabs_window_add_return_key(cdw_tabs_window_t *twindow, int key)
 {
-	cdw_assert (twindow != (cdw_tabs_window_t *) NULL, "ERROR: \"twindow\" argument is NULL\n");
+	cdw_assert (twindow, "ERROR: \"twindow\" argument is NULL\n");
 	cdw_assert (twindow->n_return_keys < N_RETURN_KEYS_MAX,
 		    "ERROR: there are already %d / %d return keys in the window, can't add another one\n",
 		    twindow->n_return_keys, N_RETURN_KEYS_MAX);
@@ -482,7 +468,7 @@ void cdw_tabs_window_add_return_keys(cdw_tabs_window_t *twindow, ...)
 */
 bool cdw_tabs_window_is_return_key(cdw_tabs_window_t *twindow, int key)
 {
-	cdw_assert (twindow != (cdw_tabs_window_t *) NULL, "ERROR: \"twindow\" argument is NULL\n");
+	cdw_assert (twindow, "ERROR: \"twindow\" argument is NULL\n");
 	cdw_assert (key != 0, "ERROR: asking for key = 0, which is an initialization value\n");
 
 	for (int i = 0; i < twindow->n_return_keys; i++) {
@@ -505,7 +491,7 @@ cdw_rv_t cdw_tabs_window_show_tab_by_id(cdw_tabs_window_t *twindow, cdw_id_t id)
 			twindow->current_tab = i;
 			show_panel(twindow->tabs[twindow->current_tab].panel);
 			update_panels();
-			cdw_main_ui_main_window_wrefresh();
+			cdw_main_window_wrefresh();
 			cdw_tabs_window_refresh_current_tab(twindow);
 
 			return CDW_OK;
