@@ -1,6 +1,6 @@
 /* cdw
  * Copyright (C) 2002 Varkonyi Balazs
- * Copyright (C) 2007 - 2012 Kamil Ignacak
+ * Copyright (C) 2007 - 2014 Kamil Ignacak
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #include "cdw_widgets.h"
@@ -47,8 +47,6 @@ static cdw_rv_t cdw_verify_wizard_build_fields(void);
 
 static CDW_DROPDOWN *cdw_verify_wizard_make_verify_mode_dropdown(WINDOW *window, int begin_y, int begin_x, int width);
 
-static int cdw_verify_wizard_on_enter_on_cancel(cdw_form_t *cdw_form, void *dummy);
-static int cdw_verify_wizard_on_enter_on_verify(cdw_form_t *cdw_form, void *dummy);
 static char *cdw_verify_wizard_make_message(int n_cols);
 
 static struct {
@@ -152,7 +150,7 @@ cdw_id_t cdw_verify_wizard(void)
 	cdw_verify_wizard_destroy();
 
 	/* redraw parent */
-	cdw_main_ui_main_window_wrefresh();
+	cdw_main_window_wrefresh();
 
 	return wizard.mode;
 }
@@ -221,20 +219,12 @@ void cdw_verify_wizard_init(void)
 */
 void cdw_verify_wizard_destroy(void)
 {
-	if (wizard.cdw_form->window != (WINDOW *) NULL) {
-		delwin(wizard.cdw_form->window);
-		wizard.cdw_form->window = (WINDOW *) NULL;
-	}
-
-	if (wizard.cdw_form->subwindow != (WINDOW *) NULL) {
-		delwin(wizard.cdw_form->subwindow);
-		wizard.cdw_form->subwindow = (WINDOW *) NULL;
-	}
-
-	if (wizard.cdw_form != (cdw_form_t *) NULL) {
-		cdw_form_delete_form_objects(wizard.cdw_form);
-		cdw_form_delete(&(wizard.cdw_form));
-	}
+	/* This order of these four function calls ensures minimum
+	   problems reported by valgrind. */
+	cdw_form_delete_form_objects(wizard.cdw_form);
+	cdw_window_delete(&wizard.cdw_form->subwindow);
+	cdw_window_delete(&wizard.cdw_form->window);
+	cdw_form_delete(&(wizard.cdw_form));
 
 	return;
 }
@@ -256,7 +246,7 @@ void cdw_verify_wizard_destroy(void)
 cdw_rv_t cdw_verify_wizard_build(void)
 {
 	wizard.cdw_form = cdw_form_new(CDW_VERIFY_WIZARD_N_FIELDS);
-	if (wizard.cdw_form == (cdw_form_t *) NULL) {
+	if (!wizard.cdw_form) {
 		cdw_vdm ("ERROR: failed to create cdw form\n");
 		return CDW_ERROR;
 	}
@@ -273,7 +263,7 @@ cdw_rv_t cdw_verify_wizard_build(void)
 						 /* 2TRANS: this is tip at the bottom of window - user can
 						    switch between window elements using tab key */
 						 _("Use 'Tab' key to move"));
-	if (wizard.cdw_form->window == (WINDOW *) NULL) {
+	if (!wizard.cdw_form->window) {
 		cdw_vdm ("ERROR: failed to create window\n");
 		return CDW_ERROR;
 	}
@@ -283,7 +273,7 @@ cdw_rv_t cdw_verify_wizard_build(void)
 						    1, 1,
 						    CDW_COLORS_DIALOG, (char *) NULL, (char *) NULL);
 
-	if (wizard.cdw_form->subwindow == (WINDOW *) NULL) {
+	if (!wizard.cdw_form->subwindow) {
 		cdw_vdm ("ERROR: failed to create subwindow\n");
 		return CDW_ERROR;
 	}
@@ -293,7 +283,7 @@ cdw_rv_t cdw_verify_wizard_build(void)
 	wizard.cdw_form->form = cdw_ncurses_new_form(wizard.cdw_form->window,
 						     wizard.cdw_form->subwindow,
 						     wizard.cdw_form->fields);
-	if (wizard.cdw_form->form == (FORM *) NULL) {
+	if (!wizard.cdw_form->form) {
 		cdw_vdm ("ERROR: failed to create form\n");
 		return CDW_ERROR;
 	}
@@ -303,8 +293,8 @@ cdw_rv_t cdw_verify_wizard_build(void)
 
 	cdw_form_add_return_chars(wizard.cdw_form, CDW_KEY_ENTER, CDW_KEY_ESCAPE, 'q', 'Q', 0);
 
-	cdw_form_set_function(wizard.cdw_form, f_ok_b, cdw_verify_wizard_on_enter_on_verify);
-	cdw_form_set_function(wizard.cdw_form, f_cancel_b, cdw_verify_wizard_on_enter_on_cancel);
+	cdw_form_set_button_return_key(wizard.cdw_form, f_ok_b, CDW_KEY_ENTER);
+	cdw_form_set_button_return_key(wizard.cdw_form, f_cancel_b, CDW_KEY_ESCAPE);
 
 	wrefresh(wizard.cdw_form->subwindow);
 	wrefresh(wizard.cdw_form->window);
@@ -319,20 +309,20 @@ cdw_rv_t cdw_verify_wizard_build(void)
 cdw_rv_t cdw_verify_wizard_build_fields(void)
 {
 	cdw_form_descr_t descr[] = {
-		/*    widget type        begin_y              begin_x        n_cols         n_lines     field enum         data1                       data2 */
+		/*    widget type           begin_y            begin_x         n_cols         n_lines   field enum        data1                      data2 */
 
 		/* 2TRANS: this is label in verify wizard */
-		{ CDW_WIDGET_TEXT,       top_message_row,     first_col,     label_n_cols,        4,  f_top_message_t,  text_makers,                  0 },
+		{ CDW_WIDGET_ID_TEXT,       top_message_row,   first_col,      label_n_cols,        4,  f_top_message_t,  text_makers,                  0 },
 
-		{ CDW_WIDGET_DROPDOWN,   mode_row,            first_col + 1, dropdown_n_cols - 2, 1,  f_mode_dd,        dropdown_makers,              0 },
+		{ CDW_WIDGET_ID_DROPDOWN,   mode_row,          first_col + 1,  dropdown_n_cols - 2, 1,  f_mode_dd,        dropdown_makers,              0 },
 
 		/* 2TRANS: button label, "verify" means "verify data" */
-		{ CDW_WIDGET_BUTTON,     buttons_row,         3,             2,                   1,  f_ok_b,           _("Verify"),  CDW_COLORS_DIALOG },
+		{ CDW_WIDGET_ID_BUTTON,     buttons_row,       3,              2,                   1,  f_ok_b,           _("Verify"),  CDW_COLORS_DIALOG },
 		/* 2TRANS: button label */
-		{ CDW_WIDGET_BUTTON,     buttons_row,         15,            2,                   1,  f_cancel_b,       _("Cancel"),  CDW_COLORS_DIALOG },
+		{ CDW_WIDGET_ID_BUTTON,     buttons_row,      15,              2,                   1,  f_cancel_b,       _("Cancel"),  CDW_COLORS_DIALOG },
 
 		/* guard */
-		{ -1,                    0,                   0,             0,                   0,  0,                (void *) NULL,                0 }};
+		{ -1,                       0,                 0,              0,                   0,  0,                (void *) NULL,                0 }};
 
 
 	wizard.cdw_form->n_fields = CDW_VERIFY_WIZARD_N_FIELDS;
@@ -356,7 +346,7 @@ CDW_DROPDOWN *cdw_verify_wizard_make_verify_mode_dropdown(WINDOW *window, int be
 	CDW_DROPDOWN *dropdown = cdw_dropdown_new(window, begin_y, begin_x, width,
 						  3, /* n_items_max */
 						  CDW_COLORS_DIALOG);
-	if (dropdown == (CDW_DROPDOWN *) NULL) {
+	if (!dropdown) {
 		cdw_vdm ("ERROR: failed to create new dropdown\n");
 		return (CDW_DROPDOWN *) NULL;
 	}
@@ -402,28 +392,8 @@ CDW_DROPDOWN *cdw_verify_wizard_make_verify_mode_dropdown(WINDOW *window, int be
 
 
 
-int cdw_verify_wizard_on_enter_on_cancel(__attribute__((unused)) cdw_form_t *cdw_form, __attribute__((unused)) void *dummy)
-{
-	return CDW_KEY_ESCAPE;
-}
-
-
-
-
-
-int cdw_verify_wizard_on_enter_on_verify(__attribute__((unused)) cdw_form_t *cdw_form, __attribute__((unused)) void *dummy)
-{
-	return CDW_KEY_ENTER;
-}
-
-
-
-
-
 char *cdw_verify_wizard_make_message(int n_cols)
 {
 	/* 2TRANS: this is message printed in a wizard; */
 	return cdw_string_wrap(_("Select what you want to verify. Verification algorithm (md5sum, sha1sum etc.) can be changed in main window -> Configuration -> Tools -> Digest tool."), (size_t) n_cols, CDW_ALIGN_LEFT);
 }
-
-
