@@ -2,6 +2,7 @@
 #define H_CDW_BUTTON
 
 #include "main.h"
+#include "cdw_widgets.h"
 #include "cdw_ncurses.h"
 
 
@@ -9,7 +10,8 @@ typedef struct {
 	WINDOW *parent; /* parent window of the widget */
 	WINDOW *strip;  /* a private window in which the widget displays its content */
 
-	cdw_form_widget_function_t on_click; /* callback */
+	cdw_form_widget_function_t on_click_callback;
+	int on_click_key;
 
 	int begin_x;
 	int begin_y;
@@ -17,6 +19,11 @@ typedef struct {
 	char *label;
 
 	cdw_colors_t colors;
+
+	/* The variable will be set to CDW_WIDGET_ID_BUTTON by
+	   cdw_button_new(). */
+	int widget_id;
+
 } CDW_BUTTON;
 
 
@@ -26,9 +33,7 @@ void cdw_button_delete(CDW_BUTTON **button);
 void cdw_button_free(CDW_BUTTON *button);
 void cdw_button_focus(CDW_BUTTON *button);
 void cdw_button_unfocus(CDW_BUTTON *button);
-
+int  cdw_button_driver(CDW_BUTTON *button, void *data);
 
 
 #endif /* ifndef H_CDW_BUTTON */
-
-
