@@ -11,7 +11,11 @@ typedef struct {
 	bool checked;    /* state of the checkbox */
 	bool visible;    /* widget may be present, but invisible to the user, and "not-visitable" */
 
-	cdw_form_widget_function_t on_toggle;   /* callback */
+	/* The variable will be set to CDW_WIDGET_ID_CHECKBOX by
+	   cdw_checkbox_new(). */
+	cdw_id_t widget_id;
+
+	cdw_form_widget_function_t on_toggle_callback;
 } CDW_CHECKBOX;
 
 
@@ -25,6 +29,6 @@ bool cdw_checkbox_get_state(CDW_CHECKBOX *checkbox);
 bool cdw_checkbox_set_state(CDW_CHECKBOX *checkbox, bool checked);
 void cdw_checkbox_set_visibility(CDW_CHECKBOX *checkbox, bool visible);
 void cdw_checkbox_draw(CDW_CHECKBOX *checkbox);
-
+int  cdw_checkbox_driver(CDW_CHECKBOX *checkbox, void *cdw_form);
 
 #endif /* #ifndef H_CDW_CHECKBOX */
