@@ -1,6 +1,6 @@
 /* cdw
  * Copyright (C) 2002 Varkonyi Balazs
- * Copyright (C) 2007 - 2012 Kamil Ignacak
+ * Copyright (C) 2007 - 2014 Kamil Ignacak
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 
@@ -37,6 +37,17 @@
 #include "cdw_debug.h"
 #include "cdw_window.h"
 #include "cdw_string.h"
+#include "cdw_form.h"
+#include "cdw_ncurses.h"
+
+
+/* a dialog can be either dialog with input field, or dialog with
+   buttons; in future it may be possible that the two will be
+   possible at the same time */
+enum {
+	CDW_DIALOG_BUTTONS = 1,
+	CDW_DIALOG_INPUT = 2   /* Unused at the moment. */
+};
 
 
 /* 4 buttons should be enough for everyone */
@@ -475,6 +486,7 @@ cdw_rv_t cdw_dialog_base_txt_sizes(CDW_DIALOG_BASE *dialog, const char *message)
 
 	if (n_rows > LINES) {
 		cdw_vdm ("ERROR: failed to calculate satisfactory sizes of text area, text may be clipped\n");
+		cdw_vdm ("ERROR: n_rows = %d, LINES = %d\n", n_rows, LINES);
 		return CDW_ERROR;
 	} else {
 		return CDW_OK;
@@ -759,85 +771,6 @@ void cdw_dialog_display_buttons(CDW_DIALOG_BASE *dialog)
 
 
 
-/**
-   \brief Create and display dialog window with text input
-
-   \date Function's top-level comment reviewed on 2012-01-08
-   \date Function's body reviewed on 2012-01-08
-
-   Create and display dialog window with input field. Display prompt in
-   the dialog window, accept data entered in the window, return proper
-   value after user ends interaction with the dialog.
-
-   Function's argument is this big data structure which isn't most
-   sophisticated solution, but it shortens function's argument list
-   significantly :)
-
-   Data entered in the dialog is returned by data->buffer. The buffer
-   must be managed by caller code.
-
-   \param data - data structure defining dialog's appearance
-
-   \return CDW_ERROR on failure
-   \return CDW_OK if user pressed Enter in the dialog
-   \return CDW_CANCEL if user pressed Escape in the dialog
-*/
-cdw_rv_t cdw_input_dialog(cdw_input_data_t *data)
-{
-	CDW_DIALOG_BASE *dialog = cdw_dialog_base_new(CDW_DIALOG_INPUT);
-	if (!dialog) {
-		cdw_vdm ("ERROR: failed to get new dialog base\n");
-		return CDW_ERROR;
-	}
-
-	cdw_dialog_base_sizes(dialog, data->prompt_message);
-	cdw_dialog_base_display_basics(dialog, data->window_title, data->prompt_message, CDW_ALIGN_LEFT);
-
-	if (data->chars_max) {
-		if (dialog->input.n_cols > data->chars_max) {
-			/* input subwindow must be no wider than limit,
-			   otherwise setting size limit for input buffer
-			   will fail */
-			dialog->input.n_cols = data->chars_max;
-		}
-	}
-
-	int begin_x = (getmaxx(dialog->window) - dialog->input.n_cols) / 2;
-	CDW_INPUT_LINE *input_line = cdw_input_line_new(dialog->window,
-							dialog->input.begin_y, begin_x,
-							dialog->input.n_cols, *(data->buffer),
-							data->input_type, data->chars_max);
-	if (!input_line) {
-		cdw_vdm ("ERROR: failed to create input line\n");
-		return CDW_ERROR;
-	}
-
-	cdw_rv_t retval = CDW_CANCEL;
-
-	int key = cdw_input_line_driver(input_line, data->buffer, data->attempts_max);
-	if (key == CDW_KEY_ENTER || key == CDW_KEY_TAB) {
-		/* user entered correct value, do noting */
-		retval = CDW_OK;
-	} else if (key == CDW_KEY_ESCAPE) {
-		/* user cancelled entering string, do nothing */
-		retval = CDW_CANCEL;
-	} else {
-		cdw_buttons_dialog(data->window_title,
-				   data->error_message,
-				   CDW_BUTTONS_OK, CDW_COLORS_WARNING);
-		retval = CDW_ERROR;
-	}
-
-	cdw_input_line_delete(&input_line);
-	cdw_dialog_base_delete(&dialog);
-
-	return retval;
-}
-
-
-
-
-
 /**
    \brief Show dialog window with title, message and buttons
 
@@ -884,7 +817,7 @@ cdw_rv_t cdw_buttons_dialog(const char *title, const char *message, int button_t
 
 	/* debug code */
 	/* char *message = "\n  a  \n  b  \n  c  \n  d  \n  e  \n  f  \n  g  \n  h  \n  i  \n  j  \n  k  \n  l  \n  m  \n  n  \n  o  \n  p  \n  q  \n  r  \n  s  \n  t  \n  u  \n  w"; */
-	/* char *message = "This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.\n\nThis program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.\n\nYou should have received a copy of the GNU General Public License along with this program; if not, write to the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA"; */
+	/* char *message = "This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.\n\nThis program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.\n\nYou should have received a copy of the GNU General Public License along with this program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA."; */
 
 	cdw_dialog_base_sizes(dialog, message);
 	cdw_dialog_base_display_basics(dialog, title, message, CDW_ALIGN_CENTER);
@@ -902,3 +835,376 @@ cdw_rv_t cdw_buttons_dialog(const char *title, const char *message, int button_t
 }
 
 
+
+
+
+
+/* ***************** */
+
+
+#define CDW_INPUT_DIALOG_N_FIELDS 5
+
+typedef struct {
+	WINDOW *window;
+	WINDOW *subwindow;
+
+	/* This pointer will point to string owned by client code. */
+	const char *prompt_message;
+
+	cdw_colors_t colors;
+
+	cdw_form_t *cdw_form;
+	FIELD *fields[CDW_INPUT_DIALOG_N_FIELDS + 1];
+
+	char *buffer; /* Buffer is owned by caller. */
+	int chars_max;
+
+	int begin_x;
+	int begin_y;
+
+	int n_cols;
+	int n_rows;
+
+	int sub_begin_x;
+	int sub_begin_y;
+
+	int sub_n_cols;
+	int sub_n_rows;
+
+	int txt_n_rows; /* Height of prompt message. */
+
+} CDW_INPUT_DIALOG;
+
+
+static CDW_INPUT_DIALOG *input_dialog = (CDW_INPUT_DIALOG *) NULL;
+
+
+static cdw_rv_t cdw_input_dialog_init(CDW_INPUT_DIALOG **dialog, const char *message, int chars_max, char *buffer);
+static void     cdw_input_dialog_delete(CDW_INPUT_DIALOG **d);
+static cdw_rv_t cdw_input_dialog_build(const char *title, const char *message, int chars_max, char *buffer);
+static cdw_rv_t cdw_input_dialog_sizes(CDW_INPUT_DIALOG *dialog);
+static int      cdw_input_dialog_driver(CDW_INPUT_DIALOG *dialog);
+static char *   cdw_input_dialog_prompt_message_maker(int n_cols);
+
+
+
+
+
+/* Some layout constraints. */
+static const int first_col =  0;
+
+
+enum {
+	f_prompt_t,
+	f_input_l,
+	f_input_i,
+	f_ok_b,
+	f_cancel_b
+};
+
+
+
+
+
+cdw_rv_t cdw_input_dialog(const char *title, const char *message, int chars_max, char *buffer)
+{
+	cdw_rv_t crv = cdw_input_dialog_build(title, message, chars_max, buffer);
+	if (crv != CDW_OK) {
+		cdw_vdm ("ERROR: failed to init wizard\n");
+		cdw_input_dialog_delete(&input_dialog);
+		return CDW_ERROR;
+	}
+
+	int rv = cdw_input_dialog_driver(input_dialog);
+	cdw_input_dialog_delete(&input_dialog);
+
+	if (rv == CDW_KEY_ENTER) {
+		return CDW_OK;
+	} else {
+		return CDW_CANCEL;
+	}
+}
+
+
+
+
+
+cdw_rv_t cdw_input_dialog_init(CDW_INPUT_DIALOG **d, const char *message, int chars_max, char *buffer)
+{
+	*d = (CDW_INPUT_DIALOG *) malloc(sizeof (CDW_INPUT_DIALOG));
+	if (!*d) {
+		cdw_vdm ("ERROR: failed to allocate memory for input line dialog\n");
+		return CDW_ERROR;
+	}
+
+	(*d)->window = (WINDOW *) NULL;
+	(*d)->subwindow = (WINDOW *) NULL;
+
+	(*d)->prompt_message = message;
+
+	(*d)->colors = CDW_COLORS_DIALOG;
+
+	(*d)->cdw_form = (cdw_form_t *) NULL;
+
+	for (int i = 0; i < CDW_INPUT_DIALOG_N_FIELDS + 1; i++) {
+		(*d)->fields[i] = (FIELD *) NULL;
+	}
+
+	(*d)->buffer = buffer;
+	(*d)->chars_max = chars_max;
+
+	(*d)->begin_x = 0;
+	(*d)->begin_y = 0;
+
+	(*d)->n_cols = 0;
+	(*d)->n_rows = 0;
+
+	(*d)->sub_begin_x = 0;
+	(*d)->sub_begin_y = 0;
+
+	(*d)->sub_n_cols = 0;
+	(*d)->sub_n_rows = 0;
+
+	(*d)->txt_n_rows = 0; /* Height of prompt message. */
+
+	return CDW_OK;
+}
+
+
+
+
+
+void cdw_input_dialog_delete(CDW_INPUT_DIALOG **d)
+{
+	cdw_assert (d, "ERROR: passed NULL pointer to the function\n");
+	if (!*d) {
+		cdw_vdm ("WARNING: passed NULL input dialog to the function\n");
+		return;
+	}
+
+	/* This order of these four function calls minimizes number of
+	   problems reported by valgrind. */
+	cdw_form_delete_form_objects((*d)->cdw_form);
+	cdw_window_delete(&(*d)->subwindow);
+	cdw_window_delete(&(*d)->window);
+	cdw_form_delete(&((*d)->cdw_form));
+
+	free(*d);
+	*d = (CDW_INPUT_DIALOG *) NULL;
+
+	return;
+}
+
+
+
+
+
+int cdw_input_dialog_driver(CDW_INPUT_DIALOG *d)
+{
+	int fi = f_input_i; /* Initial focus on input. */
+	int key = 'a';      /* Safe initial value. */
+
+	while (key != CDW_KEY_ESCAPE && key != 'q' && key != 'Q') {
+		key = cdw_form_driver(d->cdw_form, fi);
+		fi = field_index(current_field(d->cdw_form->form));
+
+		if (key == CDW_KEY_ENTER) {
+			cdw_assert (fi == f_ok_b, "ERROR: driver returns KEY_ENTER for widget other than OK button (%d)\n", fi);
+
+			/* flush */
+			form_driver(d->cdw_form->form, REQ_VALIDATION);
+
+			/* Thanks to using safe input line, if we got
+			   this far, the string in buffer is safe. */
+			char *b = field_buffer(d->cdw_form->fields[f_input_i], 0);
+			b = cdw_string_rtrim(b);
+			strncpy(d->buffer, b, (size_t) d->chars_max);
+			d->buffer[d->chars_max] = '\0';
+
+			return CDW_KEY_ENTER;
+		} else if (key == CDW_KEY_ESCAPE) {
+			return CDW_KEY_ESCAPE;
+		} else {
+			;
+		}
+	}
+
+	return CDW_KEY_ESCAPE;
+}
+
+
+
+
+
+static cdw_form_text_maker_t text_makers[] = {
+	cdw_input_dialog_prompt_message_maker
+};
+
+
+
+
+
+char *cdw_input_dialog_prompt_message_maker(int n_cols)
+{
+	/* 2TRANS: this is a description in one of
+	   configuration window panels; a series of
+	   dropdown widgets is displayed below the label */
+	return cdw_string_wrap(input_dialog->prompt_message, (size_t) n_cols, CDW_ALIGN_LEFT);
+}
+
+
+
+
+
+cdw_rv_t cdw_input_dialog_build(const char *title, const char *message, int chars_max, char *buffer)
+{
+	cdw_rv_t crv = cdw_input_dialog_init(&input_dialog, message, chars_max, buffer);
+	if (crv != CDW_OK) {
+		cdw_vdm ("ERROR: failed to get new input line dialog\n");
+		return CDW_ERROR;
+	}
+
+	CDW_INPUT_DIALOG *d = input_dialog;
+
+	d->cdw_form = cdw_form_new(CDW_INPUT_DIALOG_N_FIELDS);
+	if (!d->cdw_form) {
+		cdw_vdm ("ERROR: failed to create cdw form\n");
+		return CDW_ERROR;
+	}
+
+	d->cdw_form->fields = d->fields;
+
+	cdw_input_dialog_sizes(d);
+
+	d->cdw_form->window = cdw_window_new((WINDOW *) NULL,
+					     d->n_rows, d->n_cols,
+					     d->begin_y, d->begin_x,
+					     CDW_COLORS_DIALOG,
+					     title,
+					     /* 2TRANS: this is tip at the bottom
+						of window - user can switch between
+						window elements using tab key */
+					     _("Use 'Tab' key to move"));
+
+	if (!d->cdw_form->window) {
+		cdw_vdm ("ERROR: failed to create window\n");
+		return CDW_ERROR;
+	}
+
+	d->cdw_form->subwindow = cdw_window_new(d->cdw_form->window,
+						d->sub_n_rows, d->sub_n_cols,
+						d->sub_begin_y, d->sub_begin_x,
+						CDW_COLORS_DIALOG,
+						(char *) NULL, (char *) NULL);
+
+	if (!d->cdw_form->subwindow) {
+		cdw_vdm ("ERROR: failed to create subwindow\n");
+		return CDW_ERROR;
+	}
+
+	int input_cols = 0;
+	if (d->chars_max > d->sub_n_cols) {
+		input_cols = d->sub_n_cols;
+	} else {
+		input_cols = d->chars_max;
+	}
+
+	int last_row = d->sub_n_rows - 2;
+
+	cdw_form_descr_t descr[] = {
+		/* type                            begin_y         begin_x      n_cols           n_lines         field enum    data1                        data2 */
+		{ CDW_WIDGET_ID_TEXT,              0,              first_col,   d->sub_n_cols,   d->txt_n_rows,  f_prompt_t,   text_makers,                     0 },
+
+		{ CDW_WIDGET_ID_DYNAMIC_LABEL,     last_row - 3,   first_col,   d->sub_n_cols,   1,              f_input_l,    "",                              0 },
+		{ CDW_WIDGET_ID_SAFE_INPUT_LINE,   last_row - 2,   first_col,   input_cols,      1,              f_input_i,    d->buffer,   (size_t) d->chars_max },
+
+		/* 2TRANS: button label */
+		{ CDW_WIDGET_ID_BUTTON,            last_row,       3,           1,               1,              f_ok_b,       _("OK"),         CDW_COLORS_DIALOG },
+
+		/* 2TRANS: button label */
+		{ CDW_WIDGET_ID_BUTTON,            last_row,       23,          1,               1,              f_cancel_b,   _("Cancel"),     CDW_COLORS_DIALOG },
+
+		/* guard */
+		{ -1,                              0,              0,           0,               0,              0,            (void *) NULL,                   0 }};
+
+
+	d->cdw_form->n_fields = CDW_INPUT_DIALOG_N_FIELDS;
+
+	crv = cdw_form_description_to_fields(descr, d->cdw_form);
+	if (crv != CDW_OK) {
+		cdw_vdm ("ERROR: failed to convert form description to form\n");
+		return CDW_ERROR;
+	}
+
+	d->cdw_form->form = cdw_ncurses_new_form(d->cdw_form->window,
+						 d->cdw_form->subwindow,
+						 d->cdw_form->fields);
+	if (!d->cdw_form->form) {
+		cdw_vdm ("ERROR: failed to create form\n");
+		return CDW_ERROR;
+	}
+
+
+	cdw_form_add_return_chars(d->cdw_form, CDW_KEY_ENTER, CDW_KEY_ESCAPE, 'q', 'Q', 0);
+
+	cdw_form_set_button_return_key(d->cdw_form, f_ok_b, CDW_KEY_ENTER);
+	cdw_form_set_button_return_key(d->cdw_form, f_cancel_b, CDW_KEY_ESCAPE);
+
+	cdw_form_bind_input_and_label(d->cdw_form, f_input_i, f_input_l);
+
+
+	/* Make sure that cdw widgets are presented properly. */
+	cdw_form_redraw_widgets(d->cdw_form);
+
+
+	wrefresh(d->cdw_form->subwindow);
+	wrefresh(d->cdw_form->window);
+
+	return CDW_OK;
+
+}
+
+
+
+
+
+static const int cdw_dialog_sub_rows_diff = 1;
+static const int cdw_dialog_sub_cols_diff = 1;
+
+
+cdw_rv_t cdw_input_dialog_sizes(CDW_INPUT_DIALOG *d)
+{
+	int cols_space = 2 * cdw_dialog_sub_cols_diff; /* Horizontal space between parent window borders and content of window. */
+	int rows_space = 2 * cdw_dialog_sub_rows_diff; /* Vertical space between parent window borders and content of window. */
+
+	d->n_cols = 50;
+	d->sub_n_cols = d->n_cols - 2 * cols_space;
+
+	d->txt_n_rows = (int) cdw_string_count_lines(d->prompt_message, (size_t) d->sub_n_cols);
+
+	d->n_rows = 2 * rows_space        /* Parent window should be larger than subwindow by X rows on top and on bottom. */
+		+ d->txt_n_rows           /* Prompt on top. */
+		+ 1                       /* Space between prompt and rest of dialog. */
+		+ 1                       /* Dynamic label for "unsafe char" message. */
+		+ 1                       /* Safe input line. */
+		+ 1                       /* Space between safe input line and buttons. */
+		+ 1                       /* Buttons row. */
+		+ 1;                      /* Space between buttons row and bottom border of parent window. */
+
+	d->sub_n_rows = d->n_rows - 2 * rows_space;
+
+	d->begin_y = ((LINES - d->n_rows) / 2) - 2;
+	d->begin_x = (COLS - d->n_cols) / 2;
+
+	d->sub_begin_y = 2 * cdw_dialog_sub_rows_diff;
+	d->sub_begin_x = 2 * cdw_dialog_sub_cols_diff;
+
+	cdw_vdm ("INFO: input dialog base sizes:\n");
+	cdw_vdm ("INFO:     n_cols = %d\n", d->n_cols);
+	cdw_vdm ("INFO:     n_rows = %d\n", d->n_rows);
+	cdw_vdm ("INFO: sub n_cols = %d\n", d->sub_n_cols);
+	cdw_vdm ("INFO: sub n_rows = %d\n", d->sub_n_rows);
+	cdw_vdm ("INFO: txt n_rows = %d\n", d->txt_n_rows);
+
+	return CDW_OK;
+}
