@@ -1,6 +1,6 @@
 /* cdw
  * Copyright (C) 2002 Varkonyi Balazs
- * Copyright (C) 2007 - 2012 Kamil Ignacak
+ * Copyright (C) 2007 - 2014 Kamil Ignacak
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 
@@ -33,6 +33,7 @@
 #include "cdw_dropdown.h"
 #include "gettext.h"
 #include "cdw_debug.h"
+#include "cdw_widgets.h"
 
 
 static int      cdw_dropdown_expanded_driver(CDW_DROPDOWN *dropdown);
@@ -43,7 +44,6 @@ static void     cdw_dropdown_display_current_item_reverse(CDW_DROPDOWN *dropdown
 
 
 
-
 /**
    \brief Create basis for new dropdown
 
@@ -83,6 +83,10 @@ CDW_DROPDOWN *cdw_dropdown_new(WINDOW *parent, int begin_y, int begin_x, int wid
 	dropdown->n_items_max = n_items_max;
 	dropdown->n_items = 0;
 
+	dropdown->current_item_ind = 0; /* There will be at least one item in the dropdown, so index=0 should be safe. */
+
+	dropdown->widget_id = CDW_WIDGET_ID_DROPDOWN;
+
 	dropdown->items = (cdw_id_label_t **) malloc((size_t) (dropdown->n_items_max + 1) * sizeof (cdw_id_label_t *));
 
 	if (!dropdown->items) {
@@ -102,6 +106,8 @@ CDW_DROPDOWN *cdw_dropdown_new(WINDOW *parent, int begin_y, int begin_x, int wid
 	dropdown->width = width;
 	dropdown->colors = colors;
 
+	dropdown->on_select_callback = (cdw_form_widget_function_t) NULL;
+
 	dropdown->visible = true;
 
 	return dropdown;
@@ -373,34 +379,73 @@ void cdw_dropdown_make_visible(CDW_DROPDOWN *dropdown)
 /**
    \brief Control keyboard input when focus is on dropdown - top level function
 
+   This driver should be used only as (dropdown variable)->driver().
+
    \date Function's top-level comment reviewed on 2012-01-07
    \date Function's body reviewed on 2012-01-07
 
-   This function calls cdw_dropdown_expanded_driver() to control
-   keyboard input in expanded \p dropdown.
+   This function controls keyboard input while a \p dropdown has
+   keyboard focus.
 
-   \param dropdown - dropdown that has focus
+   Since this function will be used in some kind of dispatcher calling
+   drivers for widgets of different types, we need to pass \p dropdown
+   as void pointer.
+
+   \param dd - dropdown that has focus
+   \param dummy - pointer to additional data; currently unused
 
    \return CDW_KEY_ENTER if user pressed ENTER in expanded dropdown
    \return CDW_KEY_ESCAPE if user pressed ESCAPE, Q or q in expanded dropdown
+   \return if any other key has been pressed the function returns the key
 */
-int cdw_dropdown_driver(CDW_DROPDOWN *dropdown)
+int cdw_dropdown_driver(CDW_DROPDOWN *dd, __attribute__((unused)) void *dummy)
 {
-	cdw_assert (dropdown, "ERROR: cannot control NULL dropdown\n");
-	cdw_assert (dropdown->parent, "ERROR: cannot control dropdown with NULL parent\n");
+	cdw_assert (dd, "ERROR: NULL pointer to dropdown\n");
+	cdw_assert (dd->widget_id == CDW_WIDGET_ID_DROPDOWN, "ERROR: this is not a dropdown widget\n");
+	cdw_assert (dd->parent, "ERROR: cannot control dropdown with NULL parent\n");
 
-	cdw_dropdown_expand(dropdown);
-	int key = cdw_dropdown_expanded_driver(dropdown);
-	cdw_dropdown_collapse(dropdown);
+	int key = 'a'; /* Safe initial value. */
 
-	if (key == CDW_KEY_ENTER) {
-		/* when dropdown is closed (hidden), it should remain
-		   highlighted, so second parameter is true */
-		cdw_dropdown_display_current_item_reverse(dropdown, true);
+	while (1) {
+		key = wgetch(dd->parent);
+
+		if (key == CDW_KEY_ENTER) {
+			cdw_dropdown_expand(dd);
+			int expanded_key = cdw_dropdown_expanded_driver(dd);
+			cdw_dropdown_collapse(dd);
+
+			if (expanded_key == CDW_KEY_ENTER) {
+				/* when dropdown is closed (hidden), it should remain
+				   highlighted, so second parameter is true */
+				cdw_dropdown_display_current_item_reverse(dd, true);
+
+				/* Call callback function, let it know which item (by
+				   ID) has been selected. */
+				if (dd->on_select_callback) {
+					dd->on_select_callback(NULL, &(dd->items[dd->current_item_ind]->id));
+				}
+			}
+		} else if (key == CDW_KEY_TAB || key == KEY_BTAB
+			   || key == KEY_DOWN || key == KEY_UP) {
+
+			/* Inter-widget movement key. Will be handled
+			   by parent of the widget. */
+			break;
+		} else if (key == CDW_KEY_ESCAPE || key == 'q' || key == 'Q') {
+
+			key = CDW_KEY_ESCAPE;
+			break;
+		} else {
+			/* Some other key that may be handled only by
+			   parent of the widget. It may happen that
+			   parent is configured to handle special keys
+			   like F2 or other keys. */
+			break;
+		}
 	}
 
-	redrawwin(dropdown->parent);
-	wrefresh(dropdown->parent);
+	redrawwin(dd->parent);
+	wrefresh(dd->parent);
 
 	return key;
 }
@@ -953,6 +998,8 @@ CDW_DROPDOWN *cdw_dropdown_maker_wrapper(WINDOW *parent, int begin_y, int begin_
 		return (CDW_DROPDOWN *) NULL;
 	}
 
+	dropdown->on_select_callback = (cdw_form_widget_function_t) NULL;
+
 	for (int i = 0; i < n_items; i++) {
 		cdw_rv_t crv = cdw_dropdown_add_item(dropdown, items[i].id, _(items[i].label));
 		if (crv != CDW_OK) {
@@ -971,4 +1018,3 @@ CDW_DROPDOWN *cdw_dropdown_maker_wrapper(WINDOW *parent, int begin_y, int begin_
 	}
 	return dropdown;
 }
-
