@@ -1,6 +1,6 @@
 /* cdw
  * Copyright (C) 2002 Varkonyi Balazs
- * Copyright (C) 2007 - 2012 Kamil Ignacak
+ * Copyright (C) 2007 - 2014 Kamil Ignacak
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 
@@ -38,6 +38,7 @@
 #include "gettext.h"
 #include "cdw_string.h"
 #include "cdw_debug.h"
+#include "cdw_window.h"
 
 
 
@@ -192,26 +193,30 @@ void cdw_input_line_delete(CDW_INPUT_LINE **input_line)
 		return;
 	}
 
-	/* IMPORTANT: for some reason you have first free fields
-	   and then unpost and free form */
+	/* From ncurses docs: "The functions free_field() and
+	   free_form are available to free field and form objects.  It
+	   is an error to attempt to free a field connected to a form,
+	   but not vice-versa; thus, you will generally free your form
+	   objects first.".
+
+	   So first unpost form, then free form, then free field. */
+	if ((*input_line)->form) {
+		int rv = unpost_form((*input_line)->form);
+		cdw_vdm_n ("unpost_form", rv, "");
+
+		rv = free_form((*input_line)->form);
+		cdw_vdm_n ("free_form", rv, "");
+
+		(*input_line)->form = (FORM *) NULL;
+	}
+
 	if ((*input_line)->field[0]) {
-		free_field((*input_line)->field[0]);
-		unpost_form((*input_line)->form);
+		int rv = free_field((*input_line)->field[0]);
+		cdw_vdm_n ("free_field", rv, "");
 		(*input_line)->field[0] = (FIELD *) NULL;
 	}
 
-	if ((*input_line)->form) {
-		int e = free_form((*input_line)->form);
-		(*input_line)->form = (FORM *) NULL;
-		if (e != E_OK) {
-			cdw_vdm ("ERROR: free_form() returns \"%s\"\n", cdw_ncurses_error_string(e));
-		}
-	}
-
-	if ((*input_line)->win) {
-		delwin(((*input_line)->win));
-		(*input_line)->win = (WINDOW *) NULL;
-	}
+	cdw_window_delete(&(*input_line)->win);
 
 	free(*input_line);
 	*input_line = (CDW_INPUT_LINE *) NULL;
@@ -585,11 +590,13 @@ cdw_rv_t cdw_input_line_get_content(CDW_INPUT_LINE *input_line, char **output_bu
 		cdw_vdm ("INFO: \"%s\" is secure\n", local_buffer);
 		crv = cdw_string_set(output_buffer, local_buffer);
 		cdw_assert (crv == CDW_OK, "ERROR: failed to save final string \"%s\"\n", local_buffer);
+		cdw_string_delete(&local_buffer);
 		/* key = key */
 		return CDW_OK;
 	} else {
 		cdw_vdm ("ERROR: insecure char in \"%s\"\n", local_buffer);
 		cdw_input_line_driver_message(input_line, insecure);
+		cdw_string_delete(&local_buffer);
 		return CDW_ERROR;
 	}
 }
