@@ -7,6 +7,7 @@
 #include "main.h"
 
 typedef struct cdw_dll_item cdw_dll_item_t;
+typedef struct cdw_dll_item cdw_dll_t;
 struct cdw_dll_item {
 	cdw_dll_item_t *prev;
 	cdw_dll_item_t *next;
@@ -25,7 +26,7 @@ size_t cdw_dll_length(cdw_dll_item_t *head); /* tested */
 bool cdw_dll_is_empty(cdw_dll_item_t *head); /* partially tested */
 bool cdw_dll_is_member(cdw_dll_item_t *head, void *data, bool (*pred)(const void *, const void *)); /* tested */
 cdw_rv_t cdw_dll_clean(cdw_dll_item_t *head);
-
+cdw_rv_t cdw_dll_delete(cdw_dll_t **head, cdw_deallocator_t dealloc);
 
 
 /* unit tests */
