@@ -1,6 +1,6 @@
 /* cdw
  * Copyright (C) 2002 Varkonyi Balazs
- * Copyright (C) 2007 - 2012 Kamil Ignacak
+ * Copyright (C) 2007 - 2014 Kamil Ignacak
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #define _POSIX_SOURCE /* struct sigaction */
@@ -28,9 +28,11 @@
 #include <unistd.h> /* access() */
 #include <errno.h>
 
+#if 0
 /* wait() */
 #include <sys/types.h>
 #include <sys/wait.h>
+#endif
 
 #include "cdw_sys.h"
 #include "gettext.h"
@@ -60,7 +62,10 @@ static void cdw_sys_exit_signal_message(void);
 static void cdw_sys_sigwinch_handler(int signal_number);
 static void cdw_sys_sigchild_handler(__attribute__((unused)) int signal_number);
 
+#if 0
 static sig_atomic_t child_exit_status;
+#endif
+
 static sig_atomic_t cdw_sys_signal_number;
 
 static cdw_rv_t cdw_sys_check_file_system_support_via_proc_fs(cdio_fs_t cdio_fs);
@@ -157,11 +162,18 @@ struct {
 */
 void cdw_sys_sigchild_handler(__attribute__((unused)) int signal_number)
 {
+#if 0
+	/* Stopped/terminated child process will be handled by
+	   cdw_thread.c/run_command()/wait(). We will need to capture
+	   return code of child processes, and it's more convenient to
+	   call wait() in there. */
+
+
 	/* clean child process */
 	int status;
 	wait(&status);
 	child_exit_status = status;
-
+#endif
 	return;
 }
 
