@@ -1,6 +1,6 @@
 /* cdw
  * Copyright (C) 2002 Varkonyi Balazs
- * Copyright (C) 2007 - 2012 Kamil Ignacak
+ * Copyright (C) 2007 - 2014 Kamil Ignacak
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 #define _GNU_SOURCE /* getopt_long() */
 #include <string.h>
@@ -29,13 +29,13 @@
 #include <sys/stat.h>
 #include <fcntl.h>
 
-#include "config.h"
 #include "cdw_logging.h"
 #include "gettext.h"
 #include "cdw_drive.h"
 #include "cdw_utils.h"
 #include "cdw_debug.h"
 
+#include "config_cdw.h"
 
 
 static void cdw_utils_print_version(void);
@@ -204,7 +204,7 @@ void cdw_utils_print_help(const char *program_name)
 	/* 2TRANS: this is message printed in terminal,
 	   first %s is program name, second %s is
 	   program version */
-	printf(_("Copyright (C) 2007 - 2012 Kamil Ignacak\n\n"));
+	printf(_("Copyright (C) 2007 - 2014 Kamil Ignacak\n\n"));
 	/* 2TRANS: this is message printed in terminal,
 	   '2+' means "version 2, or later";
 	   keep double newline character */
@@ -946,4 +946,3 @@ void test_cdw_utils_id_label_table_get_id(void)
 
 
 #endif /* #ifdef CDW_UNIT_TEST_CODE */
-
